@@ -20,6 +20,7 @@ typedef struct {
 	void (*eval)	   (GnmDependent *dep);
 	void (*set_expr)   (GnmDependent *dep, GnmExprTop const *new_texpr);
 	GSList* (*changed) (GnmDependent *dep);
+	GnmCellPos const* (*pos) (GnmDependent const *dep);
 	void (*debug_name) (GnmDependent const *dep, GString *target);
 } GnmDependentClass;
 
@@ -31,6 +32,7 @@ typedef enum {
 	DEPENDENT_DYNAMIC_DEP	   = 0x00000002,	/* builtin type */
 	DEPENDENT_NAME		   = 0x00000003,	/* builtin pseudo type */
 	DEPENDENT_MANAGED	   = 0x00000004,	/* builtin type */
+	DEPENDENT_STYLE		   = 0x00000005,	/* builtin type */
 	DEPENDENT_TYPE_MASK	   = 0x00000fff,
 
 	/* Linked into the workbook wide expression list */
@@ -94,6 +96,8 @@ void	 dependent_unlink	   (GnmDependent *dep);
 void	 dependent_queue_recalc	   (GnmDependent *dep);
 void	 dependent_add_dynamic_dep (GnmDependent *dep, GnmRangeRef const *rr);
 
+GnmCellPos const *dependent_pos (GnmDependent const *dep);
+
 GOUndo  *dependents_relocate	    (GnmExprRelocateInfo const *info);
 void	 dependents_link	    (GSList *deps);
 
@@ -107,6 +111,10 @@ void dependents_workbook_destroy  (Workbook *wb);
 void dependents_revive_sheet      (Sheet *sheet);
 void workbook_queue_all_recalc	  (Workbook *wb);
 
+GSList *gnm_dep_style_dependency (Sheet *sheet,
+				  GnmExprTop const *texpr,
+				  GnmRange const *r);
+
 GnmDepContainer *gnm_dep_container_new  (Sheet *sheet);
 void		 gnm_dep_container_dump	(GnmDepContainer const *deps,
 					 Sheet *sheet);
@@ -137,6 +145,8 @@ t ## _get_dep_type (void)					\
 		static GnmDependentClass klass;			\
 		klass.eval	 = &t ## _eval;			\
 		klass.set_expr	 = set_expr_handler;		\
+		klass.changed	 = NULL;			\
+		klass.pos	 = NULL;			\
 		klass.debug_name = &t ## _debug_name;		\
 		type = dependent_type_register (&klass);	\
 	}							\
