@@ -50,7 +50,6 @@
 #include <commands.h>
 #include <mathfunc.h>
 #include <preview-grid.h>
-#include <widgets/widget-font-selector.h>
 #include <widgets/gnumeric-dashed-canvas-line.h>
 #include <widgets/gnm-format-sel.h>
 #include <style-conditions.h>
@@ -150,9 +149,7 @@ typedef struct _FormatState {
 		GORotationSel	*rotation;
 	} align;
 	struct {
-		FontSelector	*selector;
-		GtkToggleButton	*superscript, *subscript;
-		ColorPicker      color;
+		GOFontSel	*selector;
 	} font;
 	struct {
 		GocCanvas	*canvas;
@@ -168,7 +165,7 @@ typedef struct _FormatState {
 	} border;
 	struct {
 		GocCanvas	*canvas;
-		PreviewGrid     *grid;
+		GnmPreviewGrid     *grid;
 		GnmStyle        *style;
 
 		ColorPicker	 back_color;
@@ -352,8 +349,7 @@ static void
 setup_color_pickers (FormatState *state,
 		     ColorPicker *picker,
 		     char const *color_group,
-		     char const *container,
-                     int col, int row,
+		     char const *placeholder,
 		     char const *label,
 		     char const *default_caption,
 		     char const *caption,
@@ -389,8 +385,7 @@ setup_color_pickers (FormatState *state,
 	default:
 		g_warning ("Unhandled style element!");
 	}
-	cg = go_color_group_fetch (color_group,
-		 wb_control_view (WORKBOOK_CONTROL (state->wbcg)));
+	cg = go_color_group_fetch (color_group, NULL);
 	combo = go_combo_color_new (NULL, default_caption,
 		def_sc ? def_sc->go_color : GO_COLOR_BLACK, cg);
 	g_object_unref (cg);
@@ -412,11 +407,11 @@ setup_color_pickers (FormatState *state,
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
 	gtk_container_add (GTK_CONTAINER (frame), combo);
-
-	w = go_gtk_builder_get_widget (state->gui, container);
-	gtk_grid_attach (GTK_GRID (w), frame, col, row, 1, 1);
 	gtk_widget_show_all (frame);
 
+	w = go_gtk_builder_get_widget (state->gui, placeholder);
+	go_gtk_widget_replace (w, frame);
+
 	w = go_gtk_builder_get_widget (state->gui, label);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (w), combo);
 
@@ -479,6 +474,8 @@ static void
 fmt_dialog_init_format_page (FormatState *state)
 {
 	GOFormatSel *gfs;
+	GODateConventions const *date_conv =
+		workbook_date_conv (state->sheet->workbook);
 
 	state->format_sel = gnm_format_sel_new ();
 	gfs = GO_FORMAT_SEL (state->format_sel);
@@ -492,10 +489,7 @@ fmt_dialog_init_format_page (FormatState *state)
 		GOFormat const *fmt = gnm_style_get_format (state->style);
 		go_format_sel_set_style_format (gfs, fmt);
 	}
-	if (state->value)
-		gnm_format_sel_set_value (gfs, state->value);
-	go_format_sel_set_dateconv (gfs,
-				    workbook_date_conv (state->sheet->workbook));
+	go_format_sel_set_dateconv (gfs, date_conv);
 	go_format_sel_editable_enters (gfs, GTK_WINDOW (state->dialog));
 
 	g_signal_connect (G_OBJECT (state->format_sel), "format_changed",
@@ -691,31 +685,25 @@ fmt_dialog_init_align_page (FormatState *state)
 	} else
 		r = 0;
 	state->align.rotation = (GORotationSel *) go_rotation_sel_new ();
-	gtk_grid_attach (GTK_GRID (go_gtk_builder_get_widget (state->gui, "alignment-grid")),
-	                    GTK_WIDGET (state->align.rotation), 3, 0, 1, 12);
 	go_rotation_sel_set_rotation (state->align.rotation, r);
 	g_signal_connect (G_OBJECT (state->align.rotation), "rotation-changed",
 			  G_CALLBACK (cb_rotation_changed), state);
+	go_gtk_widget_replace (go_gtk_builder_get_widget (state->gui, "rotation_placeholder"),
+			 GTK_WIDGET (state->align.rotation));
 }
 
 /*****************************************************************************/
 
 static void
 cb_font_changed (G_GNUC_UNUSED GtkWidget *widget,
-		 GnmStyle *style, FormatState *state)
+		 PangoAttrList *attrs, FormatState *state)
 {
-	static GnmStyleElement const font_types[] = {
-		MSTYLE_FONT_NAME,
-		MSTYLE_FONT_SIZE,
-		MSTYLE_FONT_BOLD,
-		MSTYLE_FONT_ITALIC,
-		MSTYLE_FONT_UNDERLINE,
-		MSTYLE_FONT_STRIKETHROUGH,
-		MSTYLE_FONT_SCRIPT,
-		MSTYLE_FONT_COLOR
-	};
-	int i;
-	static int const num_font_types = G_N_ELEMENTS (font_types);
+	PangoAttrIterator *aiter;
+	const PangoAttribute *attr;
+	GnmStyle *res = state->result;
+	GOFontScript script = GO_FONT_SCRIPT_STANDARD;
+	gboolean has_script_attr = FALSE;
+	GnmColor *c;
 
 	gboolean changed = FALSE;
 	g_return_if_fail (state != NULL);
@@ -723,194 +711,248 @@ cb_font_changed (G_GNUC_UNUSED GtkWidget *widget,
 	if (!state->enable_edit)
 		return;
 
-	for (i = 0 ; i < num_font_types; i++) {
-		GnmStyleElement const t = font_types[i];
-		if (gnm_style_is_element_set (style, t)) {
-			gnm_style_merge_element (state->result, style, t);
+	aiter = pango_attr_list_get_iterator (attrs);
+
+	attr = pango_attr_iterator_get (aiter, PANGO_ATTR_FAMILY);
+	if (attr) {
+		const char *s = ((PangoAttrString*)attr)->value;
+		if (!gnm_style_is_element_set (res, MSTYLE_FONT_NAME) ||
+		    !g_str_equal (s, gnm_style_get_font_name (res))) {
 			changed = TRUE;
+			gnm_style_set_font_name (res, s);
 		}
 	}
 
+	attr = pango_attr_iterator_get (aiter, PANGO_ATTR_SIZE);
+	if (attr) {
+		int i = ((PangoAttrInt*)attr)->value;
+		double d = i / (double)PANGO_SCALE;
+		if (!gnm_style_is_element_set (res, MSTYLE_FONT_SIZE) ||
+		    d != gnm_style_get_font_size (res)) {
+			changed = TRUE;
+			gnm_style_set_font_size (res, d);
+		}
+	}
+
+	attr = pango_attr_iterator_get (aiter, PANGO_ATTR_WEIGHT);
+	if (attr) {
+		int i = ((PangoAttrInt*)attr)->value;
+		gboolean b = (i >= PANGO_WEIGHT_BOLD);
+		if (!gnm_style_is_element_set (res, MSTYLE_FONT_BOLD) ||
+		    b != gnm_style_get_font_bold (res)) {
+			changed = TRUE;
+			gnm_style_set_font_bold (res, b);
+		}
+	}
+
+	attr = pango_attr_iterator_get (aiter, PANGO_ATTR_STYLE);
+	if (attr) {
+		int i = ((PangoAttrInt*)attr)->value;
+		gboolean b = (i != PANGO_STYLE_NORMAL);
+		if (!gnm_style_is_element_set (res, MSTYLE_FONT_ITALIC) ||
+		    b != gnm_style_get_font_italic (res)) {
+			changed = TRUE;
+			gnm_style_set_font_italic (res, b);
+		}
+	}
+
+	attr = pango_attr_iterator_get (aiter, PANGO_ATTR_UNDERLINE);
+	if (attr) {
+		int i = ((PangoAttrInt*)attr)->value;
+		GnmUnderline u = gnm_translate_underline_from_pango (i);
+		if (!gnm_style_is_element_set (res, MSTYLE_FONT_UNDERLINE) ||
+		    u != gnm_style_get_font_uline (res)) {
+			changed = TRUE;
+			gnm_style_set_font_uline (res, u);
+		}
+	}
+
+	attr = pango_attr_iterator_get (aiter, PANGO_ATTR_STRIKETHROUGH);
+	if (attr) {
+		int i = ((PangoAttrInt*)attr)->value;
+		gboolean b = (i != 0);
+		if (!gnm_style_is_element_set (res, MSTYLE_FONT_STRIKETHROUGH) ||
+		    b != gnm_style_get_font_strike (res)) {
+			changed = TRUE;
+			gnm_style_set_font_strike (res, b);
+		}
+	}
+
+	attr = pango_attr_iterator_get (aiter, go_pango_attr_subscript_get_attr_type ());
+	if (attr) {
+		has_script_attr = TRUE;
+		if (((GOPangoAttrSubscript*)attr)->val)
+			script = GO_FONT_SCRIPT_SUB;
+	}
+	attr = pango_attr_iterator_get (aiter, go_pango_attr_superscript_get_attr_type ());
+	if (attr) {
+		has_script_attr = TRUE;
+		if (((GOPangoAttrSuperscript*)attr)->val)
+			script = GO_FONT_SCRIPT_SUPER;
+	}
+	if (has_script_attr &&
+	    (!gnm_style_is_element_set (res, MSTYLE_FONT_SCRIPT) ||
+	     script != gnm_style_get_font_script (res))) {
+		changed = TRUE;
+		gnm_style_set_font_script (res, script);
+	}
+
+	attr = pango_attr_iterator_get (aiter, PANGO_ATTR_FOREGROUND);
+	c = attr
+		? gnm_color_new_pango (&((PangoAttrColor*)attr)->color)
+		: style_color_auto_font ();
+	if (!gnm_style_is_element_set (res, MSTYLE_FONT_COLOR) ||
+	    !style_color_equal (c, gnm_style_get_font_color (res))) {
+		changed = TRUE;
+		gnm_style_set_font_color (res, c);
+	} else
+		style_color_unref (c);
+
+	pango_attr_iterator_destroy (aiter);
+
 	if (changed)
 		fmt_dialog_changed (state);
 }
 
-/*
- * A callback to set the font color.
- * It is called whenever the color combo changes value.
- */
 static void
-cb_font_preview_color (G_GNUC_UNUSED GOComboColor *combo,
-		       GOColor c,
-		       G_GNUC_UNUSED gboolean is_custom,
-		       G_GNUC_UNUSED gboolean by_user,
-		       gboolean is_default, FormatState *state)
+change_font_attr (FormatState *state, PangoAttribute *attr)
 {
-	GnmColor *col;
+	GOFontSel *gfs = state->font.selector;
+	PangoAttrList *attrs = pango_attr_list_copy
+		(go_font_sel_get_sample_attributes (gfs));
+	attr->start_index = 0;
+	attr->end_index = -1;
+	pango_attr_list_change (attrs, attr);
+	go_font_sel_set_sample_attributes (gfs, attrs);
+	cb_font_changed (NULL, attrs, state);
+	pango_attr_list_unref (attrs);
+}
 
-	if (!state->enable_edit)
+static void
+set_font_underline (FormatState *state, GnmUnderline u)
+{
+	PangoUnderline pu = gnm_translate_underline_to_pango (u);
+	change_font_attr (state, pango_attr_underline_new (pu));
+}
+
+static void
+cb_underline_changed (GOOptionMenu *om, FormatState *state)
+{
+	GtkWidget *selected = go_option_menu_get_history (om);
+	GnmUnderline u;
+
+	if (!selected)
 		return;
 
-	col = is_default
-		? style_color_auto_font ()
-		: gnm_color_new_go (c);
-	font_selector_set_color (state->font.selector, col);
+	u = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (selected), "value"));
+	set_font_underline (state, u);
 }
 
-static void
-cb_font_strike_toggle (GtkToggleButton *button, FormatState *state)
-{
-	if (state->enable_edit) {
-		font_selector_set_strike (
-			state->font.selector,
-			gtk_toggle_button_get_active (button));
-	}
-}
-static void
-cb_font_script_toggle (GtkToggleButton *button, FormatState *state)
-{
-	if (state->enable_edit) {
-		GOFontScript script = GO_FONT_SCRIPT_STANDARD;
-		if (gtk_toggle_button_get_active (button)) {
-			state->enable_edit = FALSE;
-			if (button == state->font.superscript) {
-				script = GO_FONT_SCRIPT_SUPER;
-				gtk_toggle_button_set_active (state->font.subscript, FALSE);
-			} else {
-				script = GO_FONT_SCRIPT_SUB;
-				gtk_toggle_button_set_active (state->font.superscript, FALSE);
-			}
-			state->enable_edit = TRUE;
-		}
-		font_selector_set_script (state->font.selector, script);
-	}
-}
-
-static gboolean
-cb_font_underline_changed (GtkComboBoxText *combo,
-			   FormatState *state)
-{
-	GnmUnderline res = UNDERLINE_NONE;
-	int i;
-	char *new_text = gtk_combo_box_text_get_active_text (combo);
-
-	if (!state->enable_edit) {
-		g_free (new_text);
-		return FALSE;
-	}
-
-	for (i = G_N_ELEMENTS (underline_types); i-- > 0; )
-		if (go_utf8_collate_casefold (new_text, g_dpgettext2 (NULL, "underline", underline_types[i].Cname)) == 0) {
-			res = underline_types[i].ut;
-			break;
-		}
-
-	font_selector_set_underline (state->font.selector, res);
-	g_free (new_text);
-	return TRUE;
-}
 
 /* Manually insert the font selector, and setup signals */
 static void
 fmt_dialog_init_font_page (FormatState *state)
 {
-	GtkWidget *tmp = font_selector_new ();
-	FontSelector *font_widget = FONT_SELECTOR (tmp);
-	GtkWidget *container = go_gtk_builder_get_widget (state->gui, "font-grid");
-	GtkWidget *uline = gtk_combo_box_text_new_with_entry ();
-	GtkEntry *uline_entry = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (uline)));
-	char const *uline_str;
-	GtkWidget *strike = go_gtk_builder_get_widget (state->gui, "strikethrough_button");
-	gboolean   strikethrough = FALSE;
+	GOColorGroup *cg;
+	GtkWidget *font_widget;
+	gboolean strikethrough = FALSE;
 	GOFontScript script = GO_FONT_SCRIPT_STANDARD;
-	int i;
+	GODateConventions const *date_conv =
+		workbook_date_conv (state->sheet->workbook);
+	GnmColor *mcolor = NULL;
+	GnmColor *def_sc;
+	GtkWidget *up;
 
-	g_return_if_fail (container != NULL);
-	g_return_if_fail (uline != NULL);
-	g_return_if_fail (strike != NULL);
+	up = go_option_menu_build
+		(C_("underline", "None"), UNDERLINE_NONE,
+		 C_("underline", "Single"), UNDERLINE_SINGLE,
+		 C_("underline", "Double"), UNDERLINE_DOUBLE,
+		 C_("underline", "Single Low"), UNDERLINE_SINGLE_LOW,
+		 C_("underline", "Double Low"), UNDERLINE_DOUBLE_LOW,
+		 NULL);
+	g_signal_connect (up,
+			  "changed", G_CALLBACK (cb_underline_changed), state);
+	def_sc = style_color_auto_font ();
+	cg = go_color_group_fetch ("fore_color_group", NULL);
+	font_widget = g_object_new (GO_TYPE_FONT_SEL,
+				    "show-style", TRUE,
+				    "show-color", TRUE,
+				    "color-unset-text", _("Automatic"),
+				    "color-group", cg,
+				    "color-default", def_sc->go_color,
+				    "show-underline", TRUE,
+				    "underline-picker", up,
+				    "show-script", TRUE,
+				    "show-strikethrough", TRUE,
+				    "vexpand", TRUE,
+				    "hexpand", TRUE,
+				    NULL);
+	g_object_unref (cg);
+	style_color_unref (def_sc);
+	state->font.selector = GO_FONT_SEL (font_widget);
+	g_object_unref (up);
 
-	/* TODO: How to insert the font box in the right place initially */
-	gtk_widget_show (tmp);
-	gtk_widget_set_vexpand (tmp, TRUE);
-	gtk_widget_set_hexpand (tmp, TRUE);
-	gtk_grid_attach (GTK_GRID (container), tmp, 0, 0, 5, 1);
+	gtk_widget_show (font_widget);
+	gtk_container_add (GTK_CONTAINER (go_gtk_builder_get_widget (state->gui, "font_sel_placeholder")),
+			   font_widget);
 
-	font_selector_editable_enters (font_widget, GTK_WINDOW (state->dialog));
+	go_font_sel_editable_enters (state->font.selector,
+				     GTK_WINDOW (state->dialog));
 
-	state->font.selector = FONT_SELECTOR (font_widget);
+	if (state->value) {
+		char *s = format_value (NULL, state->value, -1, date_conv);
+		go_font_sel_set_sample_text (state->font.selector, s);
+		g_free (s);
+	}
 
-	font_selector_set_value (state->font.selector, state->value);
-
-	if (0 == (state->conflicts & (1 << MSTYLE_FONT_NAME)))
-		font_selector_set_name (state->font.selector,
-					gnm_style_get_font_name (state->style));
+	if (0 == (state->conflicts & (1 << MSTYLE_FONT_NAME))) {
+		const char *family = gnm_style_get_font_name (state->style);
+		go_font_sel_set_family (state->font.selector, family);
+	}
 
 	if (0 == (state->conflicts & (1 << MSTYLE_FONT_BOLD)) &&
-	    0 == (state->conflicts & (1 << MSTYLE_FONT_ITALIC)))
-		font_selector_set_style (state->font.selector,
-					 gnm_style_get_font_bold (state->style),
-					 gnm_style_get_font_italic (state->style));
-	if (0 == (state->conflicts & (1 << MSTYLE_FONT_SIZE)))
-		font_selector_set_points (state->font.selector,
-					  gnm_style_get_font_size (state->style));
+	    0 == (state->conflicts & (1 << MSTYLE_FONT_ITALIC))) {
+		gboolean is_bold = gnm_style_get_font_bold (state->style);
+		gboolean is_italic = gnm_style_get_font_italic (state->style);
+
+		go_font_sel_set_style
+			(state->font.selector,
+			 is_bold ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL,
+			 is_italic ? PANGO_STYLE_ITALIC : PANGO_STYLE_NORMAL);
+	}
+
+	if (0 == (state->conflicts & (1 << MSTYLE_FONT_SIZE))) {
+		double pts = gnm_style_get_font_size (state->style);
+		go_font_sel_set_size (state->font.selector,
+				      pts * PANGO_SCALE);
+	}
 
-	for (i = 0; i < (int)G_N_ELEMENTS (underline_types); i++)
-		gtk_combo_box_text_append_text
-			(GTK_COMBO_BOX_TEXT (uline),
-			 g_dpgettext2 (NULL, "underline",
-				       underline_types[i].Cname));
 	if (0 == (state->conflicts & (1 << MSTYLE_FONT_UNDERLINE))) {
 		GnmUnderline ut = gnm_style_get_font_uline (state->style);
-		uline_str = g_dpgettext2 (NULL, "underline", underline_types[ut].Cname);
-		font_selector_set_underline (state->font.selector, ut);
-	} else
-		uline_str = "";
-	gtk_entry_set_text (uline_entry, uline_str);
-	g_object_set (uline_entry,
-		      "editable", FALSE,
-		      "can-focus", FALSE,
-		      NULL);
-	g_signal_connect (G_OBJECT (uline),
-			  "changed",
-			  G_CALLBACK (cb_font_underline_changed), state);
-	gtk_widget_show_all (uline);
-	gtk_grid_attach (GTK_GRID (container), uline, 3, 2, 1, 1);
-
-	tmp = go_gtk_builder_get_widget (state->gui, "underline_label");
-	gtk_label_set_mnemonic_widget (GTK_LABEL (tmp), uline);
-
-	if (0 == (state->conflicts & (1 << MSTYLE_FONT_STRIKETHROUGH)))
-		strikethrough = gnm_style_get_font_strike (state->style);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (strike), strikethrough);
-	font_selector_set_strike (state->font.selector, strikethrough);
-	g_signal_connect (G_OBJECT (strike),
-			  "toggled",
-			  G_CALLBACK (cb_font_strike_toggle), state);
-
-	if (0 == (state->conflicts & (1 << MSTYLE_FONT_SCRIPT)))
-		script = gnm_style_get_font_script (state->style);
-	font_selector_set_script (state->font.selector, script);
-	if (NULL != (tmp = go_gtk_builder_get_widget (state->gui, "superscript_button"))) {
-		state->font.superscript = GTK_TOGGLE_BUTTON (tmp);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp),
-					      script == GO_FONT_SCRIPT_SUPER);
-		g_signal_connect (G_OBJECT (tmp), "toggled",
-				  G_CALLBACK (cb_font_script_toggle), state);
-	}
-	if (NULL != (tmp =  go_gtk_builder_get_widget (state->gui, "subscript_button"))) {
-		state->font.subscript = GTK_TOGGLE_BUTTON (tmp);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp),
-					      script == GO_FONT_SCRIPT_SUB);
-		g_signal_connect (G_OBJECT (tmp), "toggled",
-				  G_CALLBACK (cb_font_script_toggle), state);
+		set_font_underline (state, ut);
 	}
 
 	if (0 == (state->conflicts & (1 << MSTYLE_FONT_COLOR)))
-		font_selector_set_color (
-			state->font.selector,
-			style_color_ref (gnm_style_get_font_color (state->style)));
+		mcolor = gnm_style_get_font_color (state->style);
+	go_font_sel_set_color (state->font.selector,
+			       mcolor ? mcolor->go_color : GO_COLOR_BLACK,
+			       !mcolor || mcolor->is_auto);
 
-	g_signal_connect (G_OBJECT (font_widget),
+	if (0 == (state->conflicts & (1 << MSTYLE_FONT_STRIKETHROUGH)))
+		strikethrough = gnm_style_get_font_strike (state->style);
+	go_font_sel_set_strikethrough (state->font.selector, strikethrough);
+
+	if (0 == (state->conflicts & (1 << MSTYLE_FONT_SCRIPT)))
+		script = gnm_style_get_font_script (state->style);
+	go_font_sel_set_script (state->font.selector, script);
+
+	if (0 == (state->conflicts & (1 << MSTYLE_FONT_COLOR)))
+		change_font_attr
+			(state,
+			 go_color_to_pango (gnm_style_get_font_color (state->style)->go_color,
+					    TRUE));
+
+	g_signal_connect (G_OBJECT (state->font.selector),
 			  "font_changed",
 			  G_CALLBACK (cb_font_changed), state);
 }
@@ -997,9 +1039,9 @@ fmt_dialog_init_background_page (FormatState *state)
 			   GTK_WIDGET (state->back.canvas));
 	gtk_widget_show_all (widget);
 
-	state->back.grid = PREVIEW_GRID (goc_item_new (
+	state->back.grid = GNM_PREVIEW_GRID (goc_item_new (
 						 goc_canvas_get_root (state->back.canvas),
-						 preview_grid_get_type (),
+						 gnm_preview_grid_get_type (),
 						 "render-gridlines",	FALSE,
 						 "default-col-width",	w,
 						 "default-row-height",	h,
@@ -1278,8 +1320,8 @@ draw_border_preview (FormatState *state)
 		gtk_widget_show (GTK_WIDGET (state->border.canvas));
 		gtk_widget_set_size_request (GTK_WIDGET (state->border.canvas),
 					     150, 100);
-		gtk_grid_attach (GTK_GRID (go_gtk_builder_get_widget (state->gui, "border-sample-container")),
-				   GTK_WIDGET (state->border.canvas), 1, 1, 3, 3);
+		go_gtk_widget_replace (go_gtk_builder_get_widget (state->gui, "border_sample_placeholder"),
+				 GTK_WIDGET (state->border.canvas));
 		group = GOC_GROUP (goc_canvas_get_root (state->border.canvas));
 
 		g_signal_connect (G_OBJECT (state->border.canvas),
@@ -2281,19 +2323,15 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 				      default_border_style, 54);
 
 	setup_color_pickers (state, &state->border.color,	"border_color_group",
-			     "border-grid", 2, 3,		"border_color_label",
+			     "border_color_placeholder",	"border_color_label",
 			     _("Automatic"),			_("Border"),
 			     G_CALLBACK (cb_border_color),	MSTYLE_BORDER_TOP, FALSE);
-	setup_color_pickers (state, NULL,			"fore_color_group",
-			     "font-grid", 1, 2,		"font_color_label",
-			     _("Automatic"),			_("Foreground"),
-			     G_CALLBACK (cb_font_preview_color), MSTYLE_FONT_COLOR, TRUE);
 	setup_color_pickers (state, &state->back.back_color,	"back_color_group",
-			     "background-grid",	1, 1,		"back_color_label",
+			     "background_color_placeholder",	"back_color_label",
 			     _("Clear Background"),		_("Background"),
 			     G_CALLBACK (cb_back_preview_color), MSTYLE_COLOR_BACK, FALSE);
 	setup_color_pickers (state, &state->back.pattern_color, "pattern_color_group",
-			     "background-grid", 1, 3,		"pattern_color_label",
+			     "pattern_color_placeholder",	"pattern_color_label",
 			     _("Automatic"),			_("Pattern"),
 			     G_CALLBACK (cb_pattern_preview_color), MSTYLE_COLOR_PATTERN, FALSE);
 
