@@ -7,7 +7,7 @@
  *     Jody Goldberg (jody@gnome.org)
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n-lib.h>
+#include <gnm-i18n.h>
 #include "gnumeric.h"
 #include "gnm-pane-impl.h"
 #include "gnm-pane.h"
@@ -656,19 +656,9 @@ gnm_pane_focus_out (GtkWidget *widget, GdkEventFocus *event)
 static void
 gnm_pane_realize (GtkWidget *w)
 {
-	GtkStyleContext *ctxt;
-	GdkRGBA rgba;
-
 	if (GTK_WIDGET_CLASS (parent_klass)->realize)
 		(*GTK_WIDGET_CLASS (parent_klass)->realize) (w);
 
-	/* Set the default background color of the canvas itself to white.
-	 * This makes the redraws when the canvas scrolls flicker less. */
-	ctxt = gtk_widget_get_style_context (w);
-	gtk_style_context_get_background_color (ctxt, GTK_STATE_FLAG_SELECTED, &rgba);
-	gtk_widget_override_background_color (w, GTK_STATE_FLAG_NORMAL, &gs_white);
-	gtk_widget_override_background_color (w, GTK_STATE_FLAG_SELECTED, &rgba);
-
 	gtk_im_context_set_client_window
 		(GNM_PANE (w)->im_context,
 		 gtk_widget_get_window (gtk_widget_get_toplevel (w)));
@@ -839,8 +829,8 @@ cb_ctrl_pts_free (GocItem **ctrl_pts)
 {
 	int i = 10;
 	while (i-- > 0)
-		if (ctrl_pts [i] != NULL)
-			g_object_unref (ctrl_pts [i]);
+		if (ctrl_pts[i] != NULL)
+			g_object_unref (ctrl_pts[i]);
 	g_free (ctrl_pts);
 }
 
@@ -884,10 +874,7 @@ gnm_pane_dispose (GObject *obj)
 	g_slist_free_full (pane->cursor.expr_range, g_object_unref);
 	pane->cursor.expr_range = NULL;
 
-	if (pane->mouse_cursor) {
-		g_object_unref (pane->mouse_cursor);
-		pane->mouse_cursor = NULL;
-	}
+	g_clear_object (&pane->mouse_cursor);
 	gnm_pane_clear_obj_size_tip (pane);
 
 	if (pane->drag.ctrl_pts) {
@@ -932,7 +919,7 @@ gnm_pane_init (GnmPane *pane)
 
 	pane->slide_handler = NULL;
 	pane->slide_data = NULL;
-	pane->sliding = -1;
+	pane->sliding_timer = 0;
 	pane->sliding_x  = pane->sliding_dx = -1;
 	pane->sliding_y  = pane->sliding_dy = -1;
 	pane->sliding_adjacent_h = pane->sliding_adjacent_v = FALSE;
@@ -982,6 +969,66 @@ gnm_pane_class_init (GnmPaneClass *klass)
 	widget_class->key_release_event	   = gnm_pane_key_release;
 	widget_class->focus_in_event	   = gnm_pane_focus_in;
 	widget_class->focus_out_event	   = gnm_pane_focus_out;
+
+	gtk_widget_class_install_style_property
+		(widget_class,
+		 g_param_spec_int ("function-indicator-size",
+				   P_("Function Indicator Size"),
+				   P_("Size of function indicator"),
+				   0,
+				   G_MAXINT,
+				   10,
+				   G_PARAM_READABLE));
+
+	gtk_widget_class_install_style_property
+		(widget_class,
+		 g_param_spec_int ("comment-indicator-size",
+				   P_("comment Indicator Size"),
+				   P_("Size of comment indicator"),
+				   0,
+				   G_MAXINT,
+				   6,
+				   G_PARAM_READABLE));
+
+	gtk_widget_class_install_style_property
+		(widget_class,
+		 g_param_spec_int ("resize-guide-width",
+				   P_("Resize Guide Width"),
+				   P_("With of the guides used for resizing columns and rows"),
+				   0,
+				   G_MAXINT,
+				   1,
+				   G_PARAM_READABLE));
+
+	gtk_widget_class_install_style_property
+		(widget_class,
+		 g_param_spec_int ("pane-resize-guide-width",
+				   P_("Pane Resize Guide Width"),
+				   P_("With of the guides used for resizing panes"),
+				   0,
+				   G_MAXINT,
+				   7,
+				   G_PARAM_READABLE));
+
+	gtk_widget_class_install_style_property
+		(widget_class,
+		 g_param_spec_int ("control-circle-size",
+				   P_("Control Circle Size"),
+				   P_("Size of control circle for sizing sheet objects"),
+				   0,
+				   G_MAXINT,
+				   4,
+				   G_PARAM_READABLE));
+
+	gtk_widget_class_install_style_property
+		(widget_class,
+		 g_param_spec_int ("control-circle-outline",
+				   P_("Control Circle Outline"),
+				   P_("Width of outline of control circle for sizing sheet objects"),
+				   0,
+				   G_MAXINT,
+				   1,
+				   G_PARAM_READABLE));
 }
 
 GSF_CLASS (GnmPane, gnm_pane,
@@ -996,7 +1043,7 @@ gnm_pane_header_init (GnmPane *pane, SheetControlGUI *scg,
 	GocCanvas *canvas = gnm_simple_canvas_new (scg);
 	GocGroup *group = goc_canvas_get_root (canvas);
 	GocItem *item = goc_item_new (group,
-		item_bar_get_type (),
+		gnm_item_bar_get_type (),
 		"pane",	pane,
 		"IsColHeader", is_col_header,
 		NULL);
@@ -1007,10 +1054,10 @@ gnm_pane_header_init (GnmPane *pane, SheetControlGUI *scg,
 		if (sheet && sheet->text_is_rtl)
 			goc_canvas_set_direction (canvas, GOC_DIRECTION_RTL);
 		pane->col.canvas = canvas;
-		pane->col.item = ITEM_BAR (item);
+		pane->col.item = GNM_ITEM_BAR (item);
 	} else {
 		pane->row.canvas = canvas;
-		pane->row.item = ITEM_BAR (item);
+		pane->row.item = GNM_ITEM_BAR (item);
 	}
 
 	pane->size_guide.points = NULL;
@@ -1181,16 +1228,16 @@ gnm_pane_new (SheetControlGUI *scg,
 	gnm_pane_drag_dest_init (pane, scg);
 
 	item = goc_item_new (pane->grid_items,
-		item_grid_get_type (),
+		gnm_item_grid_get_type (),
 		"SheetControlGUI", scg,
 		NULL);
-	pane->grid = ITEM_GRID (item);
+	pane->grid = GNM_ITEM_GRID (item);
 
 	item = goc_item_new (pane->grid_items,
-		item_cursor_get_type (),
+		gnm_item_cursor_get_type (),
 		"SheetControlGUI", scg,
 		NULL);
-	pane->cursor.std = ITEM_CURSOR (item);
+	pane->cursor.std = GNM_ITEM_CURSOR (item);
 	if (col_headers)
 		gnm_pane_header_init (pane, scg, TRUE);
 	else
@@ -1311,7 +1358,7 @@ gnm_pane_find_row (GnmPane const *pane, gint64 y, gint64 *row_origin)
  * gnm_pane_compute_visible_region : Keeps the top left col/row the same and
  *     recalculates the visible boundaries.
  *
- * @full_recompute :
+ * @full_recompute:
  *       if TRUE recompute the pixel offsets of the top left row/col
  *       else assumes that the pixel offsets of the top left have not changed.
  */
@@ -1478,13 +1525,13 @@ gnm_pane_redraw_range (GnmPane *pane, GnmRange const *r)
 void
 gnm_pane_slide_stop (GnmPane *pane)
 {
-	if (pane->sliding == -1)
+	if (pane->sliding_timer == 0)
 		return;
 
-	g_source_remove (pane->sliding);
+	g_source_remove (pane->sliding_timer);
 	pane->slide_handler = NULL;
 	pane->slide_data = NULL;
-	pane->sliding = -1;
+	pane->sliding_timer = 0;
 }
 
 static int
@@ -1669,9 +1716,8 @@ cb_pane_sliding (GnmPane *pane)
 
 	if (!slide_x && !slide_y)
 		gnm_pane_slide_stop (pane);
-	else if (pane->sliding == -1)
-		pane->sliding = g_timeout_add (
-					       300, (GSourceFunc) cb_pane_sliding, pane);
+	else if (pane->sliding_timer == 0)
+		pane->sliding_timer = g_timeout_add (300, (GSourceFunc)cb_pane_sliding, pane);
 
 	return TRUE;
 }
@@ -1805,12 +1851,12 @@ gnm_pane_handle_motion (GnmPane *pane,
 	pane->slide_handler = slide_handler;
 	pane->slide_data = user_data;
 
-	if (pane->sliding == -1)
+	if (pane->sliding_timer == 0)
 		cb_pane_sliding (pane);
 	return FALSE;
 }
 
-/* TODO : All the slide_* members of GnmPane really aught to be in
+/* TODO : All the slide_* members of GnmPane really ought to be in
  * SheetControlGUI, most of these routines also belong there.  However, since
  * the primary point of access is via GnmPane and SCG is very large
  * already I'm leaving them here for now.  Move them when we return to
@@ -1922,7 +1968,7 @@ gnm_pane_object_autoscroll (GnmPane *pane, GdkDragContext *context,
 	pane->slide_data    = NULL;
 	pane->sliding_x     = x;
 	pane->sliding_y     = y;
-	if (pane->sliding == -1)
+	if (pane->sliding_timer == 0)
 		cb_pane_sliding (pane);
 }
 
@@ -1930,7 +1976,7 @@ gnm_pane_object_autoscroll (GnmPane *pane, GdkDragContext *context,
  * gnm_pane_object_group:
  * @pane: #GnmPane
  *
- * Returns: (transfer none): the #GocGroup including all #ShetObjectiew
+ * Returns: (transfer none): the #GocGroup including all #SheetObjectView
  * instances in @pane.
  **/
 GocGroup *
@@ -2014,12 +2060,19 @@ gnm_pane_bound_set (GnmPane *pane,
 /****************************************************************************/
 
 void
-gnm_pane_size_guide_start (GnmPane *pane, gboolean vert, int colrow, int width)
+gnm_pane_size_guide_start (GnmPane *pane,
+			   gboolean vert, int colrow, gboolean is_colrow_resize)
 {
 	SheetControlGUI const *scg;
-	double x0, y0, x1, y1;
+	double x0, y0, x1, y1, pos;
 	double zoom;
 	GOStyle *style;
+	GdkRGBA rgba;
+	GtkStyleContext *context;
+	const char *guide_class = is_colrow_resize ? "resize-guide" : "pane-resize-guide";
+	const char *colrow_class = vert ? "col" : "row";
+	const char *width_prop_name = is_colrow_resize ? "resize-guide-width" : "pane-resize-guide-width";
+	int width;
 
 	g_return_if_fail (pane != NULL);
 	g_return_if_fail (pane->size_guide.guide  == NULL);
@@ -2029,26 +2082,25 @@ gnm_pane_size_guide_start (GnmPane *pane, gboolean vert, int colrow, int width)
 	zoom = GOC_CANVAS (pane)->pixels_per_unit;
 	scg = pane->simple.scg;
 
+	pos = scg_colrow_distance_get (scg, vert, 0, colrow) / zoom;
 	if (vert) {
-		double x = (scg_colrow_distance_get (scg, TRUE,
-					0, colrow) - .5) / zoom;
-		x0 = x;
+		x0 = pos;
 		y0 = scg_colrow_distance_get (scg, FALSE,
-					0, pane->first.row) / zoom;
-		x1= x;
+					      0, pane->first.row) / zoom;
+		x1 = pos;
 		y1 = scg_colrow_distance_get (scg, FALSE,
-					0, pane->last_visible.row+1) / zoom;
+					      0, pane->last_visible.row+1) / zoom;
 	} else {
-		double const y = (scg_colrow_distance_get (scg, FALSE,
-					0, colrow) - .5) / zoom;
 		x0 = scg_colrow_distance_get (scg, TRUE,
-					0, pane->first.col) / zoom;
-		y0 = y;
+					      0, pane->first.col) / zoom;
+		y0 = pos;
 		x1 = scg_colrow_distance_get (scg, TRUE,
-					0, pane->last_visible.col+1) / zoom;
-		y1 = y;
+					      0, pane->last_visible.col+1) / zoom;
+		y1 = pos;
 	}
 
+	gtk_widget_style_get (GTK_WIDGET (pane), width_prop_name, &width, NULL);
+
 	/* Guideline positioning is done in gnm_pane_size_guide_motion */
 	pane->size_guide.guide = goc_item_new (pane->action_items,
 		GOC_TYPE_LINE,
@@ -2057,23 +2109,28 @@ gnm_pane_size_guide_start (GnmPane *pane, gboolean vert, int colrow, int width)
 		NULL);
 	style = go_styled_object_get_style (GO_STYLED_OBJECT (pane->size_guide.guide));
 	style->line.width = width;
+	context = goc_item_get_style_context (pane->size_guide.guide);
+	gtk_style_context_add_class (context, guide_class);
+	gtk_style_context_add_class (context, colrow_class);
+	if (is_colrow_resize)
+		gtk_style_context_add_class (context, "end");
+	gtk_style_context_get_color (context, GTK_STATE_FLAG_SELECTED, &rgba);
+	go_color_from_gdk_rgba (&rgba, &style->line.color);
 
-	/* cheat for now and differentiate between col/row resize and frozen panes
-	 * using the width.  Frozen pane guides do not require a start line */
-	if (width == 1) {
-		style->line.color = GO_COLOR_BLACK;
+	if (is_colrow_resize) {
 		pane->size_guide.start = goc_item_new (pane->action_items,
 			GOC_TYPE_LINE,
 			"x0", x0, "y0", y0,
 			"x1", x1, "y1", y1,
 			NULL);
 		style = go_styled_object_get_style (GO_STYLED_OBJECT (pane->size_guide.start));
-		style->line.color = GO_COLOR_BLACK;
+		context = goc_item_get_style_context (pane->size_guide.start);
+		gtk_style_context_add_class (context, guide_class);
+		gtk_style_context_add_class (context, colrow_class);
+		gtk_style_context_add_class (context, "start");
+		gtk_style_context_get_color (context, GTK_STATE_FLAG_SELECTED, &rgba);
+		go_color_from_gdk_rgba (&rgba, &style->line.color);
 		style->line.width = width;
-	} else {
-		style->line.pattern = GO_PATTERN_GREY25;
-		style->line.color = GO_COLOR_WHITE;
-		style->line.fore = GO_COLOR_BLACK;
 	}
 }
 
@@ -2082,14 +2139,8 @@ gnm_pane_size_guide_stop (GnmPane *pane)
 {
 	g_return_if_fail (pane != NULL);
 
-	if (pane->size_guide.start != NULL) {
-		g_object_unref (pane->size_guide.start);
-		pane->size_guide.start = NULL;
-	}
-	if (pane->size_guide.guide != NULL) {
-		g_object_unref (pane->size_guide.guide);
-		pane->size_guide.guide = NULL;
-	}
+	g_clear_object (&pane->size_guide.start);
+	g_clear_object (&pane->size_guide.guide);
 }
 
 /**
@@ -2133,15 +2184,15 @@ gnm_pane_reposition_cursors (GnmPane *pane)
 {
 	GSList *l;
 
-	item_cursor_reposition (pane->cursor.std);
+	gnm_item_cursor_reposition (pane->cursor.std);
 	if (NULL != pane->cursor.rangesel)
-		item_cursor_reposition (pane->cursor.rangesel);
+		gnm_item_cursor_reposition (pane->cursor.rangesel);
 	if (NULL != pane->cursor.special)
-		item_cursor_reposition (pane->cursor.special);
+		gnm_item_cursor_reposition (pane->cursor.special);
 	for (l = pane->cursor.expr_range; l; l = l->next)
-		item_cursor_reposition (ITEM_CURSOR (l->data));
+		gnm_item_cursor_reposition (GNM_ITEM_CURSOR (l->data));
 	for (l = pane->cursor.animated; l; l = l->next)
-		item_cursor_reposition (ITEM_CURSOR (l->data));
+		gnm_item_cursor_reposition (GNM_ITEM_CURSOR (l->data));
 
 	/* ctrl pts do not scale with the zoom, compensate */
 	if (pane->drag.ctrl_pts != NULL)
@@ -2152,7 +2203,7 @@ gnm_pane_reposition_cursors (GnmPane *pane)
 gboolean
 gnm_pane_cursor_bound_set (GnmPane *pane, GnmRange const *r)
 {
-	return item_cursor_bound_set (pane->cursor.std, r);
+	return gnm_item_cursor_bound_set (pane->cursor.std, r);
 }
 
 /****************************************************************************/
@@ -2160,7 +2211,7 @@ gnm_pane_cursor_bound_set (GnmPane *pane, GnmRange const *r)
 gboolean
 gnm_pane_rangesel_bound_set (GnmPane *pane, GnmRange const *r)
 {
-	return item_cursor_bound_set (pane->cursor.rangesel, r);
+	return gnm_item_cursor_bound_set (pane->cursor.rangesel, r);
 }
 void
 gnm_pane_rangesel_start (GnmPane *pane, GnmRange const *r)
@@ -2173,25 +2224,25 @@ gnm_pane_rangesel_start (GnmPane *pane, GnmRange const *r)
 	/* Hide the primary cursor while the range selection cursor is visible
 	 * and we are selecting on a different sheet than the expr being edited */
 	if (scg_sheet (scg) != wb_control_cur_sheet (scg_wbc (scg)))
-		item_cursor_set_visibility (pane->cursor.std, FALSE);
+		gnm_item_cursor_set_visibility (pane->cursor.std, FALSE);
 	item = goc_item_new (pane->grid_items,
-		item_cursor_get_type (),
+		gnm_item_cursor_get_type (),
 		"SheetControlGUI", scg,
-		"style",	ITEM_CURSOR_ANTED,
+		"style",	GNM_ITEM_CURSOR_ANTED,
 		NULL);
-	pane->cursor.rangesel = ITEM_CURSOR (item);
-	item_cursor_bound_set (pane->cursor.rangesel, r);
+	pane->cursor.rangesel = GNM_ITEM_CURSOR (item);
+	gnm_item_cursor_bound_set (pane->cursor.rangesel, r);
 }
 
 void
 gnm_pane_rangesel_stop (GnmPane *pane)
 {
 	g_return_if_fail (pane->cursor.rangesel != NULL);
-	g_object_unref (pane->cursor.rangesel);
-	pane->cursor.rangesel = NULL;
+
+	g_clear_object (&pane->cursor.rangesel);
 
 	/* Make the primary cursor visible again */
-	item_cursor_set_visibility (pane->cursor.std, TRUE);
+	gnm_item_cursor_set_visibility (pane->cursor.std, TRUE);
 
 	gnm_pane_slide_stop (pane);
 }
@@ -2201,7 +2252,7 @@ gnm_pane_rangesel_stop (GnmPane *pane)
 gboolean
 gnm_pane_special_cursor_bound_set (GnmPane *pane, GnmRange const *r)
 {
-	return item_cursor_bound_set (pane->cursor.special, r);
+	return gnm_item_cursor_bound_set (pane->cursor.special, r);
 }
 
 void
@@ -2213,12 +2264,12 @@ gnm_pane_special_cursor_start (GnmPane *pane, int style, int button)
 	g_return_if_fail (pane->cursor.special == NULL);
 	item = goc_item_new (
 		GOC_GROUP (canvas->root),
-		item_cursor_get_type (),
+		gnm_item_cursor_get_type (),
 		"SheetControlGUI", pane->simple.scg,
 		"style",	   style,
 		"button",	   button,
 		NULL);
-	pane->cursor.special = ITEM_CURSOR (item);
+	pane->cursor.special = GNM_ITEM_CURSOR (item);
 }
 
 void
@@ -2226,8 +2277,7 @@ gnm_pane_special_cursor_stop (GnmPane *pane)
 {
 	g_return_if_fail (pane->cursor.special != NULL);
 
-	g_object_unref (pane->cursor.special);
-	pane->cursor.special = NULL;
+	g_clear_object (&pane->cursor.special);
 }
 
 void
@@ -2244,19 +2294,19 @@ gnm_pane_mouse_cursor_set (GnmPane *pane, GdkCursor *c)
 
 void
 gnm_pane_expr_cursor_bound_set (GnmPane *pane, GnmRange const *r,
-				gchar const *color)
+				GOColor color)
 {
-	ItemCursor *cursor;
+	GnmItemCursor *cursor;
 
-	cursor = (ItemCursor *) goc_item_new
+	cursor = (GnmItemCursor *) goc_item_new
 		(GOC_GROUP (GOC_CANVAS (pane)->root),
-		 item_cursor_get_type (),
+		 gnm_item_cursor_get_type (),
 		 "SheetControlGUI",	pane->simple.scg,
-		 "style",		ITEM_CURSOR_EXPR_RANGE,
+		 "style",		GNM_ITEM_CURSOR_EXPR_RANGE,
 		 "color",		color,
 		 NULL);
 
-	item_cursor_bound_set (cursor, r);
+	gnm_item_cursor_bound_set (cursor, r);
 	pane->cursor.expr_range = g_slist_prepend
 		(pane->cursor.expr_range, cursor);
 }
@@ -2278,9 +2328,9 @@ gnm_pane_edit_start (GnmPane *pane)
 	g_return_if_fail (pane->editor == NULL);
 
 	/* edit item handles visibility checks */
-	pane->editor = (ItemEdit *) goc_item_new (
+	pane->editor = (GnmItemEdit *) goc_item_new (
 		GOC_GROUP (canvas->root),
-		item_edit_get_type (),
+		gnm_item_edit_get_type (),
 		"SheetControlGUI",	pane->simple.scg,
 		NULL);
 }
@@ -2288,10 +2338,7 @@ gnm_pane_edit_start (GnmPane *pane)
 void
 gnm_pane_edit_stop (GnmPane *pane)
 {
-	if (pane->editor != NULL) {
-		g_object_unref (pane->editor);
-		pane->editor = NULL;
-	}
+	g_clear_object (&pane->editor);
 }
 
 void
@@ -2310,11 +2357,6 @@ gnm_pane_objects_drag (GnmPane *pane, SheetObject *so,
 	pane->drag.last_y += dy;
 }
 
-#define CTRL_PT_SIZE		4
-#define CTRL_PT_OUTLINE		0
-/* space for 2 halves and a full */
-#define CTRL_PT_TOTAL_SIZE	(CTRL_PT_SIZE*4 + CTRL_PT_OUTLINE*2)
-
 /* new_x and new_y are in world coords */
 static void
 gnm_pane_object_move (GnmPane *pane, GObject *ctrl_pt,
@@ -2574,7 +2616,7 @@ gnm_pane_object_start_resize (GnmPane *pane, int button, guint64 x, gint64 y,
 					 NULL, NULL, NULL);
 		return;
 	}
-	gnm_simple_canvas_grab (ctrl_pts [drag_type],
+	gnm_simple_canvas_grab (ctrl_pts[drag_type],
 		GDK_POINTER_MOTION_MASK |
 		GDK_BUTTON_PRESS_MASK |
 		GDK_BUTTON_RELEASE_MASK,
@@ -2589,13 +2631,13 @@ gnm_pane_object_start_resize (GnmPane *pane, int button, guint64 x, gint64 y,
 }
 
 /*
- ControlCircleItem
+ GnmControlCircleItem
  */
-typedef GocCircle ControlCircle;
-typedef GocCircleClass ControlCircleClass;
+typedef GocCircle GnmControlCircle;
+typedef GocCircleClass GnmControlCircleClass;
 
 #define CONTROL_TYPE_CIRCLE	(control_circle_get_type ())
-#define CONTROL_CIRCLE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), CONTROL_TYPE_CIRCLE, ControlCircle))
+#define CONTROL_CIRCLE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), CONTROL_TYPE_CIRCLE, GnmControlCircle))
 #define CONTROL_IS_CIRCLE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), CONTROL_TYPE_CIRCLE))
 
 static GType control_circle_get_type (void);
@@ -2713,6 +2755,20 @@ control_point_button2_pressed (GocItem *item, int button, G_GNUC_UNUSED double x
 	return TRUE;
 }
 
+static void
+update_control_point_colors (GocItem *item, GtkStateFlags flags)
+{
+	GtkStyleContext *context = goc_item_get_style_context (item);
+	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (item));
+	GdkRGBA rgba;
+
+	gtk_style_context_get_color (context, flags, &rgba);
+	go_color_from_gdk_rgba (&rgba, &style->line.color);
+	gtk_style_context_get_background_color (context, flags, &rgba);
+	go_color_from_gdk_rgba (&rgba, &style->fill.pattern.back);
+	goc_item_invalidate (item);
+}
+
 static gboolean
 control_point_enter_notify (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
@@ -2725,9 +2781,7 @@ control_point_enter_notify (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED
 	pane->cur_object  = g_object_get_data (G_OBJECT (item), "so");
 	idx = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "index"));
 	if (idx != 8) {
-		GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (item));
-		style->fill.pattern.back = GO_COLOR_GREEN;
-		goc_item_invalidate (item);
+		update_control_point_colors (item, GTK_STATE_FLAG_PRELIGHT);
 		gnm_pane_display_obj_size_tip (pane, item);
 	}
 	return TRUE;
@@ -2744,16 +2798,16 @@ control_point_leave_notify (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED
 
 	idx = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "index"));
 	if (idx != 8) {
-		GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (item));
-		style->fill.pattern.back = GO_COLOR_WHITE;
-		goc_item_invalidate (item);
+		update_control_point_colors (item, GTK_STATE_FLAG_NORMAL);
 		gnm_pane_clear_obj_size_tip (pane);
 	}
 	pane->cur_object = NULL;
 	return TRUE;
 }
 
-static void control_circle_class_init (GocItemClass *item_klass) {
+static void
+control_circle_class_init (GocItemClass *item_klass)
+{
 	item_klass->button_pressed = control_point_button_pressed;
 	item_klass->button_released = control_point_button_released;
 	item_klass->motion = control_point_motion;
@@ -2762,7 +2816,7 @@ static void control_circle_class_init (GocItemClass *item_klass) {
 	item_klass->leave_notify = control_point_leave_notify;
 }
 
-static GSF_CLASS (ControlCircle, control_circle,
+static GSF_CLASS (GnmControlCircle, control_circle,
 		  control_circle_class_init, NULL,
 		  GOC_TYPE_CIRCLE)
 
@@ -2777,8 +2831,7 @@ typedef GocRectangle		ItemAcetate;
 typedef GocRectangleClass	ItemAcetateClass;
 
 static double
-item_acetate_distance (GocItem *item, double x, double y,
-		    GocItem **actual_item)
+item_acetate_distance (GocItem *item, double x, double y, GocItem **actual_item)
 {
 	if (x < (item->x0 - MARGIN) ||
 	    x > (item->x1 + MARGIN) ||
@@ -2827,22 +2880,34 @@ static GSF_CLASS (ItemAcetate, item_acetate,
  *         objects
  **/
 static GocItem *
-new_control_point (GnmPane *pane, SheetObject *so, int idx, double x, double y, double radius)
+new_control_point (GnmPane *pane, SheetObject *so, int idx, double x, double y)
 {
-	GOStyle *style = go_style_new ();
+	GOStyle *style;
 	GocItem *item;
+	int radius, outline;
+	double scale = GOC_CANVAS (pane)->pixels_per_unit;
 
-	style->line.width = CTRL_PT_OUTLINE;
+	gtk_widget_style_get (GTK_WIDGET (pane),
+			      "control-circle-size", &radius,
+			      "control-circle-outline", &outline,
+			      NULL);
+
+	style = go_style_new ();
+	style->line.width = outline;
+	style->line.auto_color = FALSE;
+	style->line.dash_type = GO_LINE_SOLID; /* anything but 0 */
+	style->line.pattern = GO_PATTERN_SOLID;
 	item = goc_item_new (
 		pane->action_items,
 		CONTROL_TYPE_CIRCLE,
 		"x", x,
 		"y", y,
-		"radius", radius,
-		"style", style,
+		"radius", radius / scale,
 		NULL);
-
 	g_object_unref (style);
+
+	update_control_point_colors (item, GTK_STATE_FLAG_NORMAL);
+
 	g_object_set_data (G_OBJECT (item), "index",  GINT_TO_POINTER (idx));
 	g_object_set_data (G_OBJECT (item), "so",  so);
 
@@ -2859,15 +2924,14 @@ set_item_x_y (GnmPane *pane, SheetObject *so, GocItem **ctrl_pts,
 	      int idx, double x, double y, gboolean visible)
 {
 	double scale = GOC_CANVAS (pane)->pixels_per_unit;
-	if (ctrl_pts [idx] == NULL)
-		ctrl_pts [idx] = new_control_point (pane, so, idx, x / scale, y / scale, CTRL_PT_SIZE / scale);
+	if (ctrl_pts[idx] == NULL)
+		ctrl_pts[idx] = new_control_point (pane, so, idx, x / scale, y / scale);
 	else
-		goc_item_set (ctrl_pts [idx], "x", x / scale, "y", y / scale,
-		              "radius", CTRL_PT_SIZE / scale, NULL);
+		goc_item_set (ctrl_pts[idx], "x", x / scale, "y", y / scale, NULL);
 	if (visible)
-		goc_item_show (ctrl_pts [idx]);
+		goc_item_show (ctrl_pts[idx]);
 	else
-		goc_item_hide (ctrl_pts [idx]);
+		goc_item_hide (ctrl_pts[idx]);
 }
 
 #define normalize_high_low(d1,d2) if (d1<d2) { double tmp=d1; d1=d2; d2=tmp;}
@@ -2877,30 +2941,42 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, GocItem **ctrl_pts,
 		    double l, double t, double r, double b)
 {
 	double scale = goc_canvas_get_pixels_per_unit (GOC_CANVAS (pane));
+	int radius, outline;
+
 	if (!sheet_object_rubber_band_directly (so)) {
-		if (NULL == ctrl_pts [9]) {
+		if (NULL == ctrl_pts[9]) {
 			GOStyle *style = go_style_new ();
+			GtkStyleContext *context;
+			GdkRGBA rgba;
+			GocItem *item;
+
+			ctrl_pts[9] = item = goc_item_new (pane->action_items,
+				GOC_TYPE_RECTANGLE,
+				NULL);
+			context = goc_item_get_style_context (item);
+			gtk_style_context_add_class (context, "object-size");
+			gtk_style_context_add_class (context, "rubber-band");
+
 			style->fill.auto_type = FALSE;
 			style->fill.type  = GO_STYLE_FILL_PATTERN;
 			style->fill.auto_back = FALSE;
 			style->fill.pattern.back = 0;
 			style->fill.auto_fore = FALSE;
 			style->fill.pattern.fore = 0;
-			style->line.pattern = GO_PATTERN_THIN_DIAG;
+			style->line.pattern = GO_PATTERN_FOREGROUND_SOLID;
 			style->line.width = 0.;
 			style->line.auto_color = FALSE;
 			style->line.color = 0;
-			style->line.fore = GO_COLOR_BLACK;
-			ctrl_pts [9] = goc_item_new (pane->action_items,
-				GOC_TYPE_RECTANGLE,
-				"style", style,
-				NULL);
+			gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &rgba);
+			go_color_from_gdk_rgba (&rgba, &style->line.fore);
+			go_styled_object_set_style (GO_STYLED_OBJECT (item),
+						    style);
 			g_object_unref (style);
-			goc_item_lower_to_bottom (ctrl_pts [9]);
+			goc_item_lower_to_bottom (item);
 		}
 		normalize_high_low (r, l);
 		normalize_high_low (b, t);
-		goc_item_set (ctrl_pts [9],
+		goc_item_set (ctrl_pts[9],
 		       "x", l / scale, "y", t / scale,
 		       "width", (r - l) / scale, "height", (b - t) / scale,
 		       NULL);
@@ -2917,12 +2993,17 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, GocItem **ctrl_pts,
 		normalize_high_low (b, t);
 	}
 
-	l -= (CTRL_PT_SIZE + CTRL_PT_OUTLINE) / 2 - 1;
-	r += (CTRL_PT_SIZE + CTRL_PT_OUTLINE) / 2;
-	t -= (CTRL_PT_SIZE + CTRL_PT_OUTLINE) / 2 - 1;
-	b += (CTRL_PT_SIZE + CTRL_PT_OUTLINE) / 2;
+	gtk_widget_style_get (GTK_WIDGET (pane),
+			      "control-circle-size", &radius,
+			      "control-circle-outline", &outline,
+			      NULL);
 
-	if (NULL == ctrl_pts [8]) {
+	l -= (radius + outline) / 2 - 1;
+	r += (radius + outline) / 2;
+	t -= (radius + outline) / 2 - 1;
+	b += (radius + outline) / 2;
+
+	if (NULL == ctrl_pts[8]) {
 		GOStyle *style = go_style_new ();
 		GocItem *item;
 
@@ -2946,9 +3027,9 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, GocItem **ctrl_pts,
 			GINT_TO_POINTER (8));
 		g_object_set_data (G_OBJECT (item), "so", so);
 
-		ctrl_pts [8] = item;
+		ctrl_pts[8] = item;
 	}
-	goc_item_set (ctrl_pts [8],
+	goc_item_set (ctrl_pts[8],
 	       "x", l / scale,
 	       "y", t / scale,
 	       "width", (r - l) / scale,
@@ -2977,6 +3058,7 @@ gnm_pane_object_update_bbox (GnmPane *pane, SheetObject *so)
 	GocItem **ctrl_pts = g_hash_table_lookup (pane->drag.ctrl_pts, so);
 	double const *pts = g_hash_table_lookup (
 		pane->simple.scg->selected_objects, so);
+	int radius, outline, total_size;
 
 	if (ctrl_pts == NULL) {
 		ctrl_pts = g_new0 (GocItem *, 10);
@@ -2985,20 +3067,27 @@ gnm_pane_object_update_bbox (GnmPane *pane, SheetObject *so)
 
 	g_return_if_fail (ctrl_pts != NULL);
 
+	gtk_widget_style_get (GTK_WIDGET (pane),
+			      "control-circle-size", &radius,
+			      "control-circle-outline", &outline,
+			      NULL);
+	/* space for 2 halves and a full */
+	total_size = radius * 4 + outline * 2;
+
 	/* set the acetate 1st so that the other points will override it */
 	set_acetate_coords (pane, so, ctrl_pts, pts[0], pts[1], pts[2], pts[3]);
 	if (sheet_object_can_resize (so)) {
 		set_item_x_y (pane, so, ctrl_pts, 0, pts[0], pts[1], TRUE);
 		set_item_x_y (pane, so, ctrl_pts, 1, (pts[0] + pts[2]) / 2, pts[1],
-			      fabs (pts[2]-pts[0]) >= CTRL_PT_TOTAL_SIZE);
+			      fabs (pts[2]-pts[0]) >= total_size);
 		set_item_x_y (pane, so, ctrl_pts, 2, pts[2], pts[1], TRUE);
 		set_item_x_y (pane, so, ctrl_pts, 3, pts[0], (pts[1] + pts[3]) / 2,
-			      fabs (pts[3]-pts[1]) >= CTRL_PT_TOTAL_SIZE);
+			      fabs (pts[3]-pts[1]) >= total_size);
 		set_item_x_y (pane, so, ctrl_pts, 4, pts[2], (pts[1] + pts[3]) / 2,
-			      fabs (pts[3]-pts[1]) >= CTRL_PT_TOTAL_SIZE);
+			      fabs (pts[3]-pts[1]) >= total_size);
 		set_item_x_y (pane, so, ctrl_pts, 5, pts[0], pts[3], TRUE);
 		set_item_x_y (pane, so, ctrl_pts, 6, (pts[0] + pts[2]) / 2, pts[3],
-			      fabs (pts[2]-pts[0]) >= CTRL_PT_TOTAL_SIZE);
+			      fabs (pts[2]-pts[0]) >= total_size);
 		set_item_x_y (pane, so, ctrl_pts, 7, pts[2], pts[3], TRUE);
 	}
 }
