@@ -31,14 +31,12 @@
 
 #include <string.h>
 
-struct _ItemBar {
+struct _GnmItemBar {
 	GocItem	 base;
 
 	GnmPane		*pane;
 	GdkCursor       *normal_cursor;
 	GdkCursor       *change_cursor;
-	PangoFont	*normal_font, *bold_font;
-	int             normal_font_ascent, bold_font_ascent;
 	GtkWidget       *tip;			/* Tip for scrolling */
 	gboolean	 dragging;
 	gboolean	 is_col_header;
@@ -53,20 +51,30 @@ struct _ItemBar {
 		PangoItem	 *item;
 		PangoGlyphString *glyphs;
 	} pango;
+
+	/* Style: */
+
+	/* [ColRowSelectionType] */
+	GdkRGBA selection_colors[3];
+	PangoFont *selection_fonts[3];
+	int selection_font_ascents[3];      
+	PangoRectangle selection_logical_sizes[3];
+	GtkBorder padding;
 };
 
-typedef GocItemClass ItemBarClass;
+typedef GocItemClass GnmItemBarClass;
 static GocItemClass *parent_class;
 
 enum {
-	ITEM_BAR_PROP_0,
-	ITEM_BAR_PROP_PANE,
-	ITEM_BAR_PROP_IS_COL_HEADER
+	GNM_ITEM_BAR_PROP_0,
+	GNM_ITEM_BAR_PROP_PANE,
+	GNM_ITEM_BAR_PROP_IS_COL_HEADER
 };
 
 static int
-ib_compute_pixels_from_indent (Sheet const *sheet, gboolean const is_cols)
+ib_compute_pixels_from_indent (GnmItemBar *ib, Sheet const *sheet)
 {
+	gboolean is_cols = ib->is_col_header;
 	double const scale =
 		sheet->last_zoom_factor_used *
 		gnm_app_display_dpi_get (is_cols) / 72.;
@@ -75,127 +83,158 @@ ib_compute_pixels_from_indent (Sheet const *sheet, gboolean const is_cols)
 		: sheet->rows.max_outline_level;
 	if (!sheet->display_outlines || indent <= 0)
 		return 0;
-	return (int)(5 + (indent + 1) * 14 * scale + 0.5);
+	return (int)(ib->padding.left + (indent + 1) * 14 * scale + 0.5);
 }
 
 static void
-ib_fonts_unref (ItemBar *ib)
+ib_dispose_fonts (GnmItemBar *ib)
 {
-	if (ib->normal_font != NULL) {
-		g_object_unref (ib->normal_font);
-		ib->normal_font = NULL;
+	unsigned ui;
+
+	for (ui = 0; ui < G_N_ELEMENTS (ib->selection_fonts); ui++)
+		g_clear_object (&ib->selection_fonts[ui]);
+}
+
+static const GtkStateFlags selection_type_flags[3] = {
+	GTK_STATE_FLAG_NORMAL,
+	GTK_STATE_FLAG_PRELIGHT,
+	GTK_STATE_FLAG_ACTIVE
+};
+
+
+static void
+ib_reload_style (GnmItemBar *ib)
+{
+	GocItem *item = GOC_ITEM (ib);
+	SheetControlGUI	* const scg = ib->pane->simple.scg;
+	Sheet const *sheet = scg_sheet (scg);
+	double const zoom_factor = sheet->last_zoom_factor_used;
+	gboolean const char_label =
+		ib->is_col_header && !sheet->convs->r1c1_addresses;
+	GtkStyleContext *context = goc_item_get_style_context (item);
+	unsigned ui;
+	PangoContext *pcontext =
+		gtk_widget_get_pango_context (GTK_WIDGET (item->canvas));
+	PangoLayout *layout = pango_layout_new (pcontext);
+	PangoAttrList *attr_list;
+	GList *item_list;
+
+	gtk_style_context_save (context);
+	for (ui = 0; ui < G_N_ELEMENTS (selection_type_flags); ui++) {
+		GtkStateFlags state = selection_type_flags[ui];
+		PangoFontDescription *desc;
+		PangoRectangle ink_rect;
+		const char *long_name;
+
+		gtk_style_context_set_state (context, state);
+
+		gtk_style_context_get_color
+			(context, state, &ib->selection_colors[ui]);
+
+		gtk_style_context_get (context, state, "font", &desc, NULL);
+		pango_font_description_set_size (desc,
+						 zoom_factor * pango_font_description_get_size (desc));
+		/*
+		 * Figure out how tall the label can be.
+		 * (Note that we avoid J/Q/Y which may go below the line.)
+		 */
+		pango_layout_set_text (layout,
+				       char_label ? "AHW" : "0123456789",
+				       -1);
+		ib->selection_fonts[ui] =
+			pango_context_load_font (pcontext, desc);
+		pango_layout_set_font_description (layout, desc);
+		pango_layout_get_extents (layout, &ink_rect, NULL);
+		ib->selection_font_ascents[ui] =
+			PANGO_PIXELS (ink_rect.height + ink_rect.y);
+
+		/* The width of the widest string I can think of + padding */
+		if (ib->is_col_header) {
+			int last = gnm_sheet_get_last_col (sheet);
+			long_name = char_label ? col_name (last) :  /* HACK: */row_name (last);
+		} else
+			long_name = row_name (gnm_sheet_get_last_row (sheet));
+		pango_layout_set_text
+			(layout,
+			 char_label ? "WWWWWWWWWW" : "8888888888",
+			 strlen (long_name));
+		pango_layout_get_extents (layout, NULL,
+					  &ib->selection_logical_sizes[ui]);
 	}
 
-	if (ib->bold_font != NULL) {
-		g_object_unref (ib->bold_font);
-		ib->bold_font = NULL;
-	}
+	gtk_style_context_get_padding (context, GTK_STATE_NORMAL,
+				       &ib->padding);
+
+	gtk_style_context_restore (context);
+
+	attr_list = pango_attr_list_new ();
+	item_list = pango_itemize (pcontext, "A", 0, 1, attr_list, NULL);
+	pango_attr_list_unref (attr_list);
+	if (ib->pango.item)
+		pango_item_free (ib->pango.item);
+	ib->pango.item = item_list->data;
+	item_list->data = NULL;
+	if (item_list->next != NULL)
+		g_warning ("Leaking pango items");
+	g_list_free (item_list);
+
+	g_object_unref (layout);
 }
 
 /**
- * item_bar_calc_size :
- * @ib : #ItemBar
+ * gnm_item_bar_calc_size:
+ * @ib: #GnmItemBar
  *
  * Scale fonts and sizes by the pixels_per_unit of the associated sheet.
  *
  * Returns : the size of the fixed dimension.
  **/
 int
-item_bar_calc_size (ItemBar *ib)
+gnm_item_bar_calc_size (GnmItemBar *ib)
 {
 	SheetControlGUI	* const scg = ib->pane->simple.scg;
 	Sheet const *sheet = scg_sheet (scg);
-	double const zoom_factor = sheet->last_zoom_factor_used;
-	PangoContext *context;
-	PangoFontDescription const *src_desc = wbcg_get_font_desc (scg_wbcg (scg));
-	PangoFontDescription *desc;
-	int size = pango_font_description_get_size (src_desc);
-	PangoLayout *layout;
-	PangoRectangle ink_rect, logical_rect;
-	gboolean const char_label = ib->is_col_header && !sheet->convs->r1c1_addresses;
-	GList *item_list;
-	PangoAttrList *attr_list;
+	int size;
+	unsigned ui;
 
-	ib_fonts_unref (ib);
+	ib_dispose_fonts (ib);
+	ib_reload_style (ib);
 
-	context = gtk_widget_get_pango_context (GTK_WIDGET (ib->pane));
-	desc = pango_font_description_copy (src_desc);
-	pango_font_description_set_size (desc, zoom_factor * size);
-	layout = pango_layout_new (context);
+	ib->cell_height = 0;
+	ib->cell_width = 0;
+	for (ui = 0; ui < G_N_ELEMENTS (ib->selection_logical_sizes); ui++) {
+		int h = PANGO_PIXELS (ib->selection_logical_sizes[ui].height) +
+			(ib->padding.top + ib->padding.bottom);
+		int w = PANGO_PIXELS (ib->selection_logical_sizes[ui].width) +
+			(ib->padding.left + ib->padding.right);
+		ib->cell_height = MAX (ib->cell_height, h);
+		ib->cell_width = MAX (ib->cell_width, w);
+	}
 
-	/*
-	 * Figure out how tall the label can be.
-	 * (Note that we avoid J/Q/Y which may go below the line.)
-	 */
-	pango_layout_set_text (layout,
-			       char_label ? "AHW" : "0123456789",
-			       -1);
-	ib->normal_font = pango_context_load_font (context, desc);
-	pango_layout_set_font_description (layout, desc);
-	pango_layout_get_extents (layout, &ink_rect, NULL);
-	ib->normal_font_ascent = PANGO_PIXELS (ink_rect.height + ink_rect.y);
-
-	/*
-	 * Use the size of the bold header font to size the free dimensions.
-	 * Add 2 pixels above and below.
-	 */
-	pango_font_description_set_weight (desc, PANGO_WEIGHT_BOLD);
-	ib->bold_font = pango_context_load_font (context, desc);
-	pango_layout_set_font_description (layout, desc);
-	pango_layout_get_extents (layout, &ink_rect, &logical_rect);
-	ib->cell_height = 2 + 2 + PANGO_PIXELS (logical_rect.height);
-	ib->bold_font_ascent = PANGO_PIXELS (ink_rect.height + ink_rect.y);
-
-	/* 5 pixels left and right plus the width of the widest string I can think of */
-	if (char_label)
-		pango_layout_set_text (layout, "WWWWWWWWWW", strlen (col_name (gnm_sheet_get_last_col (sheet))));
-	else
-		pango_layout_set_text (layout, "8888888888", strlen (row_name (gnm_sheet_get_last_row (sheet))));
-	pango_layout_get_extents (layout, NULL, &logical_rect);
-	ib->cell_width = 5 + 5 + PANGO_PIXELS (logical_rect.width);
-
-	attr_list = pango_attr_list_new ();
-	pango_attr_list_insert (attr_list, pango_attr_font_desc_new (desc));
-	item_list = pango_itemize (context, "A", 0, 1, attr_list, NULL);
-	pango_attr_list_unref (attr_list);
-
-	if (ib->pango.item)
-	  pango_item_free (ib->pango.item);
-	ib->pango.item = item_list->data;
-	item_list->data = NULL;
-
-	if (item_list->next != NULL)
-	  g_warning ("Leaking pango items");
-
-	g_list_free (item_list);
-
-	size = ib_compute_pixels_from_indent (sheet, ib->is_col_header);
+	size = ib_compute_pixels_from_indent (ib, sheet);
 	if (size != ib->indent) {
 		ib->indent = size;
 		goc_item_bounds_changed (GOC_ITEM (ib));
 	}
 
-	pango_font_description_free (desc);
-	g_object_unref (layout);
-
 	return ib->indent +
 		(ib->is_col_header ? ib->cell_height : ib->cell_width);
 }
 
 /**
  * item_bar_normal_font:
- * @ib: #ItemBar
+ * @ib: #GnmItemBar
  *
- * Returns: (transfer none): the bar normal font.
+ * Returns: (transfer full): the bar normal font.
  **/
-PangoFont *
-item_bar_normal_font (ItemBar const *ib)
+PangoFontDescription *
+item_bar_normal_font (GnmItemBar const *ib)
 {
-	return ib->normal_font;
+	return pango_font_describe (ib->selection_fonts[COL_ROW_NO_SELECTION]);
 }
 
 int
-item_bar_indent	(ItemBar const *ib)
+gnm_item_bar_indent (GnmItemBar const *ib)
 {
 	return ib->indent;
 }
@@ -203,7 +242,7 @@ item_bar_indent	(ItemBar const *ib)
 static void
 item_bar_update_bounds (GocItem *item)
 {
-	ItemBar *ib = ITEM_BAR (item);
+	GnmItemBar *ib = GNM_ITEM_BAR (item);
 	item->x0 = 0;
 	item->y0 = 0;
 	if (ib->is_col_header) {
@@ -218,135 +257,105 @@ item_bar_update_bounds (GocItem *item)
 static void
 item_bar_realize (GocItem *item)
 {
-	ItemBar *ib;
+	GnmItemBar *ib = GNM_ITEM_BAR (item);
 	GdkDisplay *display;
 
-	if (parent_class->realize)
-		(*parent_class->realize)(item);
-
-	ib = ITEM_BAR (item);
+	parent_class->realize (item);
 
 	display = gtk_widget_get_display (GTK_WIDGET (item->canvas));
-	ib->normal_cursor = gdk_cursor_new_for_display (display, GDK_LEFT_PTR);
-	if (ib->is_col_header)
-		ib->change_cursor = gdk_cursor_new_for_display (display, GDK_SB_H_DOUBLE_ARROW);
-	else
-		ib->change_cursor = gdk_cursor_new_for_display (display, GDK_SB_V_DOUBLE_ARROW);
-	item_bar_calc_size (ib);
+	ib->normal_cursor =
+		gdk_cursor_new_for_display (display, GDK_LEFT_PTR);
+	ib->change_cursor =
+		gdk_cursor_new_for_display (display, 
+					    ib->is_col_header
+					    ? GDK_SB_H_DOUBLE_ARROW
+					    : GDK_SB_V_DOUBLE_ARROW);
+
+	gnm_item_bar_calc_size (ib);
 }
 
 static void
 item_bar_unrealize (GocItem *item)
 {
-	ItemBar *ib = ITEM_BAR (item);
+	GnmItemBar *ib = GNM_ITEM_BAR (item);
 
-	g_object_unref (ib->change_cursor);
-	g_object_unref (ib->normal_cursor);
+	g_clear_object (&ib->change_cursor);
+	g_clear_object (&ib->normal_cursor);
 
 	parent_class->unrealize (item);
 }
 
 static void
-ib_draw_cell (ItemBar const * const ib, cairo_t *cr,
+ib_draw_cell (GnmItemBar const * const ib, cairo_t *cr,
 	      ColRowSelectionType const type,
 	      char const * const str, GocRect *rect)
 {
-	GtkLayout *canvas = GTK_LAYOUT (ib->base.canvas);
-	GtkWidget *widget = GTK_WIDGET (canvas);
-	GtkStyleContext *ctxt = gtk_widget_get_style_context (widget);
-	PangoFont *font;
-	PangoRectangle size;
-	GOColor color, font_color;
-	GdkRGBA rgba;
-	int ascent;
+	GtkStyleContext *ctxt = goc_item_get_style_context (GOC_ITEM (ib));
+
+	g_return_if_fail ((size_t)type < G_N_ELEMENTS (selection_type_flags));
+
+	cairo_save (cr);
 
-	/* add "button" to the context path */
 	gtk_style_context_save (ctxt);
-	gtk_style_context_add_class (ctxt, GTK_STYLE_CLASS_BUTTON);
-	switch (type) {
-	default:
-	case COL_ROW_NO_SELECTION:
-		font   = ib->normal_font;
-		gtk_style_context_set_state (ctxt, GTK_STATE_FLAG_NORMAL);
-		gtk_style_context_get_background_color (ctxt, GTK_STATE_FLAG_NORMAL, &rgba);
-		color = GO_COLOR_FROM_GDK_RGBA (rgba);
-		gtk_style_context_get_color (ctxt, GTK_STATE_FLAG_NORMAL, &rgba);
-		font_color = GO_COLOR_FROM_GDK_RGBA (rgba);
-		ascent = ib->normal_font_ascent;
-		break;
+	gtk_style_context_set_state (ctxt, selection_type_flags[type]);
+	gtk_render_background (ctxt, cr, rect->x, rect->y,
+			       rect->width + 1, rect->height + 1);
 
-	case COL_ROW_PARTIAL_SELECTION:
-		font   = ib->bold_font;
-		gtk_style_context_set_state (ctxt, GTK_STATE_FLAG_PRELIGHT);
-		gtk_style_context_get_background_color (ctxt, GTK_STATE_FLAG_PRELIGHT, &rgba);
-		color = GO_COLOR_FROM_GDK_RGBA (rgba);
-		gtk_style_context_get_color (ctxt, GTK_STATE_FLAG_PRELIGHT, &rgba);
-		font_color = GO_COLOR_FROM_GDK_RGBA (rgba);
-		ascent = ib->bold_font_ascent;
-		break;
-
-	case COL_ROW_FULL_SELECTION:
-		font   = ib->bold_font;
-		gtk_style_context_set_state (ctxt, GTK_STATE_FLAG_ACTIVE);
-		gtk_style_context_get_background_color (ctxt, GTK_STATE_FLAG_ACTIVE, &rgba);
-		color = GO_COLOR_FROM_GDK_RGBA (rgba);
-		gtk_style_context_get_color (ctxt, GTK_STATE_FLAG_ACTIVE, &rgba);
-		font_color = GO_COLOR_FROM_GDK_RGBA (rgba);
-		ascent = ib->bold_font_ascent;
-		break;
-	}
 	/* When we are really small leave out the shadow and the text */
-	cairo_save (cr);
-	cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (color));
-	if (rect->width <= 2 || rect->height <= 2) {
-		cairo_rectangle (cr, rect->x, rect->y, rect->width, rect->height);
-		cairo_fill (cr);
-		cairo_restore (cr);
-		/* restore style context */
-		gtk_style_context_restore (ctxt);
-		return;
+	if (rect->width >= 2 && rect->height >= 2) {
+		PangoRectangle size;
+		PangoFont *font = ib->selection_fonts[type];
+		int ascent = ib->selection_font_ascents[type];
+		int w, h;
+
+		g_return_if_fail (font != NULL);
+		g_object_unref (ib->pango.item->analysis.font);
+		ib->pango.item->analysis.font = g_object_ref (font);
+		pango_shape (str, strlen (str),
+			     &(ib->pango.item->analysis), ib->pango.glyphs);
+		pango_glyph_string_extents (ib->pango.glyphs, font,
+					    NULL, &size);
+
+		gtk_render_frame (ctxt, cr, rect->x, rect->y,
+				  rect->width + 1, rect->height + 1);
+		w = rect->width - (ib->padding.left + ib->padding.right);
+		h = rect->height - (ib->padding.top + ib->padding.bottom);
+		cairo_rectangle (cr, rect->x + 1, rect->y + 1,
+				 rect->width - 2, rect->height - 2);
+		cairo_clip (cr);
+
+		gdk_cairo_set_source_rgba (cr, &ib->selection_colors[type]);
+
+		cairo_translate (cr,
+				 rect->x + ib->padding.left +
+				 (w - PANGO_PIXELS (size.width)) / 2,
+				 rect->y + ib->padding.top + ascent +
+				 (h - PANGO_PIXELS (size.height)) / 2);
+		pango_cairo_show_glyph_string (cr, font, ib->pango.glyphs);
 	}
-
-	gtk_render_background (ctxt, cr, rect->x, rect->y, rect->width + 1, rect->height + 1);
-	gtk_render_frame (ctxt, cr, rect->x, rect->y, rect->width + 1, rect->height + 1);
-	cairo_rectangle (cr, rect->x + 1, rect->y + 1, rect->width - 2, rect->height - 2);
-	cairo_restore (cr);
-
-	g_return_if_fail (font != NULL);
-	g_object_unref (ib->pango.item->analysis.font);
-	ib->pango.item->analysis.font = g_object_ref (font);
-	pango_shape (str, strlen (str), &(ib->pango.item->analysis), ib->pango.glyphs);
-	pango_glyph_string_extents (ib->pango.glyphs, font, NULL, &size);
-
-	cairo_save (cr);
-	cairo_clip (cr);
-	cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (font_color));
-	cairo_translate (cr,
-					 rect->x + (rect->width - PANGO_PIXELS (size.width)) / 2,
-					 rect->y + (rect->height - PANGO_PIXELS (size.height)) / 2 + ascent);
-	pango_cairo_show_glyph_string (cr, font, ib->pango.glyphs);
-	cairo_restore (cr);
-	/* restore style context */
 	gtk_style_context_restore (ctxt);
+	cairo_restore (cr);
 }
 
 int
-item_bar_group_size (ItemBar const *ib, int max_outline)
+gnm_item_bar_group_size (GnmItemBar const *ib, int max_outline)
 {
-	return (max_outline > 0) ? (ib->indent - 2) / (max_outline + 1) : 0;
+	return max_outline > 0
+		? (ib->indent - 2) / (max_outline + 1)
+		: 0;
 }
 
 static gboolean
-item_bar_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0, double x_1, double y_1)
+item_bar_draw_region (GocItem const *item, cairo_t *cr,
+		      double x_0, double y_0, double x_1, double y_1)
 {
 	double scale = item->canvas->pixels_per_unit;
 	int x0, x1, y0, y1;
-	ItemBar const         *ib = ITEM_BAR (item);
+	GnmItemBar const         *ib = GNM_ITEM_BAR (item);
 	GnmPane	 const	      *pane = ib->pane;
 	SheetControlGUI const *scg    = pane->simple.scg;
 	Sheet const           *sheet  = scg_sheet (scg);
 	SheetView const	      *sv     = scg_view (scg);
-	GtkWidget *canvas = GTK_WIDGET (item->canvas);
 	ColRowInfo const *cri, *next = NULL;
 	int pixels;
 	gboolean prev_visible;
@@ -359,19 +368,16 @@ item_bar_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 	gboolean const rtl = sheet->text_is_rtl != FALSE;
 	int shadow;
 	int first_line_offset = 1;
-	GdkRGBA rgba;
-	GtkStyleContext *ctxt = gtk_widget_get_style_context (canvas);
-	GOColor color;
+	GdkRGBA color;
+	GtkStyleContext *ctxt = goc_item_get_style_context (item);
 
 	gtk_style_context_save (ctxt);
-	gtk_style_context_add_class (ctxt, GTK_STYLE_CLASS_BUTTON);
-	gtk_style_context_get_color (ctxt, GTK_STATE_FLAG_NORMAL, &rgba);
-	color = GO_COLOR_FROM_GDK_RGBA (rgba);
+	gtk_style_context_get_color (ctxt, GTK_STATE_FLAG_NORMAL, &color);
 	goc_canvas_c2w (item->canvas, x_0, y_0, &x0, &y0);
 	goc_canvas_c2w (item->canvas, x_1, y_1, &x1, &y1);
 
 	if (ib->is_col_header) {
-		int const inc = item_bar_group_size (ib, sheet->cols.max_outline_level);
+		int const inc = gnm_item_bar_group_size (ib, sheet->cols.max_outline_level);
 		int const base_pos = .2 * inc;
 		int const len = (inc > 4) ? 4 : inc;
 		int end, total, col = pane->first.col;
@@ -435,7 +441,7 @@ item_bar_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 					cairo_set_line_width (cr, 2.0);
 					cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
 					cairo_set_line_join (cr, CAIRO_LINE_JOIN_MITER);
-					cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (color));
+					gdk_cairo_set_source_rgba (cr, &color);
 					if (!draw_right) {
 						next = sheet_col_get_info (sheet, col + 1);
 						prev_level = next->outline_level;
@@ -535,7 +541,7 @@ item_bar_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 			++col;
 		} while ((rtl && end <= total) || (!rtl && total <= end));
 	} else {
-		int const inc = item_bar_group_size (ib, sheet->rows.max_outline_level);
+		int const inc = gnm_item_bar_group_size (ib, sheet->rows.max_outline_level);
 		int base_pos = .2 * inc;
 		int const len = (inc > 4) ? 4 : inc;
 		int const end = y1;
@@ -594,7 +600,7 @@ item_bar_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 					cairo_set_line_width (cr, 2.0);
 					cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
 					cairo_set_line_join (cr, CAIRO_LINE_JOIN_MITER);
-					cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (color));
+					gdk_cairo_set_source_rgba (cr, &color);
 					if (!draw_below) {
 						next = sheet_row_get_info (sheet, row + 1);
 						points[0].y = top;
@@ -704,7 +710,7 @@ item_bar_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 
 static double
 item_bar_distance (GocItem *item, double x, double y,
-		GocItem **actual_item)
+		   GocItem **actual_item)
 {
 	*actual_item = item;
 	return 0.0;
@@ -712,12 +718,12 @@ item_bar_distance (GocItem *item, double x, double y,
 
 /**
  * is_pointer_on_division :
- * @ib : #ItemBar
- * @x  : in world coords
- * @y  : in world coords
- * @the_total :
- * @the_element :
- * @minor_pos :
+ * @ib: #GnmItemBar
+ * @x: in world coords
+ * @y: in world coords
+ * @the_total:
+ * @the_element:
+ * @minor_pos:
  *
  * NOTE : this could easily be optimized.  We need not start at 0 every time.
  *        We could potentially use the routines in gnm-pane.
@@ -725,7 +731,7 @@ item_bar_distance (GocItem *item, double x, double y,
  * Returns non-NULL if point (@x,@y) is on a division
  **/
 static ColRowInfo const *
-is_pointer_on_division (ItemBar const *ib, gint64 x, gint64 y,
+is_pointer_on_division (GnmItemBar const *ib, gint64 x, gint64 y,
 			gint64 *the_total, int *the_element, gint64 *minor_pos)
 {
 	Sheet *sheet = scg_sheet (ib->pane->simple.scg);
@@ -785,7 +791,7 @@ is_pointer_on_division (ItemBar const *ib, gint64 x, gint64 y,
 
 /* x & y in world coords */
 static void
-ib_set_cursor (ItemBar *ib, gint64 x, gint64 y)
+ib_set_cursor (GnmItemBar *ib, gint64 x, gint64 y)
 {
 	GdkWindow *window = gtk_widget_get_window (GTK_WIDGET (ib->base.canvas));
 	GdkCursor *cursor = ib->normal_cursor;
@@ -799,7 +805,7 @@ ib_set_cursor (ItemBar *ib, gint64 x, gint64 y)
 }
 
 static void
-colrow_tip_setlabel (ItemBar *ib, gboolean const is_cols, int size_pixels)
+colrow_tip_setlabel (GnmItemBar *ib, gboolean const is_cols, int size_pixels)
 {
 	if (ib->tip != NULL) {
 		char *buffer, *points, *pixels;
@@ -828,7 +834,7 @@ colrow_tip_setlabel (ItemBar *ib, gboolean const is_cols, int size_pixels)
 }
 
 static void
-item_bar_resize_stop (ItemBar *ib, int new_size)
+item_bar_resize_stop (GnmItemBar *ib, int new_size)
 {
 	if (new_size != 0 && ib->colrow_being_resized >= 0)
 		scg_colrow_size_set (ib->pane->simple.scg,
@@ -847,7 +853,7 @@ item_bar_resize_stop (ItemBar *ib, int new_size)
 static gboolean
 cb_extend_selection (GnmPane *pane, GnmPaneSlideInfo const *info)
 {
-	ItemBar * const ib = info->user_data;
+	GnmItemBar * const ib = info->user_data;
 	gboolean const is_cols = ib->is_col_header;
 	scg_colrow_select (pane->simple.scg,
 		is_cols, is_cols ? info->col : info->row, GDK_SHIFT_MASK);
@@ -855,7 +861,7 @@ cb_extend_selection (GnmPane *pane, GnmPaneSlideInfo const *info)
 }
 
 static gint
-outline_button_press (ItemBar const *ib, int element, int pixel)
+outline_button_press (GnmItemBar const *ib, int element, int pixel)
 {
 	SheetControlGUI *scg = ib->pane->simple.scg;
 	Sheet * const sheet = scg_sheet (scg);
@@ -883,7 +889,7 @@ item_bar_button_pressed (GocItem *item, int button, double x_, double y_)
 {
 	ColRowInfo const *cri;
 	GocCanvas	* const canvas = item->canvas;
-	ItemBar		* const ib = ITEM_BAR (item);
+	GnmItemBar		* const ib = GNM_ITEM_BAR (item);
 	GnmPane		* const pane = ib->pane;
 	SheetControlGUI	* const scg = pane->simple.scg;
 	SheetControl	* const sc = (SheetControl *) pane->simple.scg;
@@ -971,7 +977,7 @@ item_bar_button_pressed (GocItem *item, int button, double x_, double y_)
 static gboolean
 item_bar_2button_pressed (GocItem *item, int button, double x, double y)
 {
-	ItemBar		* const ib = ITEM_BAR (item);
+	GnmItemBar		* const ib = GNM_ITEM_BAR (item);
 	if (button > 3)
 		return FALSE;
 
@@ -983,7 +989,7 @@ item_bar_2button_pressed (GocItem *item, int button, double x, double y)
 static gboolean
 item_bar_enter_notify (GocItem *item, double x_, double y_)
 {
-	ItemBar		* const ib = ITEM_BAR (item);
+	GnmItemBar		* const ib = GNM_ITEM_BAR (item);
 	gint64 x = x_ * item->canvas->pixels_per_unit, y = y_ * item->canvas->pixels_per_unit;
 	ib_set_cursor (ib, x, y);
 	return TRUE;
@@ -994,7 +1000,7 @@ item_bar_motion (GocItem *item, double x_, double y_)
 {
 	ColRowInfo const *cri;
 	GocCanvas	* const canvas = item->canvas;
-	ItemBar		* const ib = ITEM_BAR (item);
+	GnmItemBar		* const ib = GNM_ITEM_BAR (item);
 	GnmPane		* const pane = ib->pane;
 	SheetControlGUI	* const scg = pane->simple.scg;
 	SheetControl	* const sc = (SheetControl *) pane->simple.scg;
@@ -1008,7 +1014,9 @@ item_bar_motion (GocItem *item, double x_, double y_)
 		if (!ib->has_resize_guides) {
 			ib->has_resize_guides = TRUE;
 			scg_size_guide_start (ib->pane->simple.scg,
-				ib->is_col_header, ib->colrow_being_resized, 1);
+					      ib->is_col_header,
+					      ib->colrow_being_resized,
+					      TRUE);
 		}
 
 		cri = sheet_colrow_get_info (sheet,
@@ -1043,7 +1051,7 @@ item_bar_motion (GocItem *item, double x_, double y_)
 		colrow_tip_setlabel (ib, is_cols, new_size);
 		scg_size_guide_motion (scg, is_cols, pos);
 
-		/* Redraw the ItemBar to show nice incremental progress */
+		/* Redraw the GnmItemBar to show nice incremental progress */
 		goc_canvas_invalidate (canvas, 0, 0, G_MAXINT/2,  G_MAXINT/2);
 
 	} else if (ib->start_selection != -1) {
@@ -1060,7 +1068,7 @@ item_bar_motion (GocItem *item, double x_, double y_)
 static gboolean
 item_bar_button_released (GocItem *item, int button, double x, double y)
 {
-	ItemBar	*ib = ITEM_BAR (item);
+	GnmItemBar	*ib = GNM_ITEM_BAR (item);
 	if (item == goc_canvas_get_grabbed_item (item->canvas))
 		gnm_simple_canvas_ungrab (item, 0);
 	if (ib->colrow_being_resized >= 0) {
@@ -1081,13 +1089,13 @@ static void
 item_bar_set_property (GObject *obj, guint param_id,
 		       GValue const *value, GParamSpec *pspec)
 {
-	ItemBar *ib = ITEM_BAR (obj);
+	GnmItemBar *ib = GNM_ITEM_BAR (obj);
 
 	switch (param_id){
-	case ITEM_BAR_PROP_PANE:
+	case GNM_ITEM_BAR_PROP_PANE:
 		ib->pane = g_value_get_object (value);
 		break;
-	case ITEM_BAR_PROP_IS_COL_HEADER:
+	case GNM_ITEM_BAR_PROP_IS_COL_HEADER:
 		ib->is_col_header = g_value_get_boolean (value);
 		goc_item_bounds_changed (GOC_ITEM (obj));
 		break;
@@ -1097,9 +1105,9 @@ item_bar_set_property (GObject *obj, guint param_id,
 static void
 item_bar_dispose (GObject *obj)
 {
-	ItemBar *ib = ITEM_BAR (obj);
+	GnmItemBar *ib = GNM_ITEM_BAR (obj);
 
-	ib_fonts_unref (ib);
+	ib_dispose_fonts (ib);
 
 	if (ib->tip) {
 		gtk_widget_destroy (ib->tip);
@@ -1119,7 +1127,7 @@ item_bar_dispose (GObject *obj)
 }
 
 static void
-item_bar_init (ItemBar *ib)
+gnm_item_bar_init (GnmItemBar *ib)
 {
 	ib->base.x0 = 0;
 	ib->base.y0 = 0;
@@ -1132,18 +1140,21 @@ item_bar_init (ItemBar *ib)
 	ib->indent = 0;
 	ib->start_selection = -1;
 
-	ib->normal_font = NULL;
-	ib->bold_font = NULL;
 	ib->tip = NULL;
 
 	ib->colrow_being_resized = -1;
 	ib->has_resize_guides = FALSE;
 	ib->pango.item = NULL;
 	ib->pango.glyphs = pango_glyph_string_new ();
+
+	/* Style-wise we are a button.  */
+	gtk_style_context_add_class
+		(goc_item_get_style_context (GOC_ITEM (ib)),
+		 GTK_STYLE_CLASS_BUTTON);
 }
 
 static void
-item_bar_class_init (GObjectClass  *gobject_klass)
+gnm_item_bar_class_init (GObjectClass  *gobject_klass)
 {
 	GocItemClass *item_klass = (GocItemClass *) gobject_klass;
 
@@ -1151,12 +1162,12 @@ item_bar_class_init (GObjectClass  *gobject_klass)
 
 	gobject_klass->dispose = item_bar_dispose;
 	gobject_klass->set_property = item_bar_set_property;
-	g_object_class_install_property (gobject_klass, ITEM_BAR_PROP_PANE,
+	g_object_class_install_property (gobject_klass, GNM_ITEM_BAR_PROP_PANE,
 		g_param_spec_object ("pane", "pane",
 			"The pane containing the associated grid",
 			GNM_PANE_TYPE,
 			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
-	g_object_class_install_property (gobject_klass, ITEM_BAR_PROP_IS_COL_HEADER,
+	g_object_class_install_property (gobject_klass, GNM_ITEM_BAR_PROP_IS_COL_HEADER,
 		g_param_spec_boolean ("IsColHeader", "IsColHeader",
 			"Is the item-bar a header for columns or rows",
 			FALSE,
@@ -1174,6 +1185,6 @@ item_bar_class_init (GObjectClass  *gobject_klass)
 	item_klass->motion = item_bar_motion;
 }
 
-GSF_CLASS (ItemBar, item_bar,
-	   item_bar_class_init, item_bar_init,
+GSF_CLASS (GnmItemBar, gnm_item_bar,
+	   gnm_item_bar_class_init, gnm_item_bar_init,
 	   GOC_TYPE_ITEM)
