@@ -37,13 +37,13 @@
 #include <goffice/goffice.h>
 #define GNUMERIC_ITEM "CURSOR"
 
-#define ITEM_CURSOR_CLASS(k)      (G_TYPE_CHECK_CLASS_CAST ((k), item_cursor_get_type (), ItemCursorClass))
+#define ITEM_CURSOR_CLASS(k)      (G_TYPE_CHECK_CLASS_CAST ((k), gnm_item_cursor_get_type (), GnmItemCursorClass))
 
 #define AUTO_HANDLE_WIDTH	2
 #define AUTO_HANDLE_SPACE	(AUTO_HANDLE_WIDTH * 2)
 #define CLIP_SAFETY_MARGIN      (AUTO_HANDLE_SPACE + 5)
 
-struct _ItemCursor {
+struct _GnmItemCursor {
 	GocItem canvas_item;
 
 	SheetControlGUI *scg;
@@ -57,9 +57,9 @@ struct _ItemCursor {
 	GtkWidget        *tip;
 	GnmCellPos last_tip_pos;
 
-	ItemCursorStyle style;
+	GnmItemCursorStyle style;
 	int      state;
-	int      animation_timer;
+	guint    animation_timer;
 
 	/*
 	 * For the autofill mode:
@@ -86,8 +86,14 @@ struct _ItemCursor {
 	gboolean auto_fill_handle_at_left;
 
 	GdkRGBA  color;
+
+	/* Style: */
+	GdkRGBA normal_color;
+	GdkRGBA ant_color, ant_background_color;
+	GdkRGBA drag_color, drag_background_color;
+	GdkRGBA autofill_color, autofill_background_color;
 };
-typedef GocItemClass ItemCursorClass;
+typedef GocItemClass GnmItemCursorClass;
 
 static GocItemClass *parent_class;
 
@@ -99,8 +105,43 @@ enum {
 	ITEM_CURSOR_PROP_COLOR
 };
 
+
+static void
+ic_reload_style (GnmItemCursor *ic)
+{
+	GocItem *item = GOC_ITEM (ic);
+	GtkStyleContext *context = goc_item_get_style_context (item);
+	GtkStateFlags state = GTK_STATE_FLAG_NORMAL;
+
+	gtk_style_context_save (context);
+	gtk_style_context_add_class (context, "normal");
+	gtk_style_context_get_color (context, state, &ic->normal_color);
+	gtk_style_context_restore (context);
+
+	gtk_style_context_save (context);
+	gtk_style_context_add_class (context, "ant");
+	gtk_style_context_get_color (context, state, &ic->ant_color);
+	gtk_style_context_get_background_color (context, state,
+						&ic->ant_background_color);
+	gtk_style_context_restore (context);
+
+	gtk_style_context_save (context);
+	gtk_style_context_add_class (context, "drag");
+	gtk_style_context_get_color (context, state, &ic->drag_color);
+	gtk_style_context_get_background_color (context, state,
+						&ic->drag_background_color);
+	gtk_style_context_restore (context);
+
+	gtk_style_context_save (context);
+	gtk_style_context_add_class (context, "autofill");
+	gtk_style_context_get_color (context, state, &ic->autofill_color);
+	gtk_style_context_get_background_color (context, state,
+						&ic->autofill_background_color);
+	gtk_style_context_restore (context);
+}
+
 static int
-cb_item_cursor_animation (ItemCursor *ic)
+cb_item_cursor_animation (GnmItemCursor *ic)
 {
 	GocItem *item = GOC_ITEM (ic);
 
@@ -112,7 +153,7 @@ cb_item_cursor_animation (ItemCursor *ic)
 static void
 item_cursor_dispose (GObject *obj)
 {
-	ItemCursor *ic = ITEM_CURSOR (obj);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (obj);
 
 	if (ic->tip) {
 		gtk_widget_destroy (gtk_widget_get_toplevel (ic->tip));
@@ -125,13 +166,14 @@ item_cursor_dispose (GObject *obj)
 static void
 item_cursor_realize (GocItem *item)
 {
-	ItemCursor *ic = ITEM_CURSOR (item);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
 
-	if (parent_class->realize)
-		(*parent_class->realize) (item);
+	parent_class->realize (item);
 
-	if (ic->style == ITEM_CURSOR_ANTED) {
-		g_return_if_fail (ic->animation_timer == -1);
+	ic_reload_style (ic);
+
+	if (ic->style == GNM_ITEM_CURSOR_ANTED) {
+		g_return_if_fail (ic->animation_timer == 0);
 		ic->animation_timer = g_timeout_add (
 			150, (GSourceFunc) cb_item_cursor_animation,
 			ic);
@@ -141,21 +183,20 @@ item_cursor_realize (GocItem *item)
 static void
 item_cursor_unrealize (GocItem *item)
 {
-	ItemCursor *ic = ITEM_CURSOR (item);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
 
-	if (ic->animation_timer != -1) {
+	if (ic->animation_timer != 0) {
 		g_source_remove (ic->animation_timer);
-		ic->animation_timer = -1;
+		ic->animation_timer = 0;
 	}
 
-	if (parent_class->unrealize)
-		(*parent_class->unrealize) (item);
+	parent_class->unrealize (item);
 }
 
 static void
 item_cursor_update_bounds (GocItem *item)
 {
-	ItemCursor	*ic = ITEM_CURSOR (item);
+	GnmItemCursor	*ic = GNM_ITEM_CURSOR (item);
 	GnmPane		*pane = GNM_PANE (item->canvas);
 	SheetControlGUI const * const scg = ic->scg;
 	int tmp;
@@ -182,7 +223,7 @@ item_cursor_update_bounds (GocItem *item)
 	item->y0 = (ic->outline.y1 - 2) / scale;
 
 	/* for the autohandle */
-	tmp = (ic->style == ITEM_CURSOR_SELECTION) ? AUTO_HANDLE_WIDTH : 0;
+	tmp = (ic->style == GNM_ITEM_CURSOR_SELECTION) ? AUTO_HANDLE_WIDTH : 0;
 	item->x1 = (ic->outline.x2 + 3 + tmp) / scale;
 	item->y1 = (ic->outline.y2 + 3 + tmp) / scale;
 }
@@ -190,23 +231,23 @@ item_cursor_update_bounds (GocItem *item)
 static void
 item_cursor_draw (GocItem const *item, cairo_t *cr)
 {
-	ItemCursor *ic = ITEM_CURSOR (item);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
 	int x0, y0, x1, y1; /* in widget coordinates */
 	GocPoint points[5];
-	int i, draw_thick, draw_handle;
+	int i, draw_thick, draw_stippled, draw_handle;
 	int premove = 0;
-	gboolean draw_stippled, draw_center, draw_external, draw_internal, draw_xor;
+	gboolean draw_center, draw_external, draw_internal, draw_xor;
 	double scale = item->canvas->pixels_per_unit;
 	GdkEventExpose *expose = (GdkEventExpose *) goc_canvas_get_cur_event (item->canvas);
 	GdkRGBA *fore = NULL, *back = NULL;
 
 #if 0
-		g_print ("draw[%d] %lx,%lx %lx,%lx\n",
-		 GNM_PANE (item->canvas)->index,
-		 ic->outline.x1,
-		 ic->outline.y1,
-		 ic->outline.x2,
-		 ic->outline.y2);
+	g_printerr ("draw[%d] %lx,%lx %lx,%lx\n",
+		    GNM_PANE (item->canvas)->index,
+		    ic->outline.x1,
+		    ic->outline.y1,
+		    ic->outline.x2,
+		    ic->outline.y2);
 #endif
 	if (!ic->visible || !ic->pos_initialized)
 		return;
@@ -233,59 +274,68 @@ item_cursor_draw (GocItem const *item, cairo_t *cr)
 	draw_handle   = 0;
 	draw_thick    = 1;
 	draw_center   = FALSE;
-	draw_stippled = FALSE;
+	draw_stippled = 4;
 	draw_xor      = TRUE;
 
 	switch (ic->style) {
-	case ITEM_CURSOR_AUTOFILL:
-	case ITEM_CURSOR_DRAG:
+	case GNM_ITEM_CURSOR_AUTOFILL:
 		draw_center   = TRUE;
 		draw_thick    = 3;
-		draw_stippled = TRUE;
-		fore          = &gs_black;
-		back          = &gs_white;
+		draw_stippled = 1;
+		fore          = &ic->autofill_color;
+		back          = &ic->autofill_background_color;
+		draw_xor      = FALSE;
 		break;
 
-	case ITEM_CURSOR_EXPR_RANGE:
+	case GNM_ITEM_CURSOR_DRAG:
+		draw_center   = TRUE;
+		draw_thick    = 3;
+		draw_stippled = 1;
+		fore          = &ic->drag_color;
+		back          = &ic->drag_background_color;
+		draw_xor      = FALSE;
+		break;
+
+	case GNM_ITEM_CURSOR_EXPR_RANGE:
 		draw_center   = TRUE;
 		draw_thick    = (item->canvas->last_item == item) ? 3 : 2;
 		draw_xor      = FALSE;
 		break;
 
-	case ITEM_CURSOR_SELECTION:
+	case GNM_ITEM_CURSOR_SELECTION: {
+		GnmPane const *pane = GNM_PANE (item->canvas);
+		GnmPane const *pane0 = scg_pane (pane->simple.scg, 0);
+
 		draw_internal = TRUE;
 		draw_external = TRUE;
-		{
-			GnmPane const *pane = GNM_PANE (item->canvas);
-			GnmPane const *pane0 = scg_pane (pane->simple.scg, 0);
 
-			/* In pane */
-			if (ic->pos.end.row <= pane->last_full.row)
-				draw_handle = 1;
-			/* In pane below */
-			else if ((pane->index == 2 || pane->index == 3) &&
-				 ic->pos.end.row >= pane0->first.row &&
-				 ic->pos.end.row <= pane0->last_full.row)
-				draw_handle = 1;
-			/* TODO : do we want to add checking for pane above ? */
-			else if (ic->pos.start.row < pane->first.row)
-				draw_handle = 0;
-			else if (ic->pos.start.row != pane->first.row)
-				draw_handle = 2;
-			else
-				draw_handle = 3;
-		}
+		/* In pane */
+		if (ic->pos.end.row <= pane->last_full.row)
+			draw_handle = 1;
+		/* In pane below */
+		else if ((pane->index == 2 || pane->index == 3) &&
+			 ic->pos.end.row >= pane0->first.row &&
+			 ic->pos.end.row <= pane0->last_full.row)
+			draw_handle = 1;
+		/* TODO : do we want to add checking for pane above ? */
+		else if (ic->pos.start.row < pane->first.row)
+			draw_handle = 0;
+		else if (ic->pos.start.row != pane->first.row)
+			draw_handle = 2;
+		else
+			draw_handle = 3;
 		break;
+	}
 
-	case ITEM_CURSOR_ANTED:
+	case GNM_ITEM_CURSOR_ANTED:
 		draw_center   = TRUE;
 		draw_thick    = 2;
+		fore = &ic->ant_color;
+		back = &ic->ant_background_color;
 		if (ic->state) {
-			fore = &gs_light_gray;
-			back = &gs_dark_gray;
-		} else {
-			fore = &gs_dark_gray;
-			back = &gs_light_gray;
+			GdkRGBA *swap = fore;
+			fore = back;
+			back = swap;
 		}
 	}
 
@@ -316,19 +366,19 @@ item_cursor_draw (GocItem const *item, cairo_t *cr)
 	cairo_set_line_width (cr, 1.);
 	cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
 	cairo_set_line_join (cr, CAIRO_LINE_JOIN_MITER);
-	cairo_set_source_rgba (cr, gs_black.red, gs_black.green, gs_black.blue, gs_black.alpha);
+	gdk_cairo_set_source_rgba (cr, &ic->normal_color);
 
 	if (draw_xor)
 		cairo_set_operator (cr, CAIRO_OPERATOR_HARD_LIGHT);
 	if (draw_external) {
 		switch (draw_handle) {
 		/* Auto handle at bottom */
-		case 1 :
+		case 1:
 			premove = AUTO_HANDLE_SPACE;
 			/* Fall through */
 
 		/* No auto handle */
-		case 0 :
+		case 0:
 			points [0].x = x1 + 1.5;
 			points [0].y = y1 + 1 - premove;
 			points [1].x = points [0].x;
@@ -342,11 +392,12 @@ item_cursor_draw (GocItem const *item, cairo_t *cr)
 			break;
 
 		/* Auto handle at top */
-		case 2 : premove = AUTO_HANDLE_SPACE;
-			 /* Fall through */
+		case 2:
+			premove = AUTO_HANDLE_SPACE;
+			/* Fall through */
 
 		/* Auto handle at top of sheet */
-		case 3 :
+		case 3:
 			points [0].x = x1 + 1.5;
 			points [0].y = y0 - .5 + AUTO_HANDLE_SPACE;
 			points [1].x = points [0].x;
@@ -359,7 +410,7 @@ item_cursor_draw (GocItem const *item, cairo_t *cr)
 			points [4].y = points [3].y;
 			break;
 
-		default :
+		default:
 			g_assert_not_reached ();
 		}
 		cairo_move_to (cr, points[0].x, points[0].y);
@@ -408,54 +459,30 @@ item_cursor_draw (GocItem const *item, cairo_t *cr)
 	}
 
 	if (draw_center) {
+		double dashes[2];
+
 		/* Stay in the boundary */
-		if ((draw_thick % 2) == 0) {
-			x0++;
-			y0++;
-		}
-		if ((draw_thick % 1) == 1) {
-			x0 += .5;
-			y0 += .5;
-		}
-
-		if (draw_stippled) {
-			GOPattern pat;
-			double scalex = 1., scaley = 1.;
-			cairo_pattern_t *cp;
-			cairo_matrix_t mat;
-			pat.fore = GO_COLOR_FROM_GDK_RGBA (*fore);
-			pat.back = GO_COLOR_FROM_GDK_RGBA (*back);
-			pat.pattern = GO_PATTERN_GREY50;
-			cp = go_pattern_create_cairo_pattern (&pat, cr);
-			cairo_user_to_device_distance (cr, &scalex, &scaley);
-			cairo_matrix_init_scale (&mat, scalex, scaley);
-			cairo_pattern_set_matrix (cp, &mat);
-			cairo_set_source (cr, cp);
-			cairo_pattern_destroy (cp);
-			cairo_set_line_width (cr, draw_thick);
-			cairo_rectangle (cr, x0, y0, abs (x1 - x0), abs (y1 - y0));
-			cairo_stroke (cr);
-		} else {
-			double dashes[] = {4., 4.};
-			cairo_set_dash (cr, dashes, 2, 0.);
-			cairo_set_line_width (cr, draw_thick);
-			cairo_set_source_rgba (cr, back->red, back->green, back->blue, back->alpha);
-			cairo_rectangle (cr, x0, y0, abs (x1 - x0), abs (y1 - y0));
-			cairo_stroke_preserve (cr);
-			cairo_set_dash (cr, dashes, 2, 4.);
-			cairo_set_source_rgba (cr, fore->red, fore->green, fore->blue, fore->alpha);
-			cairo_stroke (cr);
-		}
+		x0 += (draw_thick / 2.0);
+		y0 += (draw_thick / 2.0);
 
+		dashes[0] = dashes[1] = draw_stippled;
+		cairo_set_dash (cr, dashes, 2, 0.);
+		cairo_set_line_width (cr, draw_thick);
+		gdk_cairo_set_source_rgba (cr, back);
+		cairo_rectangle (cr, x0, y0, abs (x1 - x0), abs (y1 - y0));
+		cairo_stroke_preserve (cr);
+		cairo_set_dash (cr, dashes, 2, dashes[1]);
+		gdk_cairo_set_source_rgba (cr, fore);
+		cairo_stroke (cr);
 	}
-		cairo_restore (cr);
+	cairo_restore (cr);
 }
 
 gboolean
-item_cursor_bound_set (ItemCursor *ic, GnmRange const *new_bound)
+gnm_item_cursor_bound_set (GnmItemCursor *ic, GnmRange const *new_bound)
 {
 	GocItem *item;
-	g_return_val_if_fail (IS_ITEM_CURSOR (ic), FALSE);
+	g_return_val_if_fail (GNM_IS_ITEM_CURSOR (ic), FALSE);
 	g_return_val_if_fail (range_is_sane (new_bound), FALSE);
 
 	if (ic->pos_initialized && range_equal (&ic->pos, new_bound))
@@ -473,7 +500,7 @@ item_cursor_bound_set (ItemCursor *ic, GnmRange const *new_bound)
 }
 
 /**
- * item_cursor_reposition:
+ * gnm_item_cursor_reposition:
  *
  * Re-compute the pixel position of the cursor.
  *
@@ -481,7 +508,7 @@ item_cursor_bound_set (ItemCursor *ic, GnmRange const *new_bound)
  * must regenerate to stay in sync.
  **/
 void
-item_cursor_reposition (ItemCursor *ic)
+gnm_item_cursor_reposition (GnmItemCursor *ic)
 {
 	g_return_if_fail (GOC_IS_ITEM (ic));
 	goc_item_bounds_changed (GOC_ITEM (ic));
@@ -489,16 +516,16 @@ item_cursor_reposition (ItemCursor *ic)
 
 static double
 item_cursor_distance (GocItem *item, double x, double y,
-		   GocItem **actual_item)
+		      GocItem **actual_item)
 {
-	ItemCursor const *ic = ITEM_CURSOR (item);
+	GnmItemCursor const *ic = GNM_ITEM_CURSOR (item);
 
 	/* Cursor should not always receive events
 	 * 1) when invisible
 	 * 2) when animated
 	 * 3) while a guru is up
 	 */
-	if (!ic->visible || ic->style == ITEM_CURSOR_ANTED ||
+	if (!ic->visible || ic->style == GNM_ITEM_CURSOR_ANTED ||
 	    wbc_gtk_get_guru (scg_wbcg (ic->scg)) != NULL)
 		return DBL_MAX;
 
@@ -522,7 +549,7 @@ item_cursor_distance (GocItem *item, double x, double y,
 }
 
 static void
-item_cursor_setup_auto_fill (ItemCursor *ic, ItemCursor const *parent, int x, int y)
+item_cursor_setup_auto_fill (GnmItemCursor *ic, GnmItemCursor const *parent, int x, int y)
 {
 	Sheet const *sheet = scg_sheet (parent->scg);
 	GSList *merges;
@@ -551,7 +578,7 @@ item_cursor_setup_auto_fill (ItemCursor *ic, ItemCursor const *parent, int x, in
 }
 
 static inline gboolean
-item_cursor_in_drag_handle (ItemCursor *ic, gint64 x, gint64 y)
+item_cursor_in_drag_handle (GnmItemCursor *ic, gint64 x, gint64 y)
 {
 	double scale = ic->canvas_item.canvas->pixels_per_unit;
 	gint64 const y_test = ic->auto_fill_handle_at_top
@@ -574,7 +601,7 @@ item_cursor_in_drag_handle (ItemCursor *ic, gint64 x, gint64 y)
 }
 
 static void
-item_cursor_set_cursor (GocCanvas *canvas, ItemCursor *ic, gint64 x, gint64 y)
+item_cursor_set_cursor (GocCanvas *canvas, GnmItemCursor *ic, gint64 x, gint64 y)
 {
 	GdkCursorType cursor;
 
@@ -591,10 +618,10 @@ item_cursor_selection_motion (GocItem *item, double x_, double y_)
 {
 	GocCanvas  *canvas = item->canvas;
 	GnmPane  *pane = GNM_PANE (canvas);
-	ItemCursor *ic = ITEM_CURSOR (item);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
 	int style, button;
 	gint64 x = x_ * canvas->pixels_per_unit, y = y_ * canvas->pixels_per_unit;
-	ItemCursor *special_cursor;
+	GnmItemCursor *special_cursor;
 	GdkEventMotion *event = (GdkEventMotion *) goc_canvas_get_cur_event (item->canvas);
 
 	if (ic->drag_button < 0) {
@@ -607,9 +634,9 @@ item_cursor_selection_motion (GocItem *item, double x_, double y_)
 	 * the border or the handlebox
 	 */
 	if (item_cursor_in_drag_handle (ic, x_, y_))
-		style = ITEM_CURSOR_AUTOFILL;
+		style = GNM_ITEM_CURSOR_AUTOFILL;
 	else
-		style = ITEM_CURSOR_DRAG;
+		style = GNM_ITEM_CURSOR_DRAG;
 
 	button = ic->drag_button;
 	ic->drag_button = -1;
@@ -618,7 +645,7 @@ item_cursor_selection_motion (GocItem *item, double x_, double y_)
 	scg_special_cursor_start (ic->scg, style, button);
 	special_cursor = pane->cursor.special;
 	special_cursor->drag_button_state = ic->drag_button_state;
-	if (style == ITEM_CURSOR_AUTOFILL)
+	if (style == GNM_ITEM_CURSOR_AUTOFILL)
 		item_cursor_setup_auto_fill (
 			special_cursor, ic, x, y);
 
@@ -688,7 +715,7 @@ typedef enum {
 } ActionType;
 
 static void
-item_cursor_do_action (ItemCursor *ic, ActionType action)
+item_cursor_do_action (GnmItemCursor *ic, ActionType action)
 {
 	SheetView	*sv;
 	Sheet		*sheet;
@@ -764,7 +791,7 @@ context_menu_hander (GnumericPopupMenuElement const *element,
 }
 
 static void
-item_cursor_popup_menu (ItemCursor *ic, GdkEventButton *event)
+item_cursor_popup_menu (GnmItemCursor *ic, GdkEventButton *event)
 {
 	static GnumericPopupMenuElement const popup_elements[] = {
 		{ N_("_Move"),		NULL,
@@ -803,7 +830,7 @@ item_cursor_popup_menu (ItemCursor *ic, GdkEventButton *event)
 }
 
 static void
-item_cursor_do_drop (ItemCursor *ic, GdkEventButton *event)
+item_cursor_do_drop (GnmItemCursor *ic, GdkEventButton *event)
 {
 	/* Only do the operation if something moved */
 	SheetView const *sv = scg_view (ic->scg);
@@ -824,9 +851,9 @@ item_cursor_do_drop (ItemCursor *ic, GdkEventButton *event)
 }
 
 void
-item_cursor_set_visibility (ItemCursor *ic, gboolean visible)
+gnm_item_cursor_set_visibility (GnmItemCursor *ic, gboolean visible)
 {
-	g_return_if_fail (IS_ITEM_CURSOR (ic));
+	g_return_if_fail (GNM_IS_ITEM_CURSOR (ic));
 
 	if (ic->visible == visible)
 		return;
@@ -839,7 +866,7 @@ item_cursor_set_visibility (ItemCursor *ic, gboolean visible)
 }
 
 static void
-item_cursor_tip_setlabel (ItemCursor *ic, char const *text)
+item_cursor_tip_setlabel (GnmItemCursor *ic, char const *text)
 {
 	if (ic->tip == NULL) {
 		GtkWidget *cw = GTK_WIDGET (GOC_ITEM (ic)->canvas);
@@ -858,7 +885,7 @@ item_cursor_tip_setlabel (ItemCursor *ic, char const *text)
 static gboolean
 cb_move_cursor (GnmPane *pane, GnmPaneSlideInfo const *info)
 {
-	ItemCursor *ic = info->user_data;
+	GnmItemCursor *ic = info->user_data;
 	int const w = (ic->pos.end.col - ic->pos.start.col);
 	int const h = (ic->pos.end.row - ic->pos.start.row);
 	GnmRange r;
@@ -886,7 +913,7 @@ cb_move_cursor (GnmPane *pane, GnmPaneSlideInfo const *info)
 }
 
 static void
-item_cursor_handle_motion (ItemCursor *ic, double x, double y,
+item_cursor_handle_motion (GnmItemCursor *ic, double x, double y,
 			   GnmPaneSlideHandler slide_handler)
 {
 	GocCanvas *canvas = GOC_ITEM (ic)->canvas;
@@ -899,7 +926,7 @@ item_cursor_handle_motion (ItemCursor *ic, double x, double y,
 }
 
 static gboolean
-item_cursor_drag_motion (ItemCursor *ic, double x, double y)
+item_cursor_drag_motion (GnmItemCursor *ic, double x, double y)
 {
 	item_cursor_handle_motion (ic, x, y, &cb_move_cursor);
 	return TRUE;
@@ -935,7 +962,7 @@ limit_string_height_and_width (GString *s, size_t wmax, size_t hmax)
 static gboolean
 cb_autofill_scroll (GnmPane *pane, GnmPaneSlideInfo const *info)
 {
-	ItemCursor *ic = info->user_data;
+	GnmItemCursor *ic = info->user_data;
 	GnmRange r = ic->autofill_src;
 	int col = info->col, row = info->row;
 	int h, w;
@@ -1018,10 +1045,10 @@ cb_autofill_scroll (GnmPane *pane, GnmPaneSlideInfo const *info)
 static gboolean
 item_cursor_button_pressed (GocItem *item, int button, double x_, double y_)
 {
-	ItemCursor *ic = ITEM_CURSOR (item);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
 	gint64 x = x_ * item->canvas->pixels_per_unit, y = y_ * item->canvas->pixels_per_unit;
 	GdkEventButton *event = (GdkEventButton *) goc_canvas_get_cur_event (item->canvas);
-	if (ic->style == ITEM_CURSOR_EXPR_RANGE)
+	if (ic->style == GNM_ITEM_CURSOR_EXPR_RANGE)
 		return FALSE;
 
 	/* While editing nothing should be draggable */
@@ -1030,12 +1057,12 @@ item_cursor_button_pressed (GocItem *item, int button, double x_, double y_)
 
 	switch (ic->style) {
 
-	case ITEM_CURSOR_ANTED:
+	case GNM_ITEM_CURSOR_ANTED:
 		g_warning ("Animated cursors should not receive events, "
 			   "the point method should preclude that");
 		return FALSE;
 
-	case ITEM_CURSOR_SELECTION:
+	case GNM_ITEM_CURSOR_SELECTION:
 		/* NOTE : this cannot be called while we are editing.  because
 		 * the point routine excludes events.  so we do not need to
 		 * call wbcg_edit_finish.
@@ -1072,7 +1099,7 @@ item_cursor_button_pressed (GocItem *item, int button, double x_, double y_)
 			scg_context_menu (ic->scg, event, FALSE, FALSE);
 		return TRUE;
 
-	case ITEM_CURSOR_DRAG:
+	case GNM_ITEM_CURSOR_DRAG:
 		/* This kind of cursor is created and grabbed.  Then destroyed
 		 * when the button is released.  If we are seeing a press it
 		 * means that someone has pressed another button WHILE THE
@@ -1089,12 +1116,12 @@ item_cursor_button_pressed (GocItem *item, int button, double x_, double y_)
 static gboolean
 item_cursor_button2_pressed (GocItem *item, int button, double x_, double y_)
 {
-	ItemCursor *ic = ITEM_CURSOR (item);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
 	GdkEventButton *event = (GdkEventButton *) goc_canvas_get_cur_event (item->canvas);
 
 	switch (ic->style) {
 
-	case ITEM_CURSOR_SELECTION: {
+	case GNM_ITEM_CURSOR_SELECTION: {
 		Sheet *sheet = scg_sheet (ic->scg);
 		int final_col = ic->pos.end.col;
 		int final_row = ic->pos.end.row;
@@ -1244,7 +1271,7 @@ item_cursor_button2_pressed (GocItem *item, int button, double x_, double y_)
 		return TRUE;
 	}
 
-	case ITEM_CURSOR_DRAG:
+	case GNM_ITEM_CURSOR_DRAG:
 		return TRUE;
 
 	default:
@@ -1256,7 +1283,7 @@ item_cursor_button2_pressed (GocItem *item, int button, double x_, double y_)
 static gboolean
 item_cursor_motion (GocItem *item, double x_, double y_)
 {
-	ItemCursor *ic = ITEM_CURSOR (item);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
 	gint64 x = x_ * item->canvas->pixels_per_unit, y = y_ * item->canvas->pixels_per_unit;
 	ic->last_x = x;
 	ic->last_y = y;
@@ -1264,7 +1291,7 @@ item_cursor_motion (GocItem *item, double x_, double y_)
 		item_cursor_set_cursor (item->canvas, ic, x, y);
 		return TRUE;
 	}
-	if (ic->style == ITEM_CURSOR_EXPR_RANGE)
+	if (ic->style == GNM_ITEM_CURSOR_EXPR_RANGE)
 		return FALSE;
 
 	/* While editing nothing should be draggable */
@@ -1272,19 +1299,19 @@ item_cursor_motion (GocItem *item, double x_, double y_)
 		return TRUE;
 	switch (ic->style) {
 
-	case ITEM_CURSOR_ANTED:
+	case GNM_ITEM_CURSOR_ANTED:
 		g_warning ("Animated cursors should not receive events, "
 			   "the point method should preclude that");
 		return FALSE;
 
-	case ITEM_CURSOR_SELECTION:
+	case GNM_ITEM_CURSOR_SELECTION:
 		return item_cursor_selection_motion (item, x, y);
 
-	case ITEM_CURSOR_DRAG:
+	case GNM_ITEM_CURSOR_DRAG:
 		return item_cursor_drag_motion (ic, x, y);
 
-	case ITEM_CURSOR_AUTOFILL:
-		item_cursor_handle_motion (ITEM_CURSOR (item), x, y, &cb_autofill_scroll);
+	case GNM_ITEM_CURSOR_AUTOFILL:
+		item_cursor_handle_motion (GNM_ITEM_CURSOR (item), x, y, &cb_autofill_scroll);
 		return TRUE;
 
 	default:
@@ -1295,11 +1322,11 @@ item_cursor_motion (GocItem *item, double x_, double y_)
 static gboolean
 item_cursor_button_released (GocItem *item, int button, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
-	ItemCursor *ic = ITEM_CURSOR (item);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
 	GdkEventButton *event = (GdkEventButton *) goc_canvas_get_cur_event (item->canvas);
 	WBCGtk *wbcg = scg_wbcg (ic->scg);
 
-	if (ic->style == ITEM_CURSOR_EXPR_RANGE)
+	if (ic->style == GNM_ITEM_CURSOR_EXPR_RANGE)
 		return FALSE;
 
 	/* While editing nothing should be draggable */
@@ -1307,12 +1334,12 @@ item_cursor_button_released (GocItem *item, int button, G_GNUC_UNUSED double x,
 		return TRUE;
 
 	switch (ic->style) {
-	case ITEM_CURSOR_ANTED:
+	case GNM_ITEM_CURSOR_ANTED:
 		g_warning ("Animated cursors should not receive events, "
 			   "the point method should preclude that");
 		return FALSE;
 
-	case ITEM_CURSOR_SELECTION:
+	case GNM_ITEM_CURSOR_SELECTION:
 		if (ic->drag_button != button)
 			return TRUE;
 
@@ -1325,7 +1352,7 @@ item_cursor_button_released (GocItem *item, int button, G_GNUC_UNUSED double x,
 						     NULL);
 		return TRUE;
 
-	case ITEM_CURSOR_DRAG:
+	case GNM_ITEM_CURSOR_DRAG:
 		if (ic->drag_button != button)
 			return TRUE;
 
@@ -1337,7 +1364,7 @@ item_cursor_button_released (GocItem *item, int button, G_GNUC_UNUSED double x,
 						     NULL);
 		return TRUE;
 
-	case ITEM_CURSOR_AUTOFILL: {
+	case GNM_ITEM_CURSOR_AUTOFILL: {
 		gboolean inverse_autofill =
 			(ic->pos.start.col < ic->autofill_src.start.col ||
 			 ic->pos.start.row < ic->autofill_src.start.row);
@@ -1369,13 +1396,13 @@ item_cursor_button_released (GocItem *item, int button, G_GNUC_UNUSED double x,
 static gboolean
 item_cursor_enter_notify (GocItem *item, double x_, double y_)
 {
-	ItemCursor *ic = ITEM_CURSOR (item);
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
 	gint64 x = x_ * item->canvas->pixels_per_unit, y = y_ * item->canvas->pixels_per_unit;
-	if (ic->style == ITEM_CURSOR_EXPR_RANGE) {
+	if (ic->style == GNM_ITEM_CURSOR_EXPR_RANGE) {
 		gnm_widget_set_cursor_type (GTK_WIDGET (item->canvas), GDK_ARROW);
 		goc_item_invalidate (item);
 	}
-	else if (ic->style == ITEM_CURSOR_SELECTION)
+	else if (ic->style == GNM_ITEM_CURSOR_SELECTION)
 		item_cursor_set_cursor (item->canvas, ic, x, y);
 	return FALSE;
 }
@@ -1383,8 +1410,8 @@ item_cursor_enter_notify (GocItem *item, double x_, double y_)
 static gboolean
 item_cursor_leave_notify (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
-	ItemCursor *ic = ITEM_CURSOR (item);
-	if (ic->style == ITEM_CURSOR_EXPR_RANGE)
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (item);
+	if (ic->style == GNM_ITEM_CURSOR_EXPR_RANGE)
 		goc_item_invalidate (item);
 	return FALSE;
 }
@@ -1393,8 +1420,7 @@ static void
 item_cursor_set_property (GObject *obj, guint param_id,
 			  GValue const *value, GParamSpec *pspec)
 {
-	ItemCursor *ic = ITEM_CURSOR (obj);
-	char const *color_name;
+	GnmItemCursor *ic = GNM_ITEM_CURSOR (obj);
 
 	switch (param_id) {
 	case ITEM_CURSOR_PROP_SHEET_CONTROL_GUI:
@@ -1406,22 +1432,17 @@ item_cursor_set_property (GObject *obj, guint param_id,
 	case ITEM_CURSOR_PROP_BUTTON :
 		ic->drag_button = g_value_get_int (value);
 		break;
-	case ITEM_CURSOR_PROP_COLOR: {
-		GOColor color;
-		color_name = g_value_get_string (value);
-		if (go_color_from_str (color_name, &color)) {
-			go_color_to_gdk_rgba (color, &ic->color);
-			ic->use_color = 1;
-		}
-	}
+	case ITEM_CURSOR_PROP_COLOR:
+		go_color_to_gdk_rgba (g_value_get_uint (value), &ic->color);
+		ic->use_color = 1;
 	}
 }
 
 /*
- * ItemCursor class initialization
+ * GnmItemCursor class initialization
  */
 static void
-item_cursor_class_init (GObjectClass *gobject_klass)
+gnm_item_cursor_class_init (GObjectClass *gobject_klass)
 {
 
 	GocItemClass *item_klass = (GocItemClass *) gobject_klass;
@@ -1446,14 +1467,15 @@ item_cursor_class_init (GObjectClass *gobject_klass)
 			0, G_MAXINT, 0,
                         GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 	g_object_class_install_property (gobject_klass, ITEM_CURSOR_PROP_COLOR,
-		g_param_spec_string ("color", "Color",
-			"name of the cursor's color",
-			"black",
-                        GSF_PARAM_STATIC |  G_PARAM_WRITABLE));
+		g_param_spec_uint ("color", "Color",
+				   "Name of the cursor's color",
+				   0, 0xffffffff, 
+				   GO_COLOR_BLACK,
+				   GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 
 	item_klass->realize     = item_cursor_realize;
 	item_klass->unrealize   = item_cursor_unrealize;
-	item_klass->draw		= item_cursor_draw;
+	item_klass->draw	= item_cursor_draw;
 	item_klass->update_bounds = item_cursor_update_bounds;
 	item_klass->distance	= item_cursor_distance;
 	item_klass->button_pressed = item_cursor_button_pressed;
@@ -1465,7 +1487,7 @@ item_cursor_class_init (GObjectClass *gobject_klass)
 }
 
 static void
-item_cursor_init (ItemCursor *ic)
+gnm_item_cursor_init (GnmItemCursor *ic)
 {
 	ic->pos_initialized = FALSE;
 	ic->pos.start.col = 0;
@@ -1483,9 +1505,9 @@ item_cursor_init (ItemCursor *ic)
 	ic->last_x = 0;
 	ic->last_y = 0;
 
-	ic->style = ITEM_CURSOR_SELECTION;
+	ic->style = GNM_ITEM_CURSOR_SELECTION;
 	ic->state = 0;
-	ic->animation_timer = -1;
+	ic->animation_timer = 0;
 
 	ic->visible = TRUE;
 	ic->auto_fill_handle_at_top = FALSE;
@@ -1493,6 +1515,6 @@ item_cursor_init (ItemCursor *ic)
 	ic->drag_button = -1;
 }
 
-GSF_CLASS (ItemCursor, item_cursor,
-	   item_cursor_class_init, item_cursor_init,
+GSF_CLASS (GnmItemCursor, gnm_item_cursor,
+	   gnm_item_cursor_class_init, gnm_item_cursor_init,
 	   GOC_TYPE_ITEM)
