@@ -43,7 +43,7 @@
 
 static GocItemClass *parent_class;
 
-struct _ItemEdit {
+struct _GnmItemEdit {
 	GocItem item;
 
 	SheetControlGUI *scg;
@@ -54,14 +54,14 @@ struct _ItemEdit {
 	/* Where are we */
 	GnmCellPos pos;
 	gboolean   cursor_visible;
-	int        blink_timer;
+	guint      blink_timer;
 	int	   sel_start;
 
 	GnmFont   *gfont;
 	GnmStyle  *style;
 };
 
-typedef GocItemClass ItemEditClass;
+typedef GocItemClass GnmItemEditClass;
 
 /* The arguments we take */
 enum {
@@ -70,7 +70,7 @@ enum {
 };
 
 static void
-get_top_left (ItemEdit const *ie, int *top, int *left, PangoDirection dir)
+get_top_left (GnmItemEdit const *ie, int *top, int *left, PangoDirection dir)
 {
 	GnmVAlign const align = gnm_style_get_align_v (ie->style);
 	GocItem *item = GOC_ITEM (ie);
@@ -116,13 +116,15 @@ gnm_apply_attribute_list (PangoAttrList *attrs, PangoAttrList *added_attrs)
 static void
 item_edit_draw (GocItem const *item, cairo_t *cr)
 {
-	ItemEdit  const *ie	= ITEM_EDIT (item);
+	GnmItemEdit const *ie = GNM_ITEM_EDIT (item);
+	GtkStyleContext *context = goc_item_get_style_context (item);
 	int top, left;
 	GOColor color;
 	int x0, y0, x1, y1; /* in widget coordinates */
 	int start, end;
 	PangoRectangle pos, weak;
 	char const *text = gtk_entry_get_text (ie->entry);
+	GdkRGBA fcolor;
 	PangoDirection dir = pango_find_base_dir (text, -1);
 	PangoAttrList *entry_attributes
 		= g_object_get_data(G_OBJECT (ie->entry),
@@ -147,20 +149,21 @@ item_edit_draw (GocItem const *item, cairo_t *cr)
 	cairo_save (cr);
 
 	cairo_rectangle (cr, x0, y0, x1 - x0, y1 - y0);
-	/* avoid a weak/strong cursor to extent outside the item,
+	/* avoid a weak/strong cursor to extend outside the item,
 	 a better fix would be to have enough room for cursors */
-	cairo_clip_preserve (cr);
-	if (!gnumeric_background_set (ie->style, cr, FALSE, NULL))
-		cairo_set_source_rgba (cr, 1., 1., 0.878431373, 1.);
-	cairo_fill (cr);
+	cairo_clip (cr);
+	if (gnumeric_background_set (ie->style, cr, FALSE, NULL)) {
+		cairo_rectangle (cr, x0, y0, x1 - x0, y1 - y0);
+		cairo_fill (cr);
+	} else {
+		gtk_render_background (context, cr, x0, y0, x1 - x0, y1 - y0);
+	}
 
 	/* set the default color */
-#warning GTK3: no black in style context, using just black for now
-#if 0
-	color = GO_COLOR_FROM_GDK (gtk_widget_get_style (GTK_WIDGET (item->canvas))->black);
-#endif
-	color = GO_COLOR_BLACK;
-	cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (color));
+	gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &fcolor);
+	gdk_cairo_set_source_rgba (cr, &fcolor);
+	color = go_color_from_gdk_rgba (&fcolor, NULL);
+
 	if (dir == PANGO_DIRECTION_RTL) {
 		pango_layout_get_pixel_extents (ie->layout, NULL, &pos);
 		left -= pos.width + GNM_COL_MARGIN / goc_canvas_get_pixels_per_unit (item->canvas);
@@ -249,7 +252,7 @@ item_edit_draw (GocItem const *item, cairo_t *cr)
 
 static double
 item_edit_distance (GocItem *item, double cx, double cy,
-		 GocItem **actual_item)
+		    GocItem **actual_item)
 {
 	*actual_item = NULL;
 	if ((cx < item->x0) || (cy < item->y0) || (cx >= item->x1) || (cy >= item->y1))
@@ -270,7 +273,7 @@ static int
 item_edit_button_pressed (GocItem *item, int button, double x, double y)
 {
 	if (button == 1) {
-		ItemEdit *ie = ITEM_EDIT (item);
+		GnmItemEdit *ie = GNM_ITEM_EDIT (item);
 		GtkEditable *ed = GTK_EDITABLE (ie->entry);
 		int target_index, trailing;
 		char const *text = pango_layout_get_text (ie->layout);
@@ -323,7 +326,7 @@ item_edit_button_pressed (GocItem *item, int button, double x, double y)
 static gboolean
 item_edit_motion (GocItem *item, double x, double y)
 {
-	ItemEdit *ie = ITEM_EDIT (item);
+	GnmItemEdit *ie = GNM_ITEM_EDIT (item);
 	if (ie->sel_start >= 0) {
 		GtkEditable *ed = GTK_EDITABLE (ie->entry);
 		int target_index, trailing;
@@ -381,7 +384,7 @@ static gboolean
 item_edit_button_released (GocItem *item, G_GNUC_UNUSED int button,
 			   G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
-	ItemEdit *ie = ITEM_EDIT (item);
+	GnmItemEdit *ie = GNM_ITEM_EDIT (item);
 	if (ie->sel_start >= 0) {
 		ie->sel_start = -1;
 		return TRUE;
@@ -392,7 +395,7 @@ item_edit_button_released (GocItem *item, G_GNUC_UNUSED int button,
 static void
 item_edit_update_bounds (GocItem *item)
 {
-	ItemEdit *ie = ITEM_EDIT (item);
+	GnmItemEdit *ie = GNM_ITEM_EDIT (item);
 	double scale = item->canvas->pixels_per_unit;
 
 	if (ie->gfont != NULL) {
@@ -545,14 +548,14 @@ cb_entry_cursor_event (GocItem *item)
 {
 	/* ensure we draw a cursor when moving quickly no matter what the
 	 * current state is */
-	ITEM_EDIT (item)->cursor_visible = TRUE;
+	GNM_ITEM_EDIT (item)->cursor_visible = TRUE;
 	goc_item_invalidate (item);
 
 	return TRUE;
 }
 
 static int
-cb_item_edit_cursor_blink (ItemEdit *ie)
+cb_item_edit_cursor_blink (GnmItemEdit *ie)
 {
 	GocItem *item = GOC_ITEM (ie);
 
@@ -563,16 +566,16 @@ cb_item_edit_cursor_blink (ItemEdit *ie)
 }
 
 static void
-item_edit_cursor_blink_stop (ItemEdit *ie)
+item_edit_cursor_blink_stop (GnmItemEdit *ie)
 {
-	if (ie->blink_timer != -1) {
+	if (ie->blink_timer != 0) {
 		g_source_remove (ie->blink_timer);
-		ie->blink_timer = -1;
+		ie->blink_timer = 0;
 	}
 }
 
 static void
-item_edit_cursor_blink_start (ItemEdit *ie)
+item_edit_cursor_blink_start (GnmItemEdit *ie)
 {
 	gboolean blink;
 	int	 blink_time;
@@ -590,7 +593,7 @@ item_edit_cursor_blink_start (ItemEdit *ie)
 static void
 item_edit_realize (GocItem *item)
 {
-	ItemEdit *ie = ITEM_EDIT (item);
+	GnmItemEdit *ie = GNM_ITEM_EDIT (item);
 	Sheet const *sheet;
 	GnmPane	*pane;
 	double scale;
@@ -658,7 +661,7 @@ item_edit_realize (GocItem *item)
 static void
 item_edit_unrealize (GocItem *item)
 {
-	ItemEdit *ie = ITEM_EDIT (item);
+	GnmItemEdit *ie = GNM_ITEM_EDIT (item);
 
 	item_edit_cursor_blink_stop (ie);
 
@@ -666,10 +669,7 @@ item_edit_unrealize (GocItem *item)
 	SCG_FOREACH_PANE (ie->scg, pane,
 		gnm_pane_expr_cursor_stop (pane););
 
-	if (ie->layout) {
-		g_object_unref (ie->layout);
-		ie->layout = NULL;
-	}
+	g_clear_object (&ie->layout);
 
 	if (ie->gfont != NULL) {
 		gnm_font_unref (ie->gfont);
@@ -684,7 +684,7 @@ item_edit_unrealize (GocItem *item)
 }
 
 static void
-item_edit_init (ItemEdit *ie)
+gnm_item_edit_init (GnmItemEdit *ie)
 {
 	ie->scg = NULL;
 	ie->pos.col = -1;
@@ -693,13 +693,14 @@ item_edit_init (ItemEdit *ie)
 	ie->style      = NULL;
 	ie->cursor_visible = TRUE;
 	ie->sel_start = -1;
+	ie->blink_timer = 0;
 }
 
 static void
 item_edit_set_property (GObject *gobject, guint param_id,
 			GValue const *value, GParamSpec *pspec)
 {
-	ItemEdit *ie = ITEM_EDIT (gobject);
+	GnmItemEdit *ie = GNM_ITEM_EDIT (gobject);
 
 	switch (param_id) {
 	case ARG_SHEET_CONTROL_GUI: {
@@ -718,7 +719,7 @@ item_edit_set_property (GObject *gobject, guint param_id,
 }
 
 static void
-item_edit_class_init (GObjectClass *gobject_class)
+gnm_item_edit_class_init (GObjectClass *gobject_class)
 {
 	GocItemClass *item_class = (GocItemClass *) gobject_class;
 
@@ -748,6 +749,6 @@ item_edit_class_init (GObjectClass *gobject_class)
 	item_class->button_released = item_edit_button_released;
 }
 
-GSF_CLASS (ItemEdit, item_edit,
-	   item_edit_class_init, item_edit_init,
+GSF_CLASS (GnmItemEdit, gnm_item_edit,
+	   gnm_item_edit_class_init, gnm_item_edit_init,
 	   GOC_TYPE_ITEM)
