@@ -39,6 +39,7 @@
 #include "commands.h"
 #include "hlink.h"
 #include "gui-util.h"
+#include "gnm-i18n.h"
 
 #include <goffice/goffice.h>
 #include <gtk/gtk.h>
@@ -54,12 +55,12 @@
 #endif
 
 typedef enum {
-	ITEM_GRID_NO_SELECTION,
-	ITEM_GRID_SELECTING_CELL_RANGE,
-	ITEM_GRID_SELECTING_FORMULA_RANGE
+	GNM_ITEM_GRID_NO_SELECTION,
+	GNM_ITEM_GRID_SELECTING_CELL_RANGE,
+	GNM_ITEM_GRID_SELECTING_FORMULA_RANGE
 } ItemGridSelectionType;
 
-struct _ItemGrid {
+struct _GnmItemGrid {
 	GocItem canvas_item;
 
 	SheetControlGUI *scg;
@@ -71,25 +72,68 @@ struct _ItemGrid {
 	/* information for the cursor motion handler */
 	guint cursor_timer;
 	gint64 last_x, last_y;
-	GnmHLink *cur_link; /* do not derference, just a pointer */
+	GnmHLink *cur_link; /* do not dereference, just a pointer */
 	GtkWidget *tip;
 	guint tip_timer;
 
 	GdkCursor *cursor_link, *cursor_cross;
 
 	guint32 last_click_time;
+
+	/* Style: */
+	GdkRGBA function_marker_color;
+	GdkRGBA function_marker_border_color;
+	int function_marker_size;
+
+	GdkRGBA pane_divider_color;
+	int pane_divider_width;
+
 };
-typedef GocItemClass ItemGridClass;
+typedef GocItemClass GnmItemGridClass;
 static GocItemClass *parent_class;
 
 enum {
-	ITEM_GRID_PROP_0,
-	ITEM_GRID_PROP_SHEET_CONTROL_GUI,
-	ITEM_GRID_PROP_BOUND
+	GNM_ITEM_GRID_PROP_0,
+	GNM_ITEM_GRID_PROP_SHEET_CONTROL_GUI,
+	GNM_ITEM_GRID_PROP_BOUND
 };
 
 static void
-ig_clear_hlink_tip (ItemGrid *ig)
+ig_reload_style (GnmItemGrid *ig)
+{
+	GocItem *item = GOC_ITEM (ig);
+	GtkStyleContext *context = goc_item_get_style_context (item);
+	GtkBorder border;
+	GtkStateFlags state = GTK_STATE_FLAG_NORMAL;
+	GnmPane *pane = GNM_PANE (item->canvas);
+
+	gtk_style_context_save (context);
+	gtk_style_context_add_region (context, "function-marker", 0);
+	gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL,
+				     &ig->function_marker_color);
+	gtk_style_context_get_border_color (context, state,
+					    &ig->function_marker_border_color);
+	gtk_style_context_restore (context);
+
+	gtk_style_context_save (context);
+	gtk_style_context_add_region (context, "pane-divider", 0);
+	gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL,
+				     &ig->pane_divider_color);
+	gtk_style_context_get_border (context, GTK_STATE_FLAG_NORMAL, &border);
+	ig->pane_divider_width = border.top;  /* Hack? */
+	gtk_style_context_restore (context);
+
+	/* ---------------------------------------- */
+
+	context = gtk_widget_get_style_context (GTK_WIDGET (pane));
+	gtk_widget_style_get (GTK_WIDGET (pane),
+			      "function-indicator-size",
+			      &ig->function_marker_size,
+			      NULL);
+}
+
+static void
+ig_clear_hlink_tip (GnmItemGrid *ig)
 {
 	if (ig->tip_timer != 0) {
 		g_source_remove (ig->tip_timer);
@@ -105,7 +149,7 @@ ig_clear_hlink_tip (ItemGrid *ig)
 static void
 item_grid_finalize (GObject *object)
 {
-	ItemGrid *ig = ITEM_GRID (object);
+	GnmItemGrid *ig = GNM_ITEM_GRID (object);
 
 	if (ig->cursor_timer != 0) {
 		g_source_remove (ig->cursor_timer);
@@ -118,7 +162,7 @@ item_grid_finalize (GObject *object)
 }
 
 static gint
-cb_cursor_motion (ItemGrid *ig)
+cb_cursor_motion (GnmItemGrid *ig)
 {
 	Sheet const *sheet = scg_sheet (ig->scg);
 	GocCanvas *canvas = ig->canvas_item.canvas;
@@ -154,12 +198,12 @@ static void
 item_grid_realize (GocItem *item)
 {
 	GdkDisplay *display;
-	ItemGrid   *ig;
+	GnmItemGrid   *ig;
 
-	if (parent_class->realize)
-		parent_class->realize (item);
+	parent_class->realize (item);
 
-	ig = ITEM_GRID (item);
+	ig = GNM_ITEM_GRID (item);
+	ig_reload_style (ig);
 
 	display = gtk_widget_get_display (GTK_WIDGET (item->canvas));
 	ig->cursor_link  = gdk_cursor_new_for_display (display, GDK_HAND2);
@@ -172,20 +216,10 @@ item_grid_realize (GocItem *item)
 static void
 item_grid_unrealize (GocItem *item)
 {
-	ItemGrid *ig = ITEM_GRID (item);
-
-	if (ig->cursor_link) {
-		g_object_unref (ig->cursor_link);
-		ig->cursor_link = NULL;
-	}
-
-	if (ig->cursor_cross) {
-		g_object_unref (ig->cursor_cross);
-		ig->cursor_cross = NULL;
-	}
-
-	if (parent_class->unrealize)
-		parent_class->unrealize (item);
+	GnmItemGrid *ig = GNM_ITEM_GRID (item);
+	g_clear_object (&ig->cursor_link);
+	g_clear_object (&ig->cursor_cross);
+	parent_class->unrealize (item);
 }
 
 static void
@@ -198,9 +232,11 @@ item_grid_update_bounds (GocItem *item)
 }
 
 static void
-draw_function_marker (GnmCell const *cell, cairo_t *cr,
+draw_function_marker (GnmItemGrid *ig,
+		      GnmCell const *cell, cairo_t *cr,
 		      double x, double y, double w, double h, int const dir)
 {
+	int size = ig->function_marker_size;
 	if (cell == NULL || !gnm_cell_has_expr (cell))
 		return;
 
@@ -211,24 +247,24 @@ draw_function_marker (GnmCell const *cell, cairo_t *cr,
 	cairo_new_path (cr);
 	if (dir > 0) {
 		cairo_move_to (cr, x, y);
-		cairo_line_to (cr, x + 10., y);
-		cairo_arc (cr, x, y, 10., 0., M_PI / 2.);
+		cairo_line_to (cr, x + size, y);
+		cairo_arc (cr, x, y, size, 0., M_PI / 2.);
 	} else {
 		cairo_move_to (cr, x + w, y);
-		cairo_line_to (cr, x + w, y + 10.);
-		cairo_arc (cr, x + w, y, 10., M_PI/2., M_PI);
+		cairo_line_to (cr, x + w, y + size);
+		cairo_arc (cr, x + w, y, size, M_PI/2., M_PI);
 	}
 	cairo_close_path (cr);
-	cairo_set_source_rgb(cr, 0.0, 1.0, 0.0);
+	gdk_cairo_set_source_rgba (cr, &ig->function_marker_color);
 	cairo_fill_preserve (cr);
-	cairo_set_source_rgb(cr, 0.3, 0.3, 0.3);
+	gdk_cairo_set_source_rgba (cr, &ig->function_marker_border_color);
 	cairo_set_line_width (cr, 0.5);
 	cairo_stroke (cr);
 	cairo_restore (cr);
 }
 
 static void
-item_grid_draw_merged_range (cairo_t *cr, ItemGrid *ig,
+item_grid_draw_merged_range (cairo_t *cr, GnmItemGrid *ig,
 			     int start_x, int start_y,
 			     GnmRange const *view, GnmRange const *range,
 			     gboolean draw_selection, GtkStyleContext *ctxt)
@@ -278,8 +314,8 @@ item_grid_draw_merged_range (cairo_t *cr, ItemGrid *ig,
 	}
 
 	/* Check for background THEN selection */
-	if (gnumeric_background_set (style, cr,
-				     is_selected, ctxt) || is_selected) {
+	if (gnumeric_background_set (style, cr, is_selected, ctxt) ||
+	    is_selected) {
 		/* Remember X excludes the far pixels */
 		if (dir > 0)
 			cairo_rectangle (cr, l, t, r-l+1, b-t+1);
@@ -311,14 +347,14 @@ item_grid_draw_merged_range (cairo_t *cr, ItemGrid *ig,
 
 		if (dir > 0) {
 			if (show_function_cell_markers)
-				draw_function_marker (cell, cr, l, t,
+				draw_function_marker (ig, cell, cr, l, t,
 						      r - l, b - t, dir);
 			cell_draw (cell, cr,
 				   l, t, r - l, b - t, -1,
 				   show_extension_markers);
 		} else {
 			if (show_function_cell_markers)
-				draw_function_marker (cell, cr, r, t,
+				draw_function_marker (ig, cell, cr, r, t,
 						      l - r, b - t, dir);
 			cell_draw (cell, cr,
 				   r, t, l - r, b - t, -1,
@@ -332,7 +368,7 @@ item_grid_draw_merged_range (cairo_t *cr, ItemGrid *ig,
 }
 
 static void
-item_grid_draw_background (cairo_t *cr, ItemGrid *ig,
+item_grid_draw_background (cairo_t *cr, GnmItemGrid *ig,
 			   GnmStyle const *style,
 			   int col, int row, int x, int y, int w, int h,
 			   gboolean draw_selection, GtkStyleContext *ctxt)
@@ -342,8 +378,7 @@ item_grid_draw_background (cairo_t *cr, ItemGrid *ig,
 		(sv->edit_pos.col != col || sv->edit_pos.row != row) &&
 		sv_is_pos_selected (sv, col, row);
 	gboolean const has_back =
-		gnumeric_background_set (style, cr,
-					 is_selected, ctxt);
+		gnumeric_background_set (style, cr, is_selected, ctxt);
 
 #if DEBUG_SELECTION_PAINT
 	if (is_selected) {
@@ -366,20 +401,22 @@ merged_col_cmp (GnmRange const *a, GnmRange const *b)
 }
 
 static void
-ig_cairo_draw_bound (cairo_t* cr, int x0, int y0, int x1, int y1)
+ig_cairo_draw_bound (GnmItemGrid *ig, cairo_t* cr, int x0, int y0, int x1, int y1)
 {
-	cairo_set_line_width (cr, 1.);
+	double width = ig->pane_divider_width;
+	cairo_set_line_width (cr, width);
 	cairo_set_dash (cr, NULL, 0, 0.);
 	cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
 	cairo_set_line_join (cr, CAIRO_LINE_JOIN_MITER);
-	cairo_set_source_rgba (cr, 0.2, 0.2, 0.2, 1.);
-	cairo_move_to (cr, x0 - .5, y0 - .5);
-	cairo_line_to (cr, x1 - .5, y1 - .5);
+	gdk_cairo_set_source_rgba (cr, &ig->pane_divider_color);
+	cairo_move_to (cr, x0 - width / 2, y0 - width / 2);
+	cairo_line_to (cr, x1 - width / 2, y1 - width / 2);
 	cairo_stroke (cr);
 }
 
 static gboolean
-item_grid_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0, double x_1, double y_1)
+item_grid_draw_region (GocItem const *item, cairo_t *cr,
+		       double x_0, double y_0, double x_1, double y_1)
 {
 	GocCanvas *canvas = item->canvas;
 	double scale = canvas->pixels_per_unit;
@@ -390,7 +427,7 @@ item_grid_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 	Sheet const *sheet = scg_sheet (pane->simple.scg);
 	WBCGtk *wbcg = scg_wbcg (pane->simple.scg);
 	GnmCell const * const edit_cell = wbcg->editing_cell;
-	ItemGrid *ig = ITEM_GRID (item);
+	GnmItemGrid *ig = GNM_ITEM_GRID (item);
 	ColRowInfo const *ri = NULL, *next_ri = NULL;
 	int const dir = sheet->text_is_rtl ? -1 : 1;
 	SheetView const *sv = scg_view (ig->scg);
@@ -438,7 +475,7 @@ item_grid_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 
 #if 0
 	g_printerr ("%s:", cell_coord_name (start_col, start_row));
-	g_printerr ("%s <= %d vs %d", cell_coord_name(end_col, end_row), y, expose->area.y);
+	g_printerr ("%s <= %ld vs ???", cell_coord_name(end_col, end_row), (long)y);
 	g_printerr (" [%s]\n", cell_coord_name (ig->bound.end.col, ig->bound.end.row));
 
 #endif
@@ -477,10 +514,11 @@ item_grid_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 
 	/* Fill entire region with default background (even past far edge) */
 	cairo_save (cr);
-	/* FIXME: we previously used gs_white */
-	cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (GO_COLOR_WHITE));
-	cairo_rectangle (cr, x0, y0, width, height);
-	cairo_fill (cr);
+	gtk_render_background (goc_item_get_style_context (item),
+			       cr,
+			       x0 - canvas->scroll_x1 * scale,
+			       y0 - canvas->scroll_y1 * scale,
+			       width, height);
 	cairo_restore (cr);
 
 	/* Get ordered list of merged regions */
@@ -670,7 +708,7 @@ plain_draw : /* a quick hack to deal with 142267 */
 			item_grid_draw_background (cr, ig,
 				style, col, row, x, y,
 				ci->size_pixels, ri->size_pixels,
-						   draw_selection, ctxt);
+				draw_selection, ctxt);
 
 
 			/* Is this part of a span?
@@ -689,7 +727,7 @@ plain_draw : /* a quick hack to deal with 142267 */
 				GnmCell const *cell = sheet_cell_get (sheet, col, row);
 				if (!gnm_cell_is_empty (cell) && cell != edit_cell) {
 					if (show_function_cell_markers)
-						draw_function_marker (cell, cr, x, y,
+						draw_function_marker (ig, cell, cr, x, y,
 								      ci->size_pixels,
 								      ri->size_pixels,
 								      dir);
@@ -747,7 +785,7 @@ plain_draw : /* a quick hack to deal with 142267 */
 				}
 
 				if (show_function_cell_markers)
-					draw_function_marker (cell, cr, real_x, y,
+					draw_function_marker (ig, cell, cr, real_x, y,
 							      tmp_width,
 							      ri->size_pixels, dir);
 				cell_draw (cell, cr,
@@ -792,13 +830,13 @@ plain_draw : /* a quick hack to deal with 142267 */
 	}
 
 	if (ig->bound.start.row > 0 && start_y < 1)
-		ig_cairo_draw_bound (cr, start_x, 1, x, 1);
+		ig_cairo_draw_bound (ig, cr, start_x, 1, x, 1);
 	if (ig->bound.start.col > 0) {
 		if (canvas->direction == GOC_DIRECTION_RTL && start_x >= goc_canvas_get_width (canvas)) {
 			x = goc_canvas_get_width (canvas);
-			ig_cairo_draw_bound (cr, x, start_y, x, y);
+			ig_cairo_draw_bound (ig, cr, x, start_y, x, y);
 		} else if (canvas->direction == GOC_DIRECTION_LTR && start_x < 1)
-			ig_cairo_draw_bound (cr, 1, start_y, 1, y);
+			ig_cairo_draw_bound (ig, cr, 1, start_y, 1, y);
 	}
 
 	gtk_widget_destroy (entry);
@@ -821,7 +859,7 @@ item_grid_distance (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED double
 /***********************************************************************/
 
 static gboolean
-ig_obj_create_begin (ItemGrid *ig, int button, gint64 x, gint64 y)
+ig_obj_create_begin (GnmItemGrid *ig, int button, gint64 x, gint64 y)
 {
 	GnmPane *pane = GNM_PANE (GOC_ITEM (ig)->canvas);
 	SheetObject *so = ig->scg->wbcg->new_object;
@@ -848,7 +886,7 @@ ig_obj_create_begin (ItemGrid *ig, int button, gint64 x, gint64 y)
 static int
 item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 {
-	ItemGrid *ig = ITEM_GRID (item);
+	GnmItemGrid *ig = GNM_ITEM_GRID (item);
 	GocCanvas    *canvas = item->canvas;
 	GnmPane *pane = GNM_PANE (canvas);
 	SheetControlGUI *scg = ig->scg;
@@ -888,7 +926,7 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 	 * reset the location to a new place, or extend the selection.
 	 */
 	if (button == 1 && scg->rangesel.active) {
-		ig->selecting = ITEM_GRID_SELECTING_FORMULA_RANGE;
+		ig->selecting = GNM_ITEM_GRID_SELECTING_FORMULA_RANGE;
 		if (event->state & GDK_SHIFT_MASK)
 			scg_rangesel_extend_to (scg, pos.col, pos.row);
 		else
@@ -905,7 +943,7 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 	 */
 	if (button == 1 && wbcg_rangesel_possible (wbcg)) {
 		scg_rangesel_start (scg, pos.col, pos.row, pos.col, pos.row);
-		ig->selecting = ITEM_GRID_SELECTING_FORMULA_RANGE;
+		ig->selecting = GNM_ITEM_GRID_SELECTING_FORMULA_RANGE;
 		gnm_pane_slide_init (pane);
 		gnm_simple_canvas_grab (item,
 			GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
@@ -967,7 +1005,7 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 		}
 
 		ig->last_click_time = event->time;
-		ig->selecting = ITEM_GRID_SELECTING_CELL_RANGE;
+		ig->selecting = GNM_ITEM_GRID_SELECTING_CELL_RANGE;
 		gnm_pane_slide_init (pane);
 		gnm_simple_canvas_grab (item,
 			GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
@@ -1006,7 +1044,7 @@ cb_extend_expr_range (GnmPane *pane, GnmPaneSlideInfo const *info)
 }
 
 static gint
-cb_cursor_come_to_rest (ItemGrid *ig)
+cb_cursor_come_to_rest (GnmItemGrid *ig)
 {
 	Sheet const *sheet = scg_sheet (ig->scg);
 	GocCanvas *canvas = ig->canvas_item.canvas;
@@ -1046,13 +1084,13 @@ cb_cursor_come_to_rest (ItemGrid *ig)
 static gboolean
 item_grid_motion (GocItem *item, double x_, double y_)
 {
-	ItemGrid *ig = ITEM_GRID (item);
+	GnmItemGrid *ig = GNM_ITEM_GRID (item);
 	GocCanvas *canvas = item->canvas;
 	GnmPane   *pane = GNM_PANE (canvas);
 	GnmPaneSlideHandler slide_handler = NULL;
 	gint64 x = x_ * canvas->pixels_per_unit, y = y_ * canvas->pixels_per_unit;
 	switch (ig->selecting) {
-	case ITEM_GRID_NO_SELECTION:
+	case GNM_ITEM_GRID_NO_SELECTION:
 		if (ig->cursor_timer == 0)
 			ig->cursor_timer = g_timeout_add (100,
 				(GSourceFunc)cb_cursor_motion, ig);
@@ -1063,10 +1101,10 @@ item_grid_motion (GocItem *item, double x_, double y_)
 		ig->last_x = x;
 		ig->last_y = y;
 		return TRUE;
-	case ITEM_GRID_SELECTING_CELL_RANGE :
+	case GNM_ITEM_GRID_SELECTING_CELL_RANGE :
 		slide_handler = &cb_extend_cell_range;
 		break;
-	case ITEM_GRID_SELECTING_FORMULA_RANGE :
+	case GNM_ITEM_GRID_SELECTING_FORMULA_RANGE :
 		slide_handler = &cb_extend_expr_range;
 		break;
 	default:
@@ -1083,7 +1121,7 @@ item_grid_motion (GocItem *item, double x_, double y_)
 static gboolean
 item_grid_button_released (GocItem *item, int button, G_GNUC_UNUSED double x_, G_GNUC_UNUSED double y_)
 {
-	ItemGrid *ig = ITEM_GRID (item);
+	GnmItemGrid *ig = GNM_ITEM_GRID (item);
 	GnmPane  *pane = GNM_PANE (item->canvas);
 	SheetControlGUI *scg = ig->scg;
 	Sheet *sheet = scg_sheet (scg);
@@ -1096,16 +1134,16 @@ item_grid_button_released (GocItem *item, int button, G_GNUC_UNUSED double x_, G
 	gnm_pane_slide_stop (pane);
 
 	switch (selecting) {
-	case ITEM_GRID_NO_SELECTION:
+	case GNM_ITEM_GRID_NO_SELECTION:
 		return TRUE;
 
-	case ITEM_GRID_SELECTING_FORMULA_RANGE :
+	case GNM_ITEM_GRID_SELECTING_FORMULA_RANGE :
 /*  Removal of this code (2 lines)                                                */
 /*  should fix http://bugzilla.gnome.org/show_bug.cgi?id=63485                    */
 /*			sheet_make_cell_visible (sheet,                           */
 /*				sheet->edit_pos.col, sheet->edit_pos.row, FALSE); */
 		/* Fall through */
-	case ITEM_GRID_SELECTING_CELL_RANGE :
+	case GNM_ITEM_GRID_SELECTING_CELL_RANGE :
 		sv_selection_simplify (scg_view (scg));
 		wb_view_selection_desc (
 			wb_control_view (scg_wbc (scg)), TRUE, NULL);
@@ -1115,14 +1153,14 @@ item_grid_button_released (GocItem *item, int button, G_GNUC_UNUSED double x_, G
 		g_assert_not_reached ();
 	}
 
-	ig->selecting = ITEM_GRID_NO_SELECTION;
+	ig->selecting = GNM_ITEM_GRID_NO_SELECTION;
 	gnm_simple_canvas_ungrab (item, event->time);
 
-	if (selecting == ITEM_GRID_SELECTING_FORMULA_RANGE)
+	if (selecting == GNM_ITEM_GRID_SELECTING_FORMULA_RANGE)
 		gnm_expr_entry_signal_update (
 			wbcg_get_entry_logical (scg_wbcg (scg)), TRUE);
 
-	if (selecting == ITEM_GRID_SELECTING_CELL_RANGE) {
+	if (selecting == GNM_ITEM_GRID_SELECTING_CELL_RANGE) {
 		GnmCellPos const *pos = sv_is_singleton_selected (scg_view (scg));
 		if (pos != NULL) {
 			GnmHLink *link;
@@ -1138,7 +1176,7 @@ item_grid_button_released (GocItem *item, int button, G_GNUC_UNUSED double x_, G
 static gboolean
 item_grid_enter_notify (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
-	ItemGrid  *ig = ITEM_GRID (item);
+	GnmItemGrid  *ig = GNM_ITEM_GRID (item);
 	scg_set_display_cursor (ig->scg);
 	return TRUE;
 }
@@ -1146,7 +1184,7 @@ item_grid_enter_notify (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED dou
 static gboolean
 item_grid_leave_notify (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
-	ItemGrid  *ig = ITEM_GRID (item);
+	GnmItemGrid  *ig = GNM_ITEM_GRID (item);
 	ig_clear_hlink_tip (ig);
 	if (ig->cursor_timer != 0) {
 		g_source_remove (ig->cursor_timer);
@@ -1156,7 +1194,7 @@ item_grid_leave_notify (GocItem *item, G_GNUC_UNUSED double x, G_GNUC_UNUSED dou
 }
 
 static void
-item_grid_init (ItemGrid *ig)
+gnm_item_grid_init (GnmItemGrid *ig)
 {
 	GocItem *item = GOC_ITEM (ig);
 
@@ -1165,7 +1203,7 @@ item_grid_init (ItemGrid *ig)
 	item->x1 = 0;
 	item->y1 = 0;
 
-	ig->selecting = ITEM_GRID_NO_SELECTION;
+	ig->selecting = GNM_ITEM_GRID_NO_SELECTION;
 	/* We need something at least as big as any sheet.  */
 	ig->bound.start.col = ig->bound.start.row = 0;
 	ig->bound.end.col = GNM_MAX_COLS - 1;
@@ -1180,15 +1218,15 @@ static void
 item_grid_set_property (GObject *obj, guint param_id,
 			GValue const *value, G_GNUC_UNUSED GParamSpec *pspec)
 {
-	ItemGrid *ig = ITEM_GRID (obj);
+	GnmItemGrid *ig = GNM_ITEM_GRID (obj);
 	GnmRange const *r;
 
 	switch (param_id) {
-	case ITEM_GRID_PROP_SHEET_CONTROL_GUI :
+	case GNM_ITEM_GRID_PROP_SHEET_CONTROL_GUI :
 		ig->scg = g_value_get_object (value);
 		break;
 
-	case ITEM_GRID_PROP_BOUND :
+	case GNM_ITEM_GRID_PROP_BOUND :
 		r = g_value_get_pointer (value);
 		g_return_if_fail (r != NULL);
 		ig->bound =  *r;
@@ -1197,7 +1235,7 @@ item_grid_set_property (GObject *obj, guint param_id,
 }
 
 static void
-item_grid_class_init (GObjectClass *gobject_klass)
+gnm_item_grid_class_init (GObjectClass *gobject_klass)
 {
 	GocItemClass *item_klass = (GocItemClass *) gobject_klass;
 
@@ -1205,12 +1243,12 @@ item_grid_class_init (GObjectClass *gobject_klass)
 
 	gobject_klass->finalize     = item_grid_finalize;
 	gobject_klass->set_property = item_grid_set_property;
-	g_object_class_install_property (gobject_klass, ITEM_GRID_PROP_SHEET_CONTROL_GUI,
+	g_object_class_install_property (gobject_klass, GNM_ITEM_GRID_PROP_SHEET_CONTROL_GUI,
 		g_param_spec_object ("SheetControlGUI", "SheetControlGUI",
 			"the sheet control gui controlling the item",
 			SHEET_CONTROL_GUI_TYPE,
                         GSF_PARAM_STATIC | G_PARAM_WRITABLE));
-	g_object_class_install_property (gobject_klass, ITEM_GRID_PROP_BOUND,
+	g_object_class_install_property (gobject_klass, GNM_ITEM_GRID_PROP_BOUND,
 		g_param_spec_pointer ("bound", "Bound",
 			"The display bounds",
 			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
@@ -1227,6 +1265,6 @@ item_grid_class_init (GObjectClass *gobject_klass)
 	item_klass->distance        = item_grid_distance;
 }
 
-GSF_CLASS (ItemGrid, item_grid,
-	   item_grid_class_init, item_grid_init,
+GSF_CLASS (GnmItemGrid, gnm_item_grid,
+	   gnm_item_grid_class_init, gnm_item_grid_init,
 	   GOC_TYPE_ITEM)
