@@ -34,6 +34,9 @@ gnm_float gnm_trunc (gnm_float x);
 gnm_float logfbit (gnm_float x);
 gnm_float logspace_add (gnm_float logx, gnm_float logy);
 gnm_float logspace_sub (gnm_float logx, gnm_float logy);
+gnm_float stirlerr(gnm_float n);
+gnm_float gnm_owent (gnm_float h, gnm_float a);
+gnm_float pochhammer (gnm_float x, gnm_float n, gboolean give_log);
 
 gnm_float gnm_cot (gnm_float x);
 gnm_float gnm_acot (gnm_float x);
@@ -67,16 +70,16 @@ gnm_float qgamma (gnm_float p, gnm_float shape, gnm_float scale, gboolean lower_
 
 /* The beta distribution.  */
 gnm_float dbeta (gnm_float x, gnm_float a, gnm_float b, gboolean give_log);
-gnm_float pbeta (gnm_float x, gnm_float pin, gnm_float qin, gboolean lower_tail, gboolean log_p);
-gnm_float qbeta (gnm_float alpha, gnm_float p, gnm_float q, gboolean lower_tail, gboolean log_p);
+gnm_float pbeta (gnm_float x, gnm_float a, gnm_float b, gboolean lower_tail, gboolean log_p);
+gnm_float qbeta (gnm_float p, gnm_float a, gnm_float b, gboolean lower_tail, gboolean log_p);
 
 /* The t distribution.  */
 gnm_float dt (gnm_float x, gnm_float n, gboolean give_log);
 gnm_float pt (gnm_float x, gnm_float n, gboolean lower_tail, gboolean log_p);
-gnm_float qt (gnm_float p, gnm_float ndf, gboolean lower_tail, gboolean log_p);
+gnm_float qt (gnm_float p, gnm_float n, gboolean lower_tail, gboolean log_p);
 
 /* The F distribution.  */
-gnm_float df (gnm_float x, gnm_float m, gnm_float n, gboolean give_log);
+gnm_float df (gnm_float x, gnm_float n1, gnm_float n2, gboolean give_log);
 gnm_float pf (gnm_float x, gnm_float n1, gnm_float n2, gboolean lower_tail, gboolean log_p);
 gnm_float qf (gnm_float p, gnm_float n1, gnm_float n2, gboolean lower_tail, gboolean log_p);
 
@@ -107,19 +110,19 @@ gnm_float pbinom2 (gnm_float x0, gnm_float x1, gnm_float n, gnm_float p);
 gnm_float qbinom (gnm_float p, gnm_float n, gnm_float psuc, gboolean lower_tail, gboolean log_p);
 
 /* Negative binomial distribution.  */
-gnm_float dnbinom (gnm_float x, gnm_float n, gnm_float p, gboolean give_log);
-gnm_float pnbinom (gnm_float x, gnm_float n, gnm_float p, gboolean lower_tail, gboolean log_p);
-gnm_float qnbinom (gnm_float p, gnm_float n, gnm_float pr, gboolean lower_tail, gboolean log_p);
+gnm_float dnbinom (gnm_float x, gnm_float n, gnm_float psuc, gboolean give_log);
+gnm_float pnbinom (gnm_float x, gnm_float n, gnm_float psuc, gboolean lower_tail, gboolean log_p);
+gnm_float qnbinom (gnm_float p, gnm_float n, gnm_float psuc, gboolean lower_tail, gboolean log_p);
 
 /* Hyper-geometrical distribution.  */
 gnm_float dhyper (gnm_float x, gnm_float r, gnm_float b, gnm_float n, gboolean give_log);
-gnm_float phyper (gnm_float x, gnm_float NR, gnm_float NB, gnm_float n, gboolean lower_tail, gboolean log_p);
-gnm_float qhyper (gnm_float p, gnm_float NR, gnm_float NB, gnm_float n, gboolean lower_tail, gboolean log_p);
+gnm_float phyper (gnm_float x, gnm_float r, gnm_float b, gnm_float n, gboolean lower_tail, gboolean log_p);
+gnm_float qhyper (gnm_float p, gnm_float r, gnm_float b, gnm_float n, gboolean lower_tail, gboolean log_p);
 
-/* Geometrical distribution.  */
-gnm_float dgeom (gnm_float x, gnm_float p, gboolean give_log);
-gnm_float pgeom (gnm_float x, gnm_float p, gboolean lower_tail, gboolean log_p);
-gnm_float qgeom (gnm_float p, gnm_float prob, gboolean lower_tail, gboolean log_p);
+/* Geometric distribution.  */
+gnm_float dgeom (gnm_float x, gnm_float psuc, gboolean give_log);
+gnm_float pgeom (gnm_float x, gnm_float psuc, gboolean lower_tail, gboolean log_p);
+gnm_float qgeom (gnm_float p, gnm_float psuc, gboolean lower_tail, gboolean log_p);
 
 /* Cauchy distribution.  */
 gnm_float dcauchy (gnm_float x, gnm_float location, gnm_float scale, gboolean give_log);
