@@ -167,7 +167,7 @@ cb_graph_size_changed (GocItem *item, GtkAllocation *allocation)
 	h = print_info_get_paper_height (pi, GTK_UNIT_POINTS);
 	print_info_get_margins (pi, &top, &bottom, &left, &right, &edge_to_below_header, &edge_to_above_footer);
 	w -= left + right;
-	h -= top + bottom + edge_to_above_footer + edge_to_below_header;
+	h -= edge_to_above_footer + edge_to_below_header;
 	g_object_get (item, "renderer", &rend, NULL);
 	g_object_get (rend, "model", &graph, NULL);
 	gog_graph_set_size (graph, w, h);
@@ -658,7 +658,7 @@ sheet_object_graph_set_gog (SheetObject *so, GogGraph *graph)
 		if (sog->graph == graph)
 			return;
 
-		g_object_ref (G_OBJECT (graph));
+		g_object_ref (graph);
 	} else
 		graph = g_object_new (GOG_TYPE_GRAPH, NULL);
 
@@ -744,14 +744,18 @@ sheet_object_graph_guru (WBCGtk *wbcg, GogGraph *graph,
 		GO_CMD_CONTEXT (wbcg), closure);
 	if (!graph) {
 		GnmGraphDataClosure *data = (GnmGraphDataClosure *) g_new0 (GnmGraphDataClosure, 1);
-		GtkWidget *custom = gtk_table_new (2, 3, FALSE), *w;
+		GtkWidget *custom = gtk_grid_new (), *w;
 		GObject *object;
 
 		data->dalloc = GOG_DATA_ALLOCATOR (wbcg);
-		g_object_set (custom, "row-spacing", 6, "column-spacing", 12, NULL);
+		g_object_set (custom,
+		              "row-spacing", 6,
+		              "column-spacing", 12,
+		              "margin-top", 6,
+		              NULL);
 		w = gtk_label_new (_("Series as:"));
 		g_object_set (w, "xalign", 0., NULL);
-		gtk_table_attach (GTK_TABLE (custom), w, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+		gtk_grid_attach (GTK_GRID (custom), w, 0, 0, 1, 1);
 		w = gtk_combo_box_text_new ();
 		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (w), _("Auto"));
 		/*Translators: Series as "Columns"*/
@@ -760,13 +764,13 @@ sheet_object_graph_guru (WBCGtk *wbcg, GogGraph *graph,
 		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (w), C_("graph", "Rows"));
 		gtk_combo_box_set_active (GTK_COMBO_BOX (w), 0);
 		g_signal_connect (G_OBJECT (w), "changed", G_CALLBACK (cb_selection_mode_changed), data);
-		gtk_table_attach (GTK_TABLE (custom), w, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+		gtk_grid_attach (GTK_GRID (custom), w, 1, 0, 1, 1);
 		w = gtk_check_button_new_with_label (_("Use first series as shared abscissa"));
 		g_signal_connect (G_OBJECT (w), "toggled", G_CALLBACK (cb_shared_mode_changed), data);
-		gtk_table_attach (GTK_TABLE (custom), w, 0, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+		gtk_grid_attach (GTK_GRID (custom), w, 0, 1, 2, 1);
 		w = gtk_check_button_new_with_label (_("New graph sheet"));
 		g_signal_connect (G_OBJECT (w), "toggled", G_CALLBACK (cb_sheet_target_changed), data);
-		gtk_table_attach (GTK_TABLE (custom), w, 0, 2, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
+		gtk_grid_attach (GTK_GRID (custom), w, 0, 2, 2, 1);
 		data->obj = G_OBJECT (custom);
 		gog_guru_add_custom_widget (dialog, custom);
 		object = (GObject*) g_object_get_data (data->obj, "graph");
@@ -787,14 +791,15 @@ sheet_object_graph_guru (WBCGtk *wbcg, GogGraph *graph,
 }
 
 /**
- * @so: #SheetObject
+ * sheet_object_graph_ensure_size:
+ * @sog: #SheetObject
  *
  * Updates the size of the graph item in the canvas for graph sheets objects.
  */
 void
-sheet_object_graph_ensure_size (SheetObject *so)
+sheet_object_graph_ensure_size (SheetObject *sog)
 {
-	GList *ptr = so->realized_list;
+	GList *ptr = sog->realized_list;
 	while (ptr) {
 		cb_post_new_view (GOC_ITEM (GOC_GROUP (ptr->data)->children->data));
 		ptr = ptr->next;
@@ -928,7 +933,7 @@ dim_start (GsfXMLIn *xin, xmlChar const **attrs)
 {
 	GuppiReadState *state = (GuppiReadState *) xin->user_state;
 	unsigned i, id = 0;
-	char const *name = NULL;
+	char const *name = "?";
 	GogMSDimType type = GOG_MS_DIM_LABELS;
 	GogPlotDesc const *desc = gog_plot_description (state->plot);
 	GError *err = NULL;
@@ -949,7 +954,6 @@ dim_start (GsfXMLIn *xin, xmlChar const **attrs)
 		if (desc->series.dim[i].ms_type == type) {
 			GOData *data = g_object_ref (g_ptr_array_index (state->data, id));
 			gog_dataset_set_dim (GOG_DATASET (state->cur), i,data,
-			                     //g_object_ref (g_ptr_array_index (state->data, id)),
 			                     &err);
 			break;
 		}
