@@ -3,6 +3,7 @@
  * sheet-style.c: storage mechanism for styles and eventually cells.
  *
  * Copyright (C) 2000-2006 Jody Goldberg (jody@gnome.org)
+ * Copyright 2013 Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -106,21 +107,21 @@ sh_insert (GnmStyleHash *h, GnmStyle *st)
 	}
 }
 
-static void
-sh_foreach (GnmStyleHash *h, GHFunc func, gpointer user)
+static GSList *
+sh_all_styles (GnmStyleHash *h)
 {
 	GHashTableIter iter;
 	gpointer value;
+	GSList *res = NULL;
 
 	g_hash_table_iter_init (&iter, h);
 	while (g_hash_table_iter_next (&iter, NULL, &value)) {
 		GSList *l = value;
-		while (l) {
-			GnmStyle *st = l->data;
-			func (st, st, user);
-			l = l->next;
-		}
+		for (; l; l = l->next)
+			res = g_slist_prepend (res, l->data);
 	}
+
+	return res;
 }
 
 static GnmStyleHash *
@@ -169,7 +170,7 @@ cell_tile_optimize (CellTile **tile, int level, CellTileOptimize *data,
 		    int ccol, int crow);
 
 
-/**
+/*
  * sheet_style_unlink
  * For internal use only
  */
@@ -181,10 +182,9 @@ sheet_style_unlink (Sheet *sheet, GnmStyle *st)
 }
 
 /**
- * sheet_style_find :
- *
+ * sheet_style_find:
  * @sheet: (transfer full): the sheet
- * @s: a style
+ * @st: a style
  *
  * Looks up a style from the sheets collection.  Linking if necessary.
  * ABSORBS the reference and adds a link.
@@ -238,26 +238,28 @@ pstyle_set_border (GnmStyle *st, GnmBorder *border,
  * by caching and rereferencing the merged result for repeated styles.
  */
 typedef struct {
-	GnmStyle	   *new_style;
-	GnmStyle	   *pstyle;
+	GnmStyle   *new_style;
+	GnmStyle   *pstyle;
 	GHashTable *cache;
 	Sheet	   *sheet;
 } ReplacementStyle;
 
-static ReplacementStyle *
-rstyle_ctor (ReplacementStyle *res, GnmStyle *new_style, GnmStyle *pstyle, Sheet *sheet)
+static void
+rstyle_ctor_style (ReplacementStyle *res, GnmStyle *new_style, Sheet *sheet)
 {
 	res->sheet = sheet;
-	if (new_style != NULL) {
-		res->new_style = sheet_style_find (sheet, new_style);
-		res->pstyle = NULL;
-		res->cache = NULL;
-	} else {
-		res->new_style = NULL;
-		res->pstyle = pstyle;
-		res->cache = g_hash_table_new (g_direct_hash, g_direct_equal);
-	}
-	return res;
+	res->new_style = sheet_style_find (sheet, new_style);
+	res->pstyle = NULL;
+	res->cache = NULL;
+}
+
+static void
+rstyle_ctor_pstyle (ReplacementStyle *res, GnmStyle *pstyle, Sheet *sheet)
+{
+	res->sheet = sheet;
+	res->new_style = NULL;
+	res->pstyle = pstyle;
+	res->cache = g_hash_table_new (g_direct_hash, g_direct_equal);
 }
 
 static void
@@ -285,13 +287,13 @@ rstyle_dtor (ReplacementStyle *rs)
 	}
 }
 
-/**
- * rstyle_apply :  Utility routine that is at the core of applying partial
+/*
+ * rstyle_apply:  Utility routine that is at the core of applying partial
  * styles or storing complete styles.  It will eventually be smarter
  * and will maintain the cache of styles associated with each sheet
  */
 static void
-rstyle_apply (GnmStyle **old, ReplacementStyle *rs)
+rstyle_apply (GnmStyle **old, ReplacementStyle *rs, GnmRange const *r)
 {
 	GnmStyle *s;
 	g_return_if_fail (old != NULL);
@@ -301,7 +303,7 @@ rstyle_apply (GnmStyle **old, ReplacementStyle *rs)
 		/* Cache the merged styles keeping a reference to the originals
 		 * just in case all instances change.
 		 */
-		s = (GnmStyle *)g_hash_table_lookup (rs->cache, *old);
+		s = g_hash_table_lookup (rs->cache, *old);
 		if (s == NULL) {
 			GnmStyle *tmp = gnm_style_new_merged (*old, rs->pstyle);
 			s = sheet_style_find (rs->sheet, tmp);
@@ -312,9 +314,14 @@ rstyle_apply (GnmStyle **old, ReplacementStyle *rs)
 		s = rs->new_style;
 
 	if (*old != s) {
-		gnm_style_link (s);
-		if (*old)
+		if (*old) {
+			gnm_style_unlink_dependents (*old, r);
 			gnm_style_unlink (*old);
+		}
+
+		gnm_style_link_dependents (s, r);
+		gnm_style_link (s);
+
 		*old = s;
 	}
 }
@@ -336,16 +343,30 @@ typedef enum {
 	TILE_MATRIX	=  3,
 	TILE_PTR_MATRIX	=  4
 } CellTileType;
-static int const tile_size[] = {
+static int const tile_size[/*type*/] = {
 	1,				/* TILE_SIMPLE */
 	TILE_SIZE_COL,			/* TILE_COL */
 	TILE_SIZE_ROW,			/* TILE_ROW */
 	TILE_SIZE_COL * TILE_SIZE_ROW	/* TILE_MATRIX */
 };
-static const char * const tile_type_str[] = {
+static int const tile_col_count[/*type*/] = {
+	1,				/* TILE_SIMPLE */
+	TILE_SIZE_COL,			/* TILE_COL */
+	1,				/* TILE_ROW */
+	TILE_SIZE_COL,			/* TILE_MATRIX */
+	TILE_SIZE_COL			/* TILE_PTR_MATRIX */
+};
+static int const tile_row_count[/*type*/] = {
+	1,				/* TILE_SIMPLE */
+	1,				/* TILE_COL */
+	TILE_SIZE_ROW,			/* TILE_ROW */
+	TILE_SIZE_ROW,			/* TILE_MATRIX */
+	TILE_SIZE_ROW			/* TILE_PTR_MATRIX */
+};
+static const char * const tile_type_str[/*type*/] = {
 	"simple", "col", "row", "matrix", "ptr-matrix"
 };
-static int const tile_widths[] = {
+static int const tile_widths[/*level*/] = {
 	1,
 	TILE_SIZE_COL,
 	TILE_SIZE_COL * TILE_SIZE_COL,
@@ -355,7 +376,7 @@ static int const tile_widths[] = {
 	TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL,
 	TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL
 };
-static int const tile_heights[] = {
+static int const tile_heights[/*level*/] = {
 	1,
 	TILE_SIZE_ROW,
 	TILE_SIZE_ROW * TILE_SIZE_ROW,
@@ -421,6 +442,11 @@ static int tile_allocations = 0;
 #endif
 
 
+/*
+ * Destroy a CellTile (recursively if needed).  This will unlink all the
+ * styles in it.  We do _not_ unlink style dependents here.  That is done
+ * only in rstyle_apply.
+ */
 static void
 cell_tile_dtor (CellTile *tile)
 {
@@ -477,20 +503,20 @@ cell_tile_ptr_matrix_new (CellTile *t)
 	res = CHUNK_ALLOC (CellTilePtrMatrix, TILE_PTR_MATRIX);
 	*((CellTileType *)&(res->type)) = TILE_PTR_MATRIX;
 
-	/* TODO :
+	/* TODO:
 	 * If we wanted to get fancy we could use self similarity to decrease
 	 * the number of subtiles.  However, this would increase the cost of
 	 * applying changes later so I'm not sure it is worth the effort.
 	 */
 	switch (t->type) {
-	case TILE_SIMPLE : {
+	case TILE_SIMPLE: {
 		int i = TILE_SIZE_COL * TILE_SIZE_ROW;
 		while (--i >= 0)
 			res->ptr[i] = cell_tile_style_new (
 				t->style_simple.style[0], TILE_SIMPLE);
 		break;
 	}
-	case TILE_COL : {
+	case TILE_COL: {
 		int i, r, c;
 		for (i = r = 0 ; r < TILE_SIZE_ROW ; ++r)
 			for (c = 0 ; c < TILE_SIZE_COL ; ++c)
@@ -498,7 +524,7 @@ cell_tile_ptr_matrix_new (CellTile *t)
 					t->style_col.style[c], TILE_SIMPLE);
 		break;
 	}
-	case TILE_ROW : {
+	case TILE_ROW: {
 		int i, r, c;
 		for (i = r = 0 ; r < TILE_SIZE_ROW ; ++r)
 			for (c = 0 ; c < TILE_SIZE_COL ; ++c)
@@ -506,72 +532,71 @@ cell_tile_ptr_matrix_new (CellTile *t)
 					t->style_row.style[r], TILE_SIMPLE);
 		break;
 	}
-	case TILE_MATRIX : {
+	case TILE_MATRIX: {
 		int i = TILE_SIZE_COL * TILE_SIZE_ROW;
 		while (--i >= 0)
 			res->ptr[i] = cell_tile_style_new (
 				t->style_matrix.style[i], TILE_SIMPLE);
 		break;
 	}
-	default : ;
+	default: ;
 	}
 
 	return (CellTile *)res;
 }
 
 static CellTile *
-cell_tile_matrix_set (CellTile *t, GnmRange const *indic, ReplacementStyle *rs)
+cell_tile_matrix_set (CellTile *t)
 {
-	int i, r, c;
+	int r, c;
 	CellTileStyleMatrix *res;
-	GnmStyle *tmp;
 
 	g_return_val_if_fail (t != NULL, NULL);
 	g_return_val_if_fail (TILE_SIMPLE <= t->type &&
 			      TILE_MATRIX >= t->type, NULL);
 
-	res = (CellTileStyleMatrix *)((t->type != TILE_MATRIX)
-		? cell_tile_style_new (NULL, TILE_MATRIX) : t);
+	if (t->type == TILE_MATRIX)
+		return t;
+
+	res = (CellTileStyleMatrix *)cell_tile_style_new (NULL, TILE_MATRIX);
 
 	switch (t->type) {
-	case TILE_SIMPLE :
-		gnm_style_link_multiple (tmp = t->style_simple.style[0],
-				     i = TILE_SIZE_COL * TILE_SIZE_ROW);
+	case TILE_SIMPLE: {
+		GnmStyle *tmp = t->style_simple.style[0];
+		int i = TILE_SIZE_COL * TILE_SIZE_ROW;
+		gnm_style_link_multiple (tmp, i);
 		while (--i >= 0)
 			res->style[i] = tmp;
 		break;
+	}
 
-	case TILE_COL :
-		for (i = r = 0 ; r < TILE_SIZE_ROW ; ++r)
-			for (c = 0 ; c < TILE_SIZE_COL ; ++c)
+	case TILE_COL: {
+		int i = 0;
+		for (r = 0; r < TILE_SIZE_ROW; ++r)
+			for (c = 0; c < TILE_SIZE_COL; ++c)
 				gnm_style_link (res->style[i++] =
-					     t->style_col.style[c]);
+						t->style_col.style[c]);
 		break;
-	case TILE_ROW :
-		for (i = r = 0 ; r < TILE_SIZE_ROW ; ++r) {
-			gnm_style_link_multiple (tmp = t->style_row.style[r],
-					      TILE_SIZE_COL);
-			for (c = 0 ; c < TILE_SIZE_COL ; ++c)
+	}
+
+	case TILE_ROW: {
+		int i = 0;
+		for (r = 0; r < TILE_SIZE_ROW; ++r) {
+			GnmStyle *tmp = t->style_row.style[r];
+			gnm_style_link_multiple (tmp, TILE_SIZE_COL);
+			for (c = 0; c < TILE_SIZE_COL; ++c)
 				res->style[i++] = tmp;
 		}
 		break;
-	case TILE_MATRIX :
-	default :
-		break;
 	}
 
-	if (t->type != TILE_MATRIX)
-		cell_tile_dtor (t);
-
-	if (indic != NULL) {
-		GnmStyle **style = res->style;
-		r = indic->start.row;
-		style += r*TILE_SIZE_COL;
-		for ( ;r <= indic->end.row ; ++r, style += TILE_SIZE_COL)
-			for (c = indic->start.col ; c <= indic->end.col ; ++c)
-				rstyle_apply (style + c, rs);
+	case TILE_MATRIX:
+	default:
+		g_assert_not_reached();
 	}
 
+	cell_tile_dtor (t);
+
 	return (CellTile *)res;
 }
 
@@ -616,9 +641,6 @@ sheet_style_init_size (Sheet *sheet, int cols, int rows)
 	}
 	sheet->tile_top_level = MAX (lc, lr);
 
-	sheet->max_height = tile_heights[sheet->tile_top_level];
-	sheet->max_width = tile_widths[sheet->tile_top_level];
-
 	if (active_sheet_count++ == 0) {
 #if USE_TILE_POOLS
 		tile_pools[TILE_SIMPLE] =
@@ -692,7 +714,7 @@ sheet_style_resize (Sheet *sheet, int cols, int rows)
 
 	/* Save the style for the surviving area.  */
 	range_init (&save_range, 0, 0,
-		    MIN (cols, old_cols), MIN (rows, old_rows));
+		    MIN (cols, old_cols) - 1, MIN (rows, old_rows) - 1);
 	styles = sheet_style_get_range (sheet, &save_range);
 
 	/* Build new empty structures.  */
@@ -715,12 +737,6 @@ sheet_style_resize (Sheet *sheet, int cols, int rows)
 	style_list_free	(styles);
 }
 
-static void
-cb_unlink (void *key, G_GNUC_UNUSED void *value, G_GNUC_UNUSED void *user)
-{
-	gnm_style_unlink (key);
-}
-
 #if USE_TILE_POOLS
 static void
 cb_tile_pool_leak (gpointer data, gpointer user)
@@ -734,10 +750,18 @@ void
 sheet_style_shutdown (Sheet *sheet)
 {
 	GnmStyleHash *table;
+	GnmRange r;
 
 	g_return_if_fail (IS_SHEET (sheet));
 	g_return_if_fail (sheet->style_data != NULL);
 
+	/*
+	 * Clear all styles.  This is an easy way to clear out all
+	 * style dependencies.
+	 */
+	range_init_full_sheet (&r, sheet);
+	sheet_style_set_range (sheet, &r, sheet_style_default (sheet));
+
 	cell_tile_dtor (sheet->style_data->styles);
 	sheet->style_data->styles = NULL;
 
@@ -750,7 +774,8 @@ sheet_style_shutdown (Sheet *sheet)
 	 */
 	table = sheet->style_data->style_hash;
 	sheet->style_data->style_hash = NULL;
-	sh_foreach (table, cb_unlink, NULL);
+	g_slist_free_full (sh_all_styles (table),
+			   (GDestroyNotify)gnm_style_unlink);
 	sh_destroy (table);
 	style_color_unref (sheet->style_data->auto_pattern_color);
 
@@ -790,9 +815,9 @@ sheet_style_shutdown (Sheet *sheet)
 }
 
 /**
- * sheet_style_set_auto_pattern_color :
+ * sheet_style_set_auto_pattern_color:
  * @sheet:         The sheet
- * @pattern_color: The color
+ * @grid_color: The color
  *
  * Set the color for rendering auto colored patterns in this sheet.
  * Absorbs a reference to @pattern_color;
@@ -837,6 +862,8 @@ sheet_style_get_auto_pattern_color (Sheet const *sheet)
 }
 
 /**
+ * sheet_style_update_grid_color:
+ *
  * This function updates the color of gnm_style_border_none when the sheet to be
  * rendered is known. gnm_style_border_none tells how to render the
  * grid. Because the grid color may be different for different sheets, the
@@ -869,68 +896,128 @@ sheet_style_update_grid_color (Sheet const *sheet)
 
 /****************************************************************************/
 
-static GnmStyle *
-vector_apply_pstyle (GnmStyle **styles, int n, ReplacementStyle *rs)
+static gboolean
+tile_is_uniform (CellTile const *tile)
 {
-	gboolean is_uniform = TRUE;
-	GnmStyle *prev = NULL;
+	const int s = tile_size[tile->type];
+	GnmStyle const *st = tile->style_any.style[0];
+	int i;
 
-	while (--n >= 0) {
-		rstyle_apply (styles + n, rs);
-		if (is_uniform) {
-			if (prev == NULL)
-				prev = styles[n];
-			else if (prev != styles[n])
-				is_uniform = FALSE;
-		}
-	}
-	return is_uniform ? prev : NULL;
+	for (i = 1; i < s; i++)
+		if (tile->style_any.style[i] != st)
+			return FALSE;
+
+	return TRUE;
 }
 
+static void
+vector_apply_pstyle (CellTile *tile, ReplacementStyle *rs,
+		     int cc, int cr, int level, GnmRange const *indic)
+{
+	const CellTileType type = tile->type;
+	const int ncols = tile_col_count[type];
+	const int nrows = tile_row_count[type];
+	const int w1 = tile_widths[level + 1] / ncols;
+	const int h1 = tile_heights[level + 1] / nrows;
+	const int fcol = indic->start.col;
+	const int frow = indic->start.row;
+	const int lcol = MIN (ncols - 1, indic->end.col);
+	const int lrow = MIN (nrows - 1, indic->end.row);
+	GnmSheetSize const *ss = gnm_sheet_get_size (rs->sheet);
+	int r, c;
+	GnmRange rng;
+
+	for (r = frow; r <= lrow; r++) {
+		GnmStyle **st = tile->style_any.style + ncols * r;
+		rng.start.row = cr + h1 * r;
+		rng.end.row = MIN (rng.start.row + (h1 - 1),
+				   ss->max_rows - 1);
+		for (c = fcol; c <= lcol; c++) {
+			rng.start.col = cc + w1 * c;
+			rng.end.col = MIN (rng.start.col + (w1 - 1),
+					   ss->max_cols - 1);
+			rstyle_apply (st + c, rs, &rng);
+		}
+	}
+}
+
+/*
+ * Determine whether before applying a style in the area of apply_to
+ * one needs to split the tile column-wise.
+ *
+ * If FALSE is returned then the tile need to be split to a TILE_PTR_MATRIX
+ * because the current level is not fine-grained enough.
+ *
+ * If TRUE is returned, TILE_SIMPLE needs to be split into TILE_COL and
+ * TILE_ROW needs to be split into TILE_MATRIX.  TILE_COL and TILE_MATRIX
+ * should be kept.  In indic, the inclusive post-split indicies of the
+ * range will be returned.
+ *
+ * If apply_to covers the entire tile, TRUE will be returned and the judgement
+ * on splitting above should be ignored.  The indices in indic will be as-if
+ * the split was done.
+ */
 static gboolean
 col_indicies (int corner_col, int w, GnmRange const *apply_to,
-	      int *first_index, int *last_index)
+	      GnmRange *indec)
 {
 	int i, tmp;
 
 	i = apply_to->start.col - corner_col;
-	tmp = i / w;
-	if (i != (tmp * w))
-		return FALSE;
-	*first_index = (i >= 0) ? tmp : 0;
+	if (i <= 0)
+		indec->start.col = 0;
+	else {
+		tmp = i / w;
+		if (i != tmp * w)
+			return FALSE;
+		indec->start.col = tmp;
+	}
 
 	i = 1 + apply_to->end.col - corner_col;
 	tmp = i / w;
-	if (i != (tmp * w))
-		return FALSE;
-	*last_index = (tmp <= TILE_SIZE_COL) ? (tmp-1) : TILE_SIZE_COL -1;
+	if (tmp >= TILE_SIZE_COL)
+		indec->end.col = TILE_SIZE_COL - 1;
+	else {
+		if (i != tmp * w)
+			return FALSE;
+		indec->end.col = tmp - 1;
+	}
 
 	return TRUE;
 }
 
+/* See docs for col_indicies.  Swap cols and rows.  */
 static gboolean
 row_indicies (int corner_row, int h, GnmRange const *apply_to,
-	      int *first_index, int *last_index)
+	      GnmRange *indic)
 {
 	int i, tmp;
 
 	i = apply_to->start.row - corner_row;
-	tmp = i / h;
-	if (i != (tmp * h))
-		return FALSE;
-	*first_index = (i >= 0) ? tmp : 0;
+	if (i <= 0)
+		indic->start.row = 0;
+	else {
+		int tmp = i / h;
+		if (i != tmp * h)
+			return FALSE;
+		indic->start.row = tmp;
+	}
 
 	i = 1 + apply_to->end.row - corner_row;
 	tmp = i / h;
-	if (i != (tmp * h))
-		return FALSE;
-	*last_index = (tmp <= TILE_SIZE_ROW) ? (tmp-1) : TILE_SIZE_ROW -1;
+	if (tmp >= TILE_SIZE_ROW)
+		indic->end.row = TILE_SIZE_ROW - 1;
+	else {
+		if (i != tmp * h)
+			return FALSE;
+		indic->end.row = tmp - 1;
+	}
 
 	return TRUE;
 }
 
-/**
- * cell_tile_apply : This is the primary logic for making changing areas in the
+/*
+ * cell_tile_apply: This is the primary logic for making changing areas in the
  * tree.  It could be further optimised if it becomes a bottle neck.
  */
 static void
@@ -948,7 +1035,6 @@ cell_tile_apply (CellTile **tile, int level,
 	gboolean const full_height = (apply_to->start.row <= corner_row &&
 				      apply_to->end.row >= (corner_row+height-1));
 	GnmRange indic;
-	CellTile *res = NULL;
 	CellTileType type;
 	int c, r, i;
 
@@ -964,94 +1050,104 @@ cell_tile_apply (CellTile **tile, int level,
 	    (*tile)->style_simple.style[0] == rs->new_style)
 		return;
 
-	/* Apply new style over top of the entire tile */
-	if (full_width && full_height) {
-		if (type == TILE_SIMPLE) {
-			rstyle_apply ((*tile)->style_simple.style, rs);
-			return;
-		}
-		if (rs->new_style != NULL) {
-			res = cell_tile_style_new (rs->new_style,
-						   (type = TILE_SIMPLE));
-			cell_tile_dtor (*tile);
-			*tile = res;
-		}
-		if (TILE_SIMPLE <= type && type <= TILE_MATRIX) {
-			GnmStyle *uniform = vector_apply_pstyle (
-				(*tile)->style_any.style, tile_size[type], rs);
-			if (uniform == NULL)
-				return;
+	/*
+	 * Indices for the whole tile assuming a split to matrix.
+	 * We can still use these indices if we don't split either way.
+	 */
+	indic.start.col = 0;
+	indic.start.row = 0;
+	indic.end.col = TILE_SIZE_COL - 1;
+	indic.end.row = TILE_SIZE_ROW - 1;
 
-			res = cell_tile_style_new (uniform, TILE_SIMPLE);
+	if (type == TILE_PTR_MATRIX)
+		goto drill_down;
+	else if (full_width && full_height)
+		goto apply;
+	else if (full_height) {
+		if (!col_indicies (corner_col, w, apply_to, &indic))
+			goto split_to_ptr_matrix;
+
+		switch (type) {
+		case TILE_SIMPLE: {
+			CellTile *res;
+			type = TILE_COL;
+			res = cell_tile_style_new (
+				(*tile)->style_simple.style[0],
+				type);
 			cell_tile_dtor (*tile);
 			*tile = res;
-			return;
+			/* Fall through */
 		}
-	} else if (full_height) {
-		if (col_indicies (corner_col, w, apply_to,
-				  &indic.start.col, &indic.end.col)) {
-			if (type == TILE_SIMPLE) {
-				res = cell_tile_style_new (
-					(*tile)->style_simple.style[0],
-					(type = TILE_COL));
-				cell_tile_dtor (*tile);
-				*tile = res;
-			}
-			if (type == TILE_COL) {
-				int i = indic.start.col;
-				for (;i <= indic.end.col ; ++i)
-					rstyle_apply ((*tile)->style_col.style + i, rs);
-				goto try_optimize;
-			}
-			if (type != TILE_PTR_MATRIX) {
-				indic.start.row = 0;
-				indic.end.row = TILE_SIZE_ROW - 1;
-				*tile = cell_tile_matrix_set (*tile, &indic, rs);
-				goto try_optimize;
-			}
+		case TILE_COL:
+		case TILE_MATRIX:
+			goto apply;
+		case TILE_ROW:
+			goto split_to_matrix;
+		default:
+			g_assert_not_reached ();
 		}
 	} else if (full_width) {
-		if (row_indicies (corner_row, h, apply_to,
-				  &indic.start.row, &indic.end.row)) {
-			if (type == TILE_SIMPLE) {
-				res = cell_tile_style_new (
-					(*tile)->style_simple.style[0],
-					(type = TILE_ROW));
-				cell_tile_dtor (*tile);
-				*tile = res;
-			}
-			if (type == TILE_ROW) {
-				int i = indic.start.row;
-				for (;i <= indic.end.row ; ++i)
-					rstyle_apply ((*tile)->style_row.style + i, rs);
-				goto try_optimize;
-			}
-			if (type != TILE_PTR_MATRIX) {
-				indic.start.col = 0;
-				indic.end.col = TILE_SIZE_COL - 1;
-				*tile = cell_tile_matrix_set (*tile, &indic, rs);
-				goto try_optimize;
-			}
+		if (!row_indicies (corner_row, h, apply_to, &indic))
+			goto split_to_ptr_matrix;
+		switch (type) {
+		case TILE_SIMPLE: {
+			CellTile *res;
+
+			type = TILE_ROW;
+			res = cell_tile_style_new (
+				(*tile)->style_simple.style[0],
+				type);
+			cell_tile_dtor (*tile);
+			*tile = res;
+			/* Fall through */
+		}
+		case TILE_ROW:
+		case TILE_MATRIX:
+			goto apply;
+		case TILE_COL:
+			goto split_to_matrix;
+		default:
+			g_assert_not_reached ();
 		}
 	} else {
-		if (col_indicies (corner_col, w, apply_to,
-				  &indic.start.col, &indic.end.col) &&
-		    row_indicies (corner_row, h, apply_to,
-				  &indic.start.row, &indic.end.row) &&
-		    type != TILE_PTR_MATRIX) {
-			*tile = cell_tile_matrix_set (*tile, &indic, rs);
-			goto try_optimize;
-		}
+		if (col_indicies (corner_col, w, apply_to, &indic) &&
+		    row_indicies (corner_row, h, apply_to, &indic))
+			goto split_to_matrix;
+		else
+			goto split_to_ptr_matrix;
 	}
 
-	if (res == NULL && type != TILE_PTR_MATRIX) {
-		type = TILE_PTR_MATRIX;
-		res = cell_tile_ptr_matrix_new (*tile);
+	g_assert_not_reached ();
+
+split_to_matrix:
+	*tile = cell_tile_matrix_set (*tile);
+
+apply:
+	vector_apply_pstyle (*tile, rs, corner_col, corner_row, level, &indic);
+
+try_optimize:
+	{
+		CellTileOptimize cto;
+		cto.ss = gnm_sheet_get_size (rs->sheet);
+		cto.recursion = FALSE;
+		cell_tile_optimize (tile, level, &cto, corner_col, corner_row);
+	}
+	return;
+
+split_to_ptr_matrix:
+	/*
+	 * We get here when apply_to's corners are not on a TILE_MATRIX grid.
+	 * Split to pointer matrix whose element tiles will have a finer grid.
+	 */
+	g_return_if_fail (type != TILE_PTR_MATRIX);
+	{
+		CellTile *res = cell_tile_ptr_matrix_new (*tile);
 		cell_tile_dtor (*tile);
 		*tile = res;
+		type = TILE_PTR_MATRIX;
 	}
 
-	/* drill down */
+drill_down:
 	g_return_if_fail (type == TILE_PTR_MATRIX);
 	for (i = r = 0 ; r < TILE_SIZE_ROW ; ++r, i += TILE_SIZE_COL) {
 		int const cr = corner_row + h*r;
@@ -1071,14 +1167,7 @@ cell_tile_apply (CellTile **tile, int level,
 					 level - 1, cc, cr, apply_to, rs);
 		}
 	}
-
-try_optimize:
-	{
-		CellTileOptimize cto;
-		cto.ss = gnm_sheet_get_size (rs->sheet);
-		cto.recursion = FALSE;
-		cell_tile_optimize (tile, level, &cto, corner_col, corner_row);
-	}
+	goto try_optimize;
 }
 
 /* Handler for foreach_tile.
@@ -1187,8 +1276,8 @@ foreach_tile (CellTile *tile, int level,
 	}
 }
 
-/**
- * cell_tile_apply_pos : This is an simplified version of cell_tile_apply.  It
+/*
+ * cell_tile_apply_pos: This is an simplified version of cell_tile_apply.  It
  * does not need all the bells and whistles because it operates on single cells.
  */
 static void
@@ -1198,13 +1287,16 @@ cell_tile_apply_pos (CellTile **tile, int level,
 {
 	CellTile *tmp;
 	CellTileType type;
+	GnmRange rng;
 
 	g_return_if_fail (col >= 0);
 	g_return_if_fail (col < gnm_sheet_get_max_cols (rs->sheet));
 	g_return_if_fail (row >= 0);
 	g_return_if_fail (row < gnm_sheet_get_max_rows (rs->sheet));
 
-tail_recursion :
+	range_init (&rng, col, row, col, row);
+
+tail_recursion:
 	g_return_if_fail (TILE_TOP_LEVEL >= level && level >= 0);
 	g_return_if_fail (tile != NULL);
 	g_return_if_fail (*tile != NULL);
@@ -1235,10 +1327,12 @@ tail_recursion :
 		row -= r*h;
 		goto tail_recursion;
 	} else if (type != TILE_MATRIX)
-		*tile = tmp = cell_tile_matrix_set (tmp, NULL, NULL);
+		*tile = tmp = cell_tile_matrix_set (tmp);
 
 	g_return_if_fail (tmp->type == TILE_MATRIX);
-	rstyle_apply (tmp->style_matrix.style + row*TILE_SIZE_COL + col, rs);
+	rstyle_apply (tmp->style_matrix.style + row * TILE_SIZE_COL + col,
+		      rs,
+		      &rng);
 }
 
 /**
@@ -1259,9 +1353,10 @@ sheet_style_set_range (Sheet *sheet, GnmRange const *range,
 	g_return_if_fail (IS_SHEET (sheet));
 	g_return_if_fail (range != NULL);
 
+	rstyle_ctor_style (&rs, style, sheet);
 	cell_tile_apply (&sheet->style_data->styles,
 			 sheet->tile_top_level, 0, 0,
-			 range, rstyle_ctor (&rs, style, NULL, sheet));
+			 range, &rs);
 	rstyle_dtor (&rs);
 }
 
@@ -1271,7 +1366,7 @@ sheet_style_set_range (Sheet *sheet, GnmRange const *range,
  * @col:
  * @style: #GnmStyle
  *
- * NOTE : This is a simple wrapper for now.  When we support col/row styles it
+ * NOTE: This is a simple wrapper for now.  When we support col/row styles it
  *	will make life easier.
  *
  * Apply a partial style to a full col.
@@ -1291,7 +1386,7 @@ sheet_style_apply_col (Sheet *sheet, int col, GnmStyle *pstyle)
  * @row:
  * @style: #GnmStyle
  *
- * NOTE : This is a simple wrapper for now.  When we support col/row styles it
+ * NOTE: This is a simple wrapper for now.  When we support col/row styles it
  *	will make life easier.
  *
  * Apply a partial style to a full col.
@@ -1306,11 +1401,11 @@ sheet_style_apply_row (Sheet  *sheet, int row, GnmStyle *pstyle)
 }
 
 /**
- * sheet_style_apply_pos :
- * @sheet :
- * @col   :
- * @row   :
- * @pstyle : #GnmStyle
+ * sheet_style_apply_pos:
+ * @sheet:
+ * @col:
+ * @row:
+ * @style: #GnmStyle
  *
  * Apply a partial style to a single cell
  * This function absorbs a reference to the new @style.
@@ -1323,17 +1418,18 @@ sheet_style_apply_pos (Sheet *sheet, int col, int row,
 
 	g_return_if_fail (IS_SHEET (sheet));
 
+	rstyle_ctor_pstyle (&rs, pstyle, sheet);
 	cell_tile_apply_pos (&sheet->style_data->styles,
 			     sheet->tile_top_level, col, row,
-			     rstyle_ctor (&rs, NULL, pstyle, sheet));
+			     &rs);
 	rstyle_dtor (&rs);
 }
 /**
- * sheet_style_set_pos :
- * @sheet :
- * @col   :
- * @row   :
- * @style :
+ * sheet_style_set_pos:
+ * @sheet:
+ * @col:
+ * @row:
+ * @style:
  *
  * Change the complete style for a single cell.
  * This function absorbs a reference to the new @style.
@@ -1346,15 +1442,16 @@ sheet_style_set_pos (Sheet *sheet, int col, int row,
 
 	g_return_if_fail (IS_SHEET (sheet));
 
+	rstyle_ctor_style (&rs, style, sheet);
 	cell_tile_apply_pos (&sheet->style_data->styles,
 			     sheet->tile_top_level, col, row,
-			     rstyle_ctor (&rs, style, NULL, sheet));
+			     &rs);
 	rstyle_dtor (&rs);
 }
 
 /**
- * sheet_style_default :
- * @sheet :
+ * sheet_style_default:
+ * @sheet:
  *
  * Returns a reference to default style for a sheet.
  **/
@@ -1369,10 +1466,10 @@ sheet_style_default (Sheet const *sheet)
 }
 
 /**
- * sheet_style_get :
- * @sheet : #Sheet
- * @col   :
- * @row   :
+ * sheet_style_get:
+ * @sheet: #Sheet
+ * @col:
+ * @row:
  *
  * Find the fully qualified style applicable to the specified cellpos.
  * Does _not_ add a reference.
@@ -1380,42 +1477,43 @@ sheet_style_default (Sheet const *sheet)
 GnmStyle const *
 sheet_style_get (Sheet const *sheet, int col, int row)
 {
-	int width = sheet->max_width;
-	int height = sheet->max_height;
-	int c, r, level = sheet->tile_top_level;
+	int level = sheet->tile_top_level;
 	CellTile *tile = sheet->style_data->styles;
 
-tail_recursion :
-	c = col / width;
-	r = row / height;
+	while (1) {
+		int width = tile_widths[level];
+		int height = tile_heights[level];
+		int c = col / width;
+		int r = row / height;
 
-	g_return_val_if_fail (tile != NULL, NULL);
-	g_return_val_if_fail (0 <= c && c < TILE_SIZE_COL, NULL);
-	g_return_val_if_fail (0 <= r && r < TILE_SIZE_ROW, NULL);
+		g_return_val_if_fail (tile != NULL, NULL);
+		g_return_val_if_fail (0 <= c && c < TILE_SIZE_COL, NULL);
+		g_return_val_if_fail (0 <= r && r < TILE_SIZE_ROW, NULL);
 
-	switch (tile->type) {
-	case TILE_SIMPLE : return tile->style_simple.style[0];
-	case TILE_COL :	   return tile->style_col.style[c];
-	case TILE_ROW :	   return tile->style_row.style[r];
-	case TILE_MATRIX : return tile->style_matrix.style[r*TILE_SIZE_COL+c];
+		switch (tile->type) {
+		case TILE_SIMPLE:
+			return tile->style_simple.style[0];
+		case TILE_COL:
+			return tile->style_col.style[c];
+		case TILE_ROW:
+			return tile->style_row.style[r];
+		case TILE_MATRIX:
+			return tile->style_matrix.style[r * TILE_SIZE_COL + c];
 
-	case TILE_PTR_MATRIX :
-		g_return_val_if_fail (level > 0, NULL);
+		case TILE_PTR_MATRIX:
+			g_return_val_if_fail (level > 0, NULL);
 
-		level--;
-		tile = tile->ptr_matrix.ptr[r*TILE_SIZE_COL + c];
-		col -= c * width;
-		row -= r * height;
-		width /= TILE_SIZE_COL;
-		height /= TILE_SIZE_ROW;
-		goto tail_recursion;
+			level--;
+			tile = tile->ptr_matrix.ptr[r * TILE_SIZE_COL + c];
+			col -= c * width;
+			row -= r * height;
+			continue;
 
-	default :
-		break;
+		default:
+			g_warning ("Adaptive Quad Tree corruption !");
+			return NULL;
+		}
 	}
-
-	g_warning ("Adaptive Quad Tree corruption !");
-	return NULL;
 }
 
 #define border_null(b)	((b) == none || (b) == NULL)
@@ -1529,9 +1627,9 @@ get_style_row (CellTile const *tile, int level,
 }
 
 /**
- * sheet_style_get_row :
- * @sheet : #Sheet
- * @sr    : #GnmStyleRow
+ * sheet_style_get_row:
+ * @sheet: #Sheet
+ * @sr: #GnmStyleRow
  *
  * A utility routine which efficiently retrieves a range of styles within a row.
  * It also merges adjacent borders as necessary.
@@ -1585,7 +1683,7 @@ sheet_style_get_row2 (Sheet const *sheet, int row)
 
 
 /**
- * style_row_init :
+ * style_row_init:
  *
  * A small utility routine to initialize the grid drawing GnmStyleRow data
  * structure.
@@ -1627,9 +1725,9 @@ style_row_init (GnmBorder const * * *prev_vert,
 }
 
 /**
- * sheet_style_apply_range :
- * @sheet :
- * @range :
+ * sheet_style_apply_range:
+ * @sheet:
+ * @range:
  * @pstyle:
  *
  * Apply a partial style to a region.
@@ -1643,9 +1741,10 @@ sheet_style_apply_range (Sheet *sheet, GnmRange const *range, GnmStyle *pstyle)
 	g_return_if_fail (IS_SHEET (sheet));
 	g_return_if_fail (range != NULL);
 
+	rstyle_ctor_pstyle (&rs, pstyle, sheet);
 	cell_tile_apply (&sheet->style_data->styles,
 			 sheet->tile_top_level, 0, 0,
-			 range, rstyle_ctor (&rs, NULL, pstyle, sheet));
+			 range, &rs);
 	rstyle_dtor (&rs);
 }
 
@@ -1660,11 +1759,10 @@ apply_border (Sheet *sheet, GnmRange const *r,
 }
 
 /**
- * sheet_style_apply_border :
- *
- * @sheet   :
- * @range   :
- * @borders :
+ * sheet_style_apply_border:
+ * @sheet:
+ * @range:
+ * @borders:
  *
  * When a user applies a border to a region we attempt to remove the border
  * from the opposing side to avoid overlapping border specifications.
@@ -1764,7 +1862,7 @@ sheet_style_apply_border (Sheet       *sheet,
 		}
 	}
 
-	/* Interiors vertical : prefer left */
+	/* Interiors vertical: prefer left */
 	if (borders[GNM_STYLE_BORDER_VERT] != NULL) {
 		/* 6.1 vertical interior left */
 		if (range->start.col != range->end.col) {
@@ -1861,11 +1959,10 @@ border_mask_vec (gboolean *known, GnmBorder **borders,
 }
 
 /**
- * sheet_style_get_uniform :
- *
- * @sheet   :
- * @range   :
- * @borders :
+ * sheet_style_get_uniform:
+ * @sheet:
+ * @range:
+ * @borders:
  *
  * Find out what style elements are common to every cell in a range
  * Returns a flag of TRUE if there was a conflict a given style element
@@ -1948,7 +2045,7 @@ sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
 	}
 
 	/*
-	 * TODO : The border handling is tricky and currently VERY slow for
+	 * TODO: The border handling is tricky and currently VERY slow for
 	 * large ranges.  We could easily optimize this.  There is no need to
 	 * retrieve the style in every cell just to do a filter for uniformity
 	 * by row.  One day we should do a special case version of
@@ -1987,9 +2084,8 @@ sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
 }
 
 /**
- * sheet_style_relocate
- *
- * @rinfo :
+ * sheet_style_relocate:
+ * @rinfo:
  *
  * Slide the styles from the origin region to the new position.
  */
@@ -2012,9 +2108,8 @@ sheet_style_relocate (GnmExprRelocateInfo const *rinfo)
 }
 
 /**
- * sheet_style_insert_colrow
- *
- * @rinfo :
+ * sheet_style_insert_colrow:
+ * @rinfo:
  *
  * A utility routine to give the effect of stretching the styles when a col/row
  * is inserted.  This is done by applying the styles from the left/top col/row
@@ -2096,7 +2191,6 @@ cb_style_extent (GnmStyle *style,
 
 /**
  * sheet_style_get_extent:
- *
  * @sheet: sheet to measure
  * @r: starting range and resulting range
  *
@@ -2765,11 +2859,12 @@ internal_style_list (Sheet const *sheet, GnmRange const *r,
 
 /**
  * sheet_style_get_range:
- * @sheet:
- * @range:
+ * @sheet: the sheet in which to find styles
+ * @r:     optional range to scan
  *
- * Get a list of rectangles and their associated styles
- * Caller is responsible for freeing.
+ * Get a list of rectangles and their associated styles.
+ * Caller is responsible for freeing.  Note that when a range is given,
+ * the resulting ranges are relative to the input range.
  *
  * Returns: (transfer full):
  */
@@ -2796,7 +2891,7 @@ style_conditions_filter (GnmStyle const *style)
 /**
  * sheet_style_collect_conditions:
  * @sheet:
- * @range:
+ * @r:
  *
  * Returns: (transfer full): a list of areas with conditionals, Caller is
  * responsible for freeing.
@@ -2825,7 +2920,7 @@ style_hlink_filter (GnmStyle const *style)
 /**
  * sheet_style_collect_hlinks:
  * @sheet:
- * @range:
+ * @r:
  *
  * Returns: (transfer full): a list of areas with hyperlinks, Caller is
  * responsible for freeing.
@@ -2856,7 +2951,7 @@ style_validation_filter (GnmStyle const *style)
 /**
  * sheet_style_collect_validations:
  * @sheet:
- * @range:
+ * @r:
  *
  * Returns: (transfer full): a list of areas with validation, Caller is
  * responsible for freeing.
@@ -2908,9 +3003,8 @@ sheet_style_set_list (Sheet *sheet, GnmCellPos const *corner,
 }
 
 /**
- * style_list_free :
- *
- * @list : the list to free
+ * style_list_free:
+ * @l: the list to free
  *
  * Free up the ressources in the style list.  Including unreferencing the
  * styles.
@@ -2922,11 +3016,10 @@ style_list_free (GnmStyleList *list)
 }
 
 /**
- * style_list_get_style :
- *
- * @list : A style list.
- * @col  :
- * @row  :
+ * style_list_get_style:
+ * @l: A style list.
+ * @col:
+ * @row:
  *
  * Attempts to find the style associated with the @pos offset within the 0,0
  * based style list.
@@ -2990,31 +3083,43 @@ sheet_style_region_contains_link (Sheet const *sheet, GnmRange const *r)
  * Executes @func for each style in the sheet.
  **/
 void
-sheet_style_foreach (Sheet const *sheet, GHFunc func, gpointer user_data)
+sheet_style_foreach (Sheet const *sheet, GFunc func, gpointer user_data)
 {
+	GSList *styles;
+
 	g_return_if_fail (IS_SHEET (sheet));
 	g_return_if_fail (sheet->style_data != NULL);
 
-	sh_foreach (sheet->style_data->style_hash, func, user_data);
+	styles = sh_all_styles (sheet->style_data->style_hash);
+	styles = g_slist_sort (styles, (GCompareFunc)gnm_style_cmp);
+	g_slist_foreach (styles, func, user_data);
+	g_slist_free (styles);
 }
 
 /**
  * sheet_style_range_foreach:
  * @sheet: #Sheet
+ * @r: optional range
  * @func: (scope call): callback.
  * @user_data: user data
- * @optimize:
  *
  **/
 void
-sheet_style_range_foreach (Sheet const *sheet, GHFunc func, gpointer user_data)
+sheet_style_range_foreach (Sheet const *sheet, GnmRange const *r,
+			   GHFunc func, gpointer user_data)
 {
 	GnmStyleList *styles, *l;
 
-	styles = sheet_style_get_range (sheet, NULL);
+	styles = sheet_style_get_range (sheet, r);
 
 	for (l = styles; l; l = l->next) {
 		GnmStyleRegion *sr = l->data;
+		if (r) {
+			sr->range.start.col += r->start.col;
+			sr->range.start.row += r->start.row;
+			sr->range.end.col += r->start.col;
+			sr->range.end.row += r->start.row;
+		}
 		func (NULL, sr, user_data);
 		gnm_style_region_free (sr);
 	}
@@ -3048,24 +3153,50 @@ cell_tile_optimize (CellTile **tile, int level, CellTileOptimize *data,
 
 	switch (type) {
 	case TILE_COL:
-	case TILE_ROW: {
-		int s = tile_size[type];
-		int i;
-		gboolean same = TRUE;
-
-		for (i = 1; i < s; i++) {
-			if (!gnm_style_eq ((*tile)->style_any.style[0],
-					   (*tile)->style_any.style[i])) {
-				same = FALSE;
-				break;
-			}
-		}
-
-		if (!same)
+	case TILE_ROW:
+		if (!tile_is_uniform (*tile))
 			return;
 
 		type = TILE_SIMPLE;
 		break;
+
+	case TILE_PTR_MATRIX: {
+		gboolean all_simple = TRUE;
+		int i;
+
+		for (i = 0; i < TILE_SIZE_COL * TILE_SIZE_ROW; i++) {
+			CellTile **subtile = (*tile)->ptr_matrix.ptr + i;
+			if (data->recursion) {
+				int c = i % TILE_SIZE_COL;
+				int r = i / TILE_SIZE_COL;
+				cell_tile_optimize (subtile, level - 1, data,
+						    ccol + w * c,
+						    crow + h * r);
+			}
+			if ((*subtile)->type != TILE_SIMPLE)
+				all_simple = FALSE;
+		}
+		if (!all_simple)
+			return;
+
+		res = cell_tile_style_new (NULL, TILE_MATRIX);
+		for (i = 0; i < TILE_SIZE_COL * TILE_SIZE_ROW; i++) {
+			CellTile *subtile = (*tile)->ptr_matrix.ptr[i];
+			GnmStyle *st = subtile->style_simple.style[0];
+			gnm_style_link (st);
+			res->style_matrix.style[i] = st;
+		}
+
+		if (debug_style_optimize)
+			g_printerr ("Turning %s (%dx%d) from a %s into a %s\n",
+				    range_as_string (&rng),
+				    range_width (&rng), range_height (&rng),
+				    tile_type_str[(*tile)->type],
+				    tile_type_str[res->type]);
+		cell_tile_dtor (*tile);
+		*tile = res;
+
+		/* Fall through */
 	}
 
 	case TILE_MATRIX: {
@@ -3102,76 +3233,6 @@ cell_tile_optimize (CellTile **tile, int level, CellTileOptimize *data,
 		break;
 	}
 
-	case TILE_PTR_MATRIX: {
-		int c, r, i;
-		gboolean csame = TRUE;
-		gboolean rsame = TRUE;
-		gboolean all_simple = TRUE;
-
-		for (i = r = 0 ; r < TILE_SIZE_ROW ; ++r, i += TILE_SIZE_COL) {
-			int const cr = crow + h*r;
-			for (c = 0 ; c < TILE_SIZE_COL ; ++c) {
-				int const cc = ccol + w*c;
-				CellTile const *tcr, *tc0, *t0r;
-				if (data->recursion)
-					cell_tile_optimize ((*tile)->ptr_matrix.ptr + i + c,
-							    level - 1, data, cc, cr);
-				tcr = (*tile)->ptr_matrix.ptr[i + c];
-				t0r = (*tile)->ptr_matrix.ptr[i];
-				tc0 = (*tile)->ptr_matrix.ptr[c];
-
-				if (tcr->type != TILE_SIMPLE) {
-					all_simple = FALSE;
-					csame = FALSE;
-					rsame = FALSE;
-				}
-
-				if (rsame && c)
-					rsame = gnm_style_eq (tcr->style_simple.style[0],
-							      t0r->style_simple.style[0]);
-
-				if (csame && r)
-					csame = gnm_style_eq (tcr->style_simple.style[0],
-							      tc0->style_simple.style[0]);
-			}
-		}
-		if (csame && rsame) {
-			res = cell_tile_style_new ((*tile)->ptr_matrix.ptr[0]->style_simple.style[0], TILE_SIMPLE);
-		} else if (csame) {
-			res = cell_tile_style_new (NULL, TILE_COL);
-			for (i = 0; i < TILE_SIZE_COL; i++) {
-				GnmStyle *mstyle = (*tile)->ptr_matrix.ptr[i]
-					->style_simple.style[0];
-				res->style_col.style[i] = mstyle;
-				gnm_style_link (mstyle);
-			}
-		} else if (rsame) {
-			res = cell_tile_style_new (NULL, TILE_ROW);
-			for (i = 0; i < TILE_SIZE_ROW; i++) {
-				GnmStyle *mstyle = (*tile)->ptr_matrix.ptr[i * TILE_SIZE_COL]
-					->style_simple.style[0];
-				res->style_row.style[i] = mstyle;
-				gnm_style_link (mstyle);
-			}
-		} else if (all_simple) {
-			if (debug_style_optimize)
-				g_printerr ("Could turn %s into a matrix\n",
-					    range_as_string (&rng));
-			return;
-		} else
-			return;
-
-		if (debug_style_optimize)
-			g_printerr ("Turning %s (%dx%d) from a %s into a %s\n",
-				    range_as_string (&rng),
-				    range_width (&rng), range_height (&rng),
-				    tile_type_str[(*tile)->type],
-				    tile_type_str[res->type]);
-		cell_tile_dtor (*tile);
-		*tile = res;
-		return;
-	}
-
 	default:
 		g_assert_not_reached ();
 	}
@@ -3309,6 +3370,9 @@ sheet_style_optimize (Sheet *sheet)
 			    sheet->tile_top_level, &data,
 			    0, 0);
 
+	if (debug_style_optimize)
+		g_printerr ("Optimizing %s...done\n", sheet->name_unquoted);
+
 	if (verify) {
 		GSList *post = sample_styles (sheet);
 		verify_styles (pre, post);
