@@ -113,7 +113,7 @@ struct _Sheet {
 	GnmSheetSize size;
 
 	/* tile related data */
-	int tile_top_level, max_width, max_height;
+	int tile_top_level;
 };
 
 #define GNM_SHEET_TYPE	(gnm_sheet_get_type ())
@@ -157,15 +157,17 @@ struct _GnmCellIter {
 	GnmParsePos  pp;
 	ColRowInfo  *ci, *ri;
 };
-GnmValue *sheet_foreach_cell_in_range	(Sheet *sheet, CellIterFlags flags,
-				  int start_col, int start_row,
-				  int end_col, int end_row,
-				  CellIterFunc callback,
-				  gpointer     closure);
+GnmValue *sheet_foreach_cell_in_range (Sheet *sheet, CellIterFlags flags,
+				       int start_col, int start_row,
+				       int end_col, int end_row,
+				       CellIterFunc callback,
+				       gpointer     closure);
 void	    sheet_cell_foreach	 (Sheet const *sheet,
 				  GHFunc callback, gpointer data);
 unsigned    sheet_cells_count	 (Sheet const *sheet);
-GPtrArray  *sheet_cells          (Sheet *sheet, gboolean comments);
+GPtrArray  *sheet_cell_positions (Sheet *sheet, gboolean comments);
+
+GPtrArray  *sheet_cells          (Sheet *sheet, const GnmRange *r);
 
 void        sheet_recompute_spans_for_col     (Sheet *sheet, int col);
 
